<?php
require_once(__DIR__ . '/../inc/config.php');
require_once(__DIR__ . '/_admin_inc.php');

// language
$query = "SELECT * FROM language WHERE lang = :lang AND section = :section AND template = :template";
$stmt = $conn->prepare($query);
$stmt->bindValue(':lang', $html_lang);
$stmt->bindValue(':section', 'admin');
$stmt->bindValue(':template', 'locations');
$stmt->execute();

while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
	${$row['var_name']} = e($row['translated']);
}

// pagination
$page = !empty($_GET['page']) ? $_GET['page'] : 1;
$limit = $items_per_page;

if($page > 1) {
	$offset = ($page-1) * $limit + 1;
}

else {
	$offset = 1;
}

// sort
$sort = !empty($_GET['sort']) ? $_GET['sort'] : 'cities';

$page_url = "$baseurl/admin/locations-trash?sort=$sort&page=";

if(isset($_GET['s'])) {
	$s = urlencode($_GET['s']);
	$page_url = "$baseurl/admin/locations-trash?s=$s&sort=$sort&page=";
}

// keyword
$keyword = !empty($_GET['s']) ? $_GET['s'] : '';
$keyword = '%' . $keyword . '%';

// init total_rows
$total_rows_cities    = 0;
$total_rows_regions    = 0;
$total_rows_countries = 0;

$total_rows = $total_rows_cities;

if($sort == 'cities') {
	// count how many cities
	$query = "SELECT COUNT(*) AS total_rows FROM cities WHERE status = 0";

	if(!empty($keyword)) {
		$query = "SELECT COUNT(*) AS total_rows FROM cities WHERE status = 0 AND city_name LIKE :keyword";
	}

	$stmt = $conn->prepare($query);

	if(!empty($keyword)) {
		$stmt->bindValue(':keyword', $keyword);
	}

	$stmt->execute();
	$row = $stmt->fetch(PDO::FETCH_ASSOC);
	$total_rows_cities = $row['total_rows'];
	$total_rows = $total_rows_cities;

	$cities_arr = array();

	if($total_rows_cities > 0) {
		$pager = new App\PageIterator($limit, $total_rows_cities, $page);
		$start = $pager->getStartRow();

		// select all cities information and put in an array
		$query = "SELECT cities.*, cities_feat.city_id AS feat FROM cities
		LEFT JOIN cities_feat ON cities.city_id = cities_feat.city_id
		WHERE status = 0
		ORDER BY city_name LIMIT :start, :limit";

		if(!empty($keyword)) {
			$query = "SELECT cities.*, cities_feat.city_id AS feat FROM cities
			LEFT JOIN cities_feat ON cities.city_id = cities_feat.city_id
			WHERE status = 0 AND city_name LIKE :keyword
			ORDER BY city_name LIMIT :start, :limit";
		}

		$stmt = $conn->prepare($query);

		if(!empty($keyword)) {
			$stmt->bindValue(':keyword', $keyword);
		}

		$stmt->bindValue(':start', $start);
		$stmt->bindValue(':limit', $limit);
		$stmt->execute();

		while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
			$this_city_id    = !empty($row['city_id'  ]) ? $row['city_id'  ] : '';
			$this_city_name  = !empty($row['city_name']) ? $row['city_name'] : '';
			$this_state_abbr = !empty($row['state'    ]) ? $row['state'    ] : '';
			$this_state_id   = !empty($row['state_id' ]) ? $row['state_id' ] : '';
			$this_city_slug  = !empty($row['slug'     ]) ? $row['slug'     ] : '';
			$this_is_feat    = !empty($row['feat'     ]) ? $row['feat'     ] : '';

			// sanitize
			$this_city_name  = e($this_city_name);
			$this_state_abbr = e($this_state_abbr);
			$this_city_slug  = e($this_city_slug);
			$this_is_feat    = e($this_is_feat);

			// loop array
			$cur_loop_arr = array(
				'city_id'    => $this_city_id,
				'city_name'  => $this_city_name,
				'state_abbr' => $this_state_abbr,
				'state_id'   => $this_state_id,
				'city_slug'  => $this_city_slug,
				'is_feat'    => $this_is_feat,
			);

			// add to cities array
			$cities_arr[] = $cur_loop_arr;
		}
	}
}

else if($sort == 'regions') {
	// count how many regions
	$query = "SELECT COUNT(*) AS total_rows FROM states WHERE status = 0";

	if(!empty($keyword)) {
		$query = "SELECT COUNT(*) AS total_rows FROM states WHERE status = 0 AND state_name LIKE :keyword";
	}

	$stmt = $conn->prepare($query);

	if(!empty($keyword)) {
		$stmt->bindValue(':keyword', $keyword);
	}

	$stmt->execute();
	$row = $stmt->fetch(PDO::FETCH_ASSOC);
	$total_rows_regions = $row['total_rows'];
	$total_rows = $total_rows_regions;

	$regions_arr = array();

	if($total_rows_regions > 0) {
		$pager = new App\PageIterator($limit, $total_rows_regions, $page);
		$start = $pager->getStartRow();

		// select all regions information and put in an array
		$query = "SELECT * FROM states WHERE status = 0 ORDER BY state_name LIMIT :start, :limit";

		if(!empty($keyword)) {
			$query = "SELECT * FROM states
			WHERE status = 0 AND state_name LIKE :keyword
			ORDER BY state_name LIMIT :start, :limit";
		}

		$stmt = $conn->prepare($query);

		if(!empty($keyword)) {
			$stmt->bindValue(':keyword', $keyword);
		}

		$stmt->bindValue(':start', $start);
		$stmt->bindValue(':limit', $limit);
		$stmt->execute();

		while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
			$this_state_id     = !empty($row['state_id'    ]) ? $row['state_id'    ] : '';
			$this_state_name   = !empty($row['state_name'  ]) ? $row['state_name'  ] : '';
			$this_state_abbr   = !empty($row['state_abbr'  ]) ? $row['state_abbr'  ] : '';
			$this_state_slug   = !empty($row['slug'        ]) ? $row['slug'        ] : '';
			$this_country_abbr = !empty($row['country_abbr']) ? $row['country_abbr'] : '';
			$this_country_id   = !empty($row['country_id'  ]) ? $row['country_id'  ] : '';

			// sanitize
			$this_state_name   = e($this_state_name  );
			$this_state_abbr   = e($this_state_abbr  );
			$this_state_slug   = e($this_state_slug  );
			$this_country_abbr = e($this_country_abbr);

			// loop array
			$cur_loop_arr = array(
				'state_id'     => $this_state_id,
				'state_name'   => $this_state_name,
				'state_abbr'   => $this_state_abbr,
				'state_slug'   => $this_state_slug,
				'country_abbr' => $this_country_abbr,
				'country_id'   => $this_country_id,
			);

			// add to regions array
			$regions_arr[] = $cur_loop_arr;
		}
	}
}

// else show countries
else {
	// count how many countries
	$query = "SELECT COUNT(*) AS total_rows FROM countries WHERE status = 0";
	$stmt = $conn->prepare($query);
	$stmt->execute();
	$row = $stmt->fetch(PDO::FETCH_ASSOC);
	$total_rows_countries = $row['total_rows'];
	$total_rows = $total_rows_countries;

	$countries_arr = array();

	if($total_rows_countries > 0) {
		$pager = new App\PageIterator($limit, $total_rows_countries, $page);
		$start = $pager->getStartRow();

		// select all regions information and put in an array
		$query = "SELECT * FROM countries WHERE status = 0 ORDER BY country_name LIMIT :start, :limit";
		$stmt = $conn->prepare($query);
		$stmt->bindValue(':start', $start);
		$stmt->bindValue(':limit', $limit);
		$stmt->execute();

		while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
			$this_country_id   = !empty($row['country_id'  ]) ? $row['country_id'  ] : '';
			$this_country_name = !empty($row['country_name']) ? $row['country_name'] : '';
			$this_country_abbr = !empty($row['country_abbr']) ? $row['country_abbr'] : '';
			$this_country_slug = !empty($row['slug'        ]) ? $row['slug'        ] : '';

			// sanitize
			$this_country_name = e($this_country_name);
			$this_country_abbr = e($this_country_abbr);
			$this_country_slug = e($this_country_slug);

			// loop array
			$cur_loop_arr = array(
				'country_id'   => $this_country_id,
				'country_name' => $this_country_name,
				'country_abbr' => $this_country_abbr,
				'country_slug' => $this_country_slug,
			);

			// add to countries array
			$countries_arr[] = $cur_loop_arr;
		}
	}
}
