<?php
require_once(__DIR__ . '/../inc/config.php');
require_once(__DIR__ . '/_admin_inc.php');

// pagination
$page = !empty($_GET['page']) ? $_GET['page'] : 1;
$limit = $items_per_page;

if($page > 1) {
	$offset = ($page-1) * $limit + 1;
}

else {
	$offset = 1;
}

// show
$show = !empty($_GET['show']) ? $_GET['show'] : 'all';

if(!in_array($show, array('pending', 'all'))) {
	$show = 'all';
}

// sort order (date, user, title)
$sort = !empty($_GET['sort']) ? $_GET['sort'] : 'date-desc';

if(!in_array($sort, array('date', 'date-desc', 'user', 'user-desc', 'title', 'title-desc', ))) {
	$sort = 'date-desc';
}

// page url
$page_url = "$baseurl/admin/reviews-trash?sort=$sort&page=";

// init results array
$reviews_arr = array();

// count query
$query = "SELECT COUNT(*) AS c FROM reviews WHERE status = 'trashed'";
$stmt = $conn->prepare($query);
$stmt->execute();
$row = $stmt->fetch(PDO::FETCH_ASSOC);
$total_rows = $row['c'];

if($total_rows > 0) {
	$pager = new App\PageIterator($limit, $total_rows, $page);
	$start = $pager->getStartRow();

	// define sort
	$order_by = "review_id DESC";

	if($sort == 'date') {
		$order_by = "review_id";
	}

	if($sort == 'user') {
		$order_by = "first_name";
	}

	if($sort == 'user-desc') {
		$order_by = "first_name DESC";
	}

	if($sort == 'title') {
		$order_by = "listing_title";
	}

	if($sort == 'title-desc') {
		$order_by = "listing_title DESC";
	}

	$query = "SELECT
		r.review_id, r.listing_id, r.pubdate, r.rating, r.text, r.user_id, r.status,
		p.listing_title, p.slug AS listing_slug, p.main_pic,
		rel.cat_id,
		cats.id AS cat_id, cats.cat_slug,
		c.city_id, c.slug AS city_slug, c.city_name,
		s.slug AS state_slug,
		u.first_name, u.last_name
		FROM reviews r
		LEFT JOIN listings p ON r.listing_id = p.listing_id
		LEFT JOIN rel_listing_cat rel ON rel.listing_id = r.listing_id AND rel.is_main = 1
		LEFT JOIN cats ON cats.id = rel.cat_id
		LEFT JOIN cities c ON p.city_id = c.city_id
		LEFT JOIN states s ON c.state_id = s.state_id
		LEFT JOIN users u ON r.user_id = u.id
		WHERE r.status = 'trashed'
		GROUP BY review_id
		ORDER BY $order_by LIMIT :start, :limit";
	$stmt = $conn->prepare($query);
	$stmt->bindValue(':start', $start);
	$stmt->bindValue(':limit', $limit);
	$stmt->execute();

	while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
		$this_review_id     = $row['review_id'];
		$this_cat_id        = !empty($row['cat_id'       ]) ? $row['cat_id'       ] : '';
		$this_cat_slug      = !empty($row['cat_slug'     ]) ? $row['cat_slug'     ] : $cat_id;
		$this_city_id       = !empty($row['city_id'      ]) ? $row['city_id'      ] : '';
		$this_city_name     = !empty($row['city_name'    ]) ? $row['city_name'    ] : '';
		$this_city_slug     = !empty($row['city_slug'    ]) ? $row['city_slug'    ] : '';
		$this_dir           = !empty($row['dir'          ]) ? $row['dir'          ] : '';
		$this_filename      = !empty($row['filename'     ]) ? $row['filename'     ] : '';
		$this_first_name    = !empty($row['first_name'   ]) ? $row['first_name'   ] : '';
		$this_last_name     = !empty($row['last_name'    ]) ? $row['last_name'    ] : '';
		$this_listing_id    = !empty($row['listing_id'   ]) ? $row['listing_id'   ] : '';
		$this_listing_slug  = !empty($row['listing_slug' ]) ? $row['listing_slug' ] : $listing_id;
		$this_listing_title = !empty($row['listing_title']) ? $row['listing_title'] : '';
		$this_pubdate       = !empty($row['pubdate'      ]) ? $row['pubdate'      ] : '';
		$this_rating        = !empty($row['rating'       ]) ? $row['rating'       ] : 0;
		$this_state_slug    = !empty($row['state_slug'   ]) ? $row['state_slug'   ] : '';
		$this_status        = !empty($row['status'       ]) ? $row['status'       ] : '';
		$this_text          = !empty($row['text'         ]) ? $row['text'         ] : '';
		$this_user_id       = !empty($row['user_id'      ]) ? $row['user_id'      ] : '';

		// sanitize
		$this_first_name    = e($this_first_name);
		$this_last_name     = e($this_last_name);
		$this_listing_slug  = e($this_listing_slug);
		$this_listing_title = e($this_listing_title);
		$this_text          = e($this_text);

		// simplify date
		$this_pubdate = strtotime($this_pubdate);
		$this_pubdate = date( 'Y-m-d', $this_pubdate );

		// author_name
		$this_author_name = "$this_first_name $this_last_name";
		if (mb_strlen($this_author_name) > 10) {
			$this_author_name = mb_substr($this_author_name, 0, 10) . '...';
		}

		// limit strings
		if (strlen($this_listing_title) > 20) {
			$this_listing_title = mb_substr($this_listing_title, 0, 20) . '...';
		}

		// listing link
		$this_listing_link = get_listing_link(
			$this_listing_id,
			$this_listing_slug,
			$this_cat_id,
			$this_cat_slug,
			'',
			$this_city_slug,
			$this_state_slug,
			$cfg_permalink_struct);

		// main pic url
		$this_main_pic_url = $baseurl . '/assets/imgs/blank.png';

		if(!empty($this_main_pic)) {
			if(is_file($pic_basepath . '/main-pic/' . substr($this_main_pic, 0, 2) . '/' . $this_main_pic)) {
				$this_main_pic_url = $pic_baseurl . '/main-pic/' . substr($this_main_pic, 0, 2) . '/' . $this_main_pic;
			}
		}

		// user profile pic
		$folder = floor($this_user_id / 1000) + 1;

		if(strlen($folder) < 1) {
			$folder = '999';
		}

		// profile pic path
		$this_pic_path = $pic_basepath . '/' . $profile_full_folder . '/' . $folder . '/' . $this_user_id;

		// check if file exists
		$this_pic_glob_arr = glob("$this_pic_path.*");

		if(!empty($this_pic_glob_arr)) {
			$this_prof_pic_filename = basename($this_pic_glob_arr[0]);

			// set first match as profile pic
			$this_prof_pic_url = $pic_baseurl . '/' . $profile_full_folder . '/' . $folder . '/' . $this_prof_pic_filename;

			// set first match as profile pic
			$this_prof_thumb_url = $pic_baseurl . '/' . $profile_thumb_folder . '/' . $folder . '/' . $this_prof_pic_filename;
		}

		else {
			$this_prof_pic_url = $baseurl . '/assets/imgs/blank.png';
			$this_prof_thumb_url = $baseurl . '/assets/imgs/blank.png';
		}

		$cur_arr = array(
					'review_id'      => $this_review_id,
					'author_name'    => $this_author_name,
					'author_pic_url' => $this_prof_thumb_url,
					'city_id'        => $this_city_id,
					'city_name'      => $this_city_name,
					'city_slug'      => $this_city_slug,
					'dir'            => $this_dir,
					'filename'       => $this_filename,
					'listing_link'   => $this_listing_link,
					'listing_id'     => $this_listing_id,
					'listing_title'  => $this_listing_title,
					'main_pic'       => $this_main_pic_url,
					'pubdate'        => $this_pubdate,
					'rating'         => $this_rating,
					'status'         => $this_status,
					'text'           => $this_text,
					);

		$reviews_arr[] = $cur_arr;
	}
}