<?php
require_once(__DIR__ . '/inc/config.php');

if(empty($userid)) {
	$redir_url = $baseurl . '/user/sign-in';
	header("Location: $redir_url");
}

// get listing id
$listing_id = !empty($_GET['id']) ? $_GET['id'] : '';

// check if listing id is numeric
if(!ctype_digit($listing_id) || empty($listing_id)) {
	http_response_code(404);
	include($install_dir . '/templates/404.php');
	die();
}

/*--------------------------------------------------
listing info
--------------------------------------------------*/
$query = "SELECT p.*, c.name AS cat_name, c.id AS cat_id
				FROM listings p
				LEFT JOIN rel_listing_cat r ON p.listing_id = r.listing_id
				LEFT JOIN cats c ON c.id = r.cat_id
				WHERE p.listing_id = :listing_id";
$stmt = $conn->prepare($query);
$stmt->bindValue(':listing_id', $listing_id);
$stmt->execute();

if($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
	$address        = !empty($row['address'      ]) ? $row['address'      ] : '';
	$area_code      = !empty($row['area_code'    ]) ? $row['area_code'    ] : '';
	$cat_id         = !empty($row['cat_id'       ]) ? $row['cat_id'       ] : '';
	$cat_name       = !empty($row['cat_name'     ]) ? $row['cat_name'     ] : '';
	$city_id        = !empty($row['city_id'      ]) ? $row['city_id'      ] : 0;
	$phone          = !empty($row['phone'        ]) ? $row['phone'        ] : '';
	$listing_title  = !empty($row['listing_title']) ? $row['listing_title'] : 'Undefined';
	$listing_userid = !empty($row['userid'       ]) ? $row['userid'       ] : '1';
	$postal_code    = !empty($row['postal_code'  ]) ? $row['postal_code'  ] : '';
	$short_desc     = !empty($row['short_desc'   ]) ? $row['short_desc'   ] : '';

	// get translated cat name if user language cookie is set
	if(!empty($user_cookie_lang)) {
		$cat_name = cat_name_transl($cat_id, $user_cookie_lang, 'singular', $cat_name);
	}

	// sanitize
	$listing_title  = e($listing_title );
	$address        = e($address       );
	$city_id        = e($city_id       );
	$listing_userid = e($listing_userid);
	$cat_name       = e($cat_name      );
	$short_desc     = e($short_desc    );
	$postal_code    = e($postal_code   );
	$area_code      = e($area_code     );
	$phone          = e($phone         );
}

/*--------------------------------------------------
Location
--------------------------------------------------*/
$query = "SELECT
		c.city_name, c.slug AS city_slug,
		s.state_id, s.state_name, s.state_abbr, s.slug AS state_slug
		FROM cities c
		LEFT JOIN states s ON c.state_id = s.state_id
		WHERE city_id = :city_id";
$stmt = $conn->prepare($query);
$stmt->bindValue(':city_id', $city_id);
$stmt->execute();
$row = $stmt->fetch(PDO::FETCH_ASSOC);

$city_name  = !empty($row['city_name' ]) ? $row['city_name' ] : '';
$city_slug  = !empty($row['city_slug' ]) ? $row['city_slug' ] : $city_id;
$state_id   = !empty($row['state_id'  ]) ? $row['state_id'  ] : '';
$state_name = !empty($row['state_name']) ? $row['state_name'] : '';
$state_abbr = !empty($row['state_abbr']) ? $row['state_abbr'] : '';
$state_slug = !empty($row['state_slug']) ? $row['state_slug'] : $state_id;

/*--------------------------------------------------
Photo
--------------------------------------------------*/

$query = "SELECT * FROM photos WHERE listing_id = :listing_id ORDER BY photo_id DESC LIMIT 1";
$stmt = $conn->prepare($query);
$stmt->bindValue(':listing_id', $listing_id);
$stmt->execute();
$row = $stmt->fetch(PDO::FETCH_ASSOC);
$dir      = !empty($row['dir']     ) ? $row['dir']      : '';
$filename = !empty($row['filename']) ? $row['filename'] : '';

if(!empty($filename) && !empty($dir)) {
	$photo_url = $pic_baseurl . '/' . $listing_thumb_folder . '/' . $dir . '/' . $filename;
}

else {
	$photo_url = $baseurl . '/assets/imgs/blank.png';
}

/*--------------------------------------------------
Plans
--------------------------------------------------*/
$plans = array();

$query = "SELECT * FROM plans";
$stmt = $conn->prepare($query);
$stmt->execute();

while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
	$plans[$row['plan_id']] = array(
		'plan_name' => $row['plan_name'],
		'plan_type' => $row['plan_type'],
		'plan_max_pics' => $row['plan_max_pics'],
	);
}

/*--------------------------------------------------
Check if user has credits
--------------------------------------------------*/
if(!$is_admin) {
	$user_credits = array();
	$plan_uniqid = array();

	$query = "SELECT * FROM credits WHERE user = :userid";
	$stmt = $conn->prepare($query);
	$stmt->bindValue(':userid', $userid);
	$stmt->execute();

	while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
		if(isset($plans[$row['plan']])) {
			$user_credits[$row['uniq_id']] = $row['credits'];
			$plan_uniqid[$row['uniq_id']] = $plans[$row['plan']]['plan_name'];
		}
	}

	if(array_sum($user_credits) < 1) {
		$redir_url = $baseurl . '/user/select-plan';
		header("Location: $redir_url");
	}
}

/*--------------------------------------------------
canonical
--------------------------------------------------*/
$canonical = $baseurl . '/claim';
