<?php
/**
 * Stripe webhook listener
 * The URL to this file should be defined in your Stripe Dashboard
 *
 * since v.1.0
 */

/**
GENERAL LAYOUT

if(!$is_subscription) {
	if($event['type'] == 'charge.succeeded') {
		...
	}

	else if($event['type'] == "charge.failed" || $event['type'] == "charge.refunded") {
		...
	}

	else {
		...
	}
}
else {
	if($event['type'] == 'customer.subscription.created') {
		...
	}

	else if($event['type'] == 'charge.succeeded') {
		...
	}

	else if($event['type'] == 'invoice.payment_succeeded') {
		...
	}

	else if($event['type'] == 'invoice.payment_failed') {
		...
	}

	else if($event['type'] == 'customer.subscription.deleted') {
		...
	}

	else {
		...
	}
}
*/

// includes
require_once(__DIR__ . '/../inc/config.php');
require_once(__DIR__ . '/../vendor/swiftmailer/swiftmailer/lib/swift_required.php');

// define smtp transport
$transport_smtp = (new Swift_SmtpTransport($smtp_server, $smtp_port, $cfg_smtp_encryption))
  ->setUsername($smtp_user)
  ->setPassword($smtp_pass);

// define mailer obj
$mailer = new Swift_Mailer($transport_smtp);

// set api key
// if stripe live mode
if($stripe_mode == 1) {
	$stripe_key = $stripe_live_secret_key;
}

// else is stripe test mode
else {
	$stripe_key = $stripe_test_secret_key;
}

\Stripe\Stripe::setApiKey($stripe_key);
\Stripe\Stripe::setApiVersion("2016-10-19");

// Retrieve the request's body and parse it as JSON
$input = @file_get_contents("php://input");

// extract json str into assoc array
//$event_json = json_decode($input); --> object
$event_arr = json_decode($input, true); // --> array

// Check against Stripe to confirm that the ID is valid
if(!empty($event_arr['id'])) {
	$event_obj = \Stripe\Event::retrieve($event_arr['id']);

	// convert $event into assoc array
	$event = $event_obj->toArray(true);
}

// check if it's proper event
if(!isset($event)) {
	die();
}

// event types
$events = array('charge.succeeded', 'charge.failed', 'customer.subscription.created', 'customer.subscription.deleted', 'invoice.payment_succeeded', 'invoice.payment_failed');

// act only on the event types above
if(!in_array($event['type'], $events)) {
	die();
}

// check if is subscription or not
$is_subscription = null;

if($event['type'] == 'charge.succeeded') {
	if(empty($event['data']['object']['invoice'])) {
		$is_subscription = false;
	}

	else {
		$is_subscription = true;
	}
}

if( $event['type'] == 'customer.subscription.created' ||
	$event['type'] == 'customer.subscription.deleted' ||
	$event['type'] == 'invoice.payment_succeeded'
	) {
	$is_subscription = true;
}

if($event['type'] == 'charge.failed') {
	// if charge failed, it could be either subscription or buy now
	// but if metadata is empty, it means it's subscription, if contains metadata, it's buy now
	if(!empty($event['data']['object']['metadata'])) {
		$is_subscription = false;
	}

	else {
		$is_subscription = true;
	}
}

// metadata
// for 'buy now', metadata data is sent with \Stripe\Charge::create and received in webhook of type 'charge.succeeded'
// for 'subscriptions', metadata data is sent with \Stripe\Subscription::create and received in webhook type 'customer.subscription.created' and 'customer.subscription.deleted', also in 'invoice.payment_succeeded', 'invoice.created'
$plan_type = 'undefined plan';
$plan_id   = 0;
$listing_id  = 0;
$payer_id  = ''; // in case it's from the claim listings form

if($event['type'] == 'charge.succeeded' || $event['type'] == 'charge.failed') {
	if(!$is_subscription) {
		$plan_type = !empty($event['data']['object']['metadata']['plan_type']) ? $event['data']['object']['metadata']['plan_type'] : 'undefined plan';
		$plan_id   = !empty($event['data']['object']['metadata']['plan_id']  ) ? $event['data']['object']['metadata']['plan_id']   : 0;
		$listing_id  = !empty($event['data']['object']['metadata']['listing_id'] ) ? $event['data']['object']['metadata']['listing_id']  : 0;
		$payer_id  = !empty($event['data']['object']['metadata']['payer_id'] ) ? $event['data']['object']['metadata']['payer_id']  : 0;
	}
}

if($event['type'] == 'customer.subscription.created' || $event['type'] == 'customer.subscription.deleted') {
	$plan_type = !empty($event['data']['object']['metadata']['plan_type']) ? $event['data']['object']['metadata']['plan_type'] : 'undefined plan';
	$plan_id   = !empty($event['data']['object']['metadata']['plan_id']  ) ? $event['data']['object']['metadata']['plan_id']   : 0;
	$listing_id  = !empty($event['data']['object']['metadata']['listing_id'] ) ? $event['data']['object']['metadata']['listing_id']  : 0;
	$payer_id  = !empty($event['data']['object']['metadata']['payer_id'] ) ? $event['data']['object']['metadata']['payer_id']  : 0;
}

// subscr_id
$subscr_id = 'undefined';

if($plan_type == 'one_time' || $plan_type == 'one_time_feat') {
	$subscr_id = 'none';
}

else {
	$subscr_id = !empty($event['data']['object']['id']) ? $event['data']['object']['id'] : 'empty';
}

// customer info
$customer_obj   = \Stripe\Customer::retrieve($event['data']['object']['customer']);
$customer       = $customer_obj->toArray(true);
$customer_email = $customer['email'];
$customer_id    = $customer['id'];

// transaction table vars
$parent_txn_id   = '';
$ipn_vars        = $input;
$ipn_response    = $input;
$ipn_description = !empty($event['data']['object']['object']) ? $event['data']['object']['object'] : 'undefined';
$payer_email     = !empty($customer['email'                ]) ? $customer['email']                 : 'undefined';
$txn_type        = !empty($event['type'                    ]) ? $event['type']                     : 'undefined';
$payment_status  = !empty($event['data']['object']['status']) ? $event['data']['object']['status'] : 'undefined';
$amount          = !empty($event['data']['object']['amount']) ? $event['data']['object']['amount'] : 'undefined';
$txn_id          = !empty($event['id'                      ]) ? $event['id']                       : 'undefined';
$txn_date        = !empty($event['created'                 ]) ? $event['created']                  : 'undefined';

/*--------------------------------------------------
Vars
--------------------------------------------------*/
$debug_msg = "
is_subscription = $is_subscription
ipn_description = $ipn_description
plan_id         = $plan_id
listing_id      = $listing_id
plan_type       = $plan_type
payer_email     = $payer_email
txn_type        = $txn_type
payment_status  = $payment_status
amount          = $amount
txn_id          = $txn_id
parent_txn_id   = $parent_txn_id
subscr_id       = $subscr_id
ipn_vars        = $ipn_vars
txn_date        = $txn_date
customer_id     = $customer_id;
ipn_response    = $ipn_response
";

/*--------------------------------------------------
HANDLE EVENT
--------------------------------------------------*/
// init vars
$approve = false;

// get listing details and build link to listing to use in emails
$query = "SELECT p.listing_title, p.userid, p.slug AS listing_slug,
	c.slug AS city_slug,
	s.slug AS state_slug,
	cats.cat_slug
	FROM listings p
	LEFT JOIN cities c ON p.city_id = c.city_id
	LEFT JOIN states s ON c.state_id = s.state_id
	LEFT JOIN rel_listing_cat r ON p.listing_id = r.listing_id
	LEFT JOIN cats ON cats.id = r.cat_id
	WHERE p.listing_id = :listing_id";
$stmt = $conn->prepare($query);
$stmt->bindValue(':listing_id', $listing_id);
$stmt->execute();
$row = $stmt->fetch(PDO::FETCH_ASSOC);

$listing_title      = !empty($row['listing_title']) ? $row['listing_title'] : '';
$listing_slug       = !empty($row['listing_slug']) ? $row['listing_slug'] : '';
$listing_cat_slug   = !empty($row['cat_slug'  ]) ? $row['cat_slug'  ] : '';
$listing_userid     = !empty($row['userid'    ]) ? $row['userid'    ] : '';
$listing_city_slug  = !empty($row['city_slug' ]) ? $row['city_slug' ] : '';
$listing_state_slug = !empty($row['state_slug']) ? $row['state_slug'] : '';

$listing_link = $baseurl . '/listing/' . $listing_state_slug . '/' . $listing_city_slug . '/' . $listing_cat_slug . '/' . $listing_slug;

// if buy now
if(!$is_subscription) {
	if($event['type'] == 'charge.succeeded') {
		// define email informing user of charge.succeeded
		$query = "SELECT * FROM email_templates WHERE type = 'web_accept'";
		$stmt = $conn->prepare($query);
		$stmt->execute();
		$row = $stmt->fetch(PDO::FETCH_ASSOC);
		$email_subject = !empty($row['subject']) ? $row['subject'] : '';
		$email_body    = !empty($row['body'   ]) ? $row['body'   ] : '';

		// string replacements
		$email_subject = str_replace('%site_name%', $site_name, $email_subject);
		$email_subject = str_replace('%site_url%', $baseurl, $email_subject);
		$email_body = str_replace('%site_name%', $site_name, $email_body);
		$email_body = str_replace('%site_url%', $baseurl, $email_body);

		// set approve to true
		$approve = true;
	}

	else if($event['type'] == 'charge.failed') {
		// define email informing user of charge.failed
		$query = "SELECT * FROM email_templates WHERE type = 'charge_failed'";
		$stmt = $conn->prepare($query);
		$stmt->execute();
		$row = $stmt->fetch(PDO::FETCH_ASSOC);
		$email_subject = !empty($row['subject']) ? $row['subject'] : '';
		$email_body    = !empty($row['body'   ]) ? $row['body'   ] : '';

		// string replacements
		$email_subject = str_replace('%site_name%', $site_name, $email_subject);
		$email_subject = str_replace('%site_url%', $baseurl, $email_subject);
		$email_body = str_replace('%site_name%', $site_name, $email_body);
		$email_body = str_replace('%site_url%', $baseurl, $email_body);
	}

	else if($event['type'] == 'charge.refunded') {
		// define email informing user of charge.failed
		$query = "SELECT * FROM email_templates WHERE type = 'charge_failed'";
		$stmt = $conn->prepare($query);
		$stmt->execute();
		$row = $stmt->fetch(PDO::FETCH_ASSOC);
		$email_subject = !empty($row['subject']) ? $row['subject'] : '';
		$email_body    = !empty($row['body'   ]) ? $row['body'   ] : '';

		// string replacements
		$email_subject = str_replace('%site_name%', $site_name, $email_subject);
		$email_subject = str_replace('%site_url%', $baseurl, $email_subject);
		$email_body = str_replace('%site_name%', $site_name, $email_body);
		$email_body = str_replace('%site_url%', $baseurl, $email_body);
	}

	else {
		// log transaction
		error_log("Webhook data is a one-off purchase but charge neither succeeded nor failed/refunded");
	}
}

// else is subscription
else {
	// webhook types to act on:
		// 'customer.subscription.created'
		// 'customer.subscription.deleted'
		// 'invoice.payment_succeeded'
		// 'invoice.payment_failed'
	// if subscription succeeded
	if($event['type'] == 'customer.subscription.created') {
		// define email informing user of subscr_signup success
		$query = "SELECT * FROM email_templates WHERE type = 'subscr_signup'";
		$stmt = $conn->prepare($query);
		$stmt->execute();
		$row = $stmt->fetch(PDO::FETCH_ASSOC);
		$email_subject = !empty($row['subject']) ? $row['subject'] : '';
		$email_body    = !empty($row['body'   ]) ? $row['body'   ] : '';

		// string replacements
		$email_subject = str_replace('%site_name%', $site_name, $email_subject);
		$email_subject = str_replace('%site_url%', $baseurl, $email_subject);
		$email_body = str_replace('%site_name%', $site_name, $email_body);
		$email_body = str_replace('%site_url%', $baseurl, $email_body);

		// set approve to true
		$approve = true;
	}

	else if($event['type'] == 'charge.succeeded') {
		// log transaction
	}

	else if($event['type'] == 'invoice.payment_succeeded') {
		// log transaction
	}

	else if($event['type'] == 'invoice.payment_failed') {
		// define email informing user of invoice.payment_failed
		$query = "SELECT * FROM email_templates WHERE type = 'subscr_failed'";
		$stmt = $conn->prepare($query);
		$stmt->execute();
		$row = $stmt->fetch(PDO::FETCH_ASSOC);
		$email_subject = (!empty($row['subject'])) ? $row['subject'] : '';
		$email_body    = (!empty($row['body']   )) ? $row['body']    : '';

		// string replacements
		$email_subject = str_replace('%site_name%', $site_name, $email_subject);
		$email_subject = str_replace('%site_url%', $baseurl, $email_subject);
		$email_body = str_replace('%site_name%', $site_name, $email_body);
		$email_body = str_replace('%site_url%', $baseurl, $email_body);
	}

	else if($event['type'] == 'customer.subscription.deleted') {
		// update listings, set paid to 0
		$query = 'UPDATE listings SET paid = 0 WHERE listing_id = :listing_id';
		$stmt = $conn->prepare($query);
		$stmt->bindValue(':listing_id', $listing_id);
		$stmt->execute();

		// email user informing subscription ended
		$query = "SELECT * FROM email_templates WHERE type = 'subscr_eot'";
		$stmt = $conn->prepare($query);
		$stmt->execute();
		$row = $stmt->fetch(PDO::FETCH_ASSOC);
		$email_subject = (!empty($row['subject'])) ? $row['subject'] : '';
		$email_body    = (!empty($row['body']   )) ? $row['body']    : '';
	}

	else {
		// log transaction
	}
}

// if approve
if($approve) {
	try {
		$conn->beginTransaction();

		// update paid column in listings table
		$query = 'UPDATE listings SET paid = 1 WHERE listing_id = :listing_id';
		$stmt = $conn->prepare($query);
		$stmt->bindValue(':listing_id', $listing_id);
		$stmt->execute();

		// check if it's a claim listing
		if(!empty($payer_id)) {
			// update paid column in listings table
			$query = 'UPDATE listings SET userid = :userid WHERE listing_id = :listing_id';
			$stmt = $conn->prepare($query);
			$stmt->bindValue(':listing_id', $listing_id);
			$stmt->bindValue(':userid', $payer_id);
			$stmt->execute();
		}

		$conn->commit();
	}

	catch(PDOException $e) {
		$conn->rollBack();
	}
}

/*--------------------------------------------------
Check if subscription payment and listing deleted
--------------------------------------------------*/
// if this is a subscription payment and the listing has been deleted, then cancel the subscription
if($event['type'] == 'invoice.payment_succeeded') {
	$query = "SELECT * FROM listings WHERE listing_id = :listing_id";
	$stmt = $conn->prepare($query);
	$stmt->bindValue(':listing_id', $listing_id);
	$stmt->execute();

	$row = $stmt->fetch(PDO::FETCH_ASSOC);

	if(empty($row['listing_id'])) {
		// listing has been deleted so cancel subscription
		// set api key
		// if stripe live mode
		if($stripe_mode == 1) {
			$stripe_key = $stripe_live_secret_key;
		}

		// else is stripe test mode
		else {
			$stripe_key = $stripe_test_secret_key;
		}

		$subscription = \Stripe\Subscription::retrieve($subscr_id);
		$subscription->cancel();
	}
}

/*--------------------------------------------------
SEND EMAIL TO USER
--------------------------------------------------*/
// get user details
$query = "SELECT email, first_name FROM users WHERE id = :listing_userid";
$stmt = $conn->prepare($query);
$stmt->bindValue(':listing_userid', $listing_userid);
$stmt->execute();
$row = $stmt->fetch(PDO::FETCH_ASSOC);
$listing_user_email = !empty($row['email']) ? $row['email'] : $payer_email;
$listing_user_firstname = !empty($row['first_name']) ? $row['first_name'] : $first_name;

if($event['type'] == 'charge.succeeded'
|| $event['type'] == 'charge.failed'
|| $event['type'] == 'charge.refunded'
|| $event['type'] == 'customer.subscription.created'
|| $event['type'] == 'invoice.payment_failed'
|| $event['type'] == 'customer.subscription.deleted') {
	if(!empty($email_body)) {
		// substitutions
		$email_body = str_replace('%username%'  , $listing_user_firstname, $email_body);
		$email_body = str_replace('%listing_link%', $listing_link, $email_body);

		// send
		$message = (new Swift_Message())
			->setSubject($email_subject)
			->setFrom(array($admin_email => $site_name))
			->setTo($listing_user_email)
			->setBody($email_body)
			->setReplyTo($admin_email)
			->setReturnPath($admin_email)
			;

		$mailer->send($message);
	}
}

/*--------------------------------------------------
SEND EMAIL TO ADMIN
--------------------------------------------------*/

/*--------------------------------------------------
INSERT INTO TRANSACTIONS TABLE
--------------------------------------------------*/
// convert amount to decimal
$amount = $amount / 100;

$query = "INSERT INTO transactions(
		txn_type,
		uniq_id,
		user,
		paym_email,
		gateway,
		amount,
		txn_data
	)
	VALUES(
		:txn_type,
		:uniq_id,
		:user,
		:paym_email,
		:gateway,
		:amount,
		:txn_data
	)";
$stmt = $conn->prepare($query);
$stmt->bindValue(':txn_type'      , $txn_type);
$stmt->bindValue(':uniq_id'       , '');
$stmt->bindValue(':user'          , $listing_userid);
$stmt->bindValue(':paym_email'    , $customer_email);
$stmt->bindValue(':gateway'       , 'stripe');
$stmt->bindValue(':amount'        , $amount);
$stmt->bindValue(':txn_data'      , $ipn_vars);
$stmt->execute();
