<?php
require_once(__DIR__ . '/inc/config.php');

// check csrf token
require_once(__DIR__ . '/_inc_request_with_ajax.php');

// error codes
/*
1 - $txt_message_sent
2 - $txt_please_wait (submitting messages in less than $cgf_min_secs time
3 - missing required fields
4 - mailer error
5 - $txt_invalid_email invalid email
6 - invalid $from_page
*/

// sender ip
$sender_ip = get_ip();

// if sender ip already submitted less than 30 secs ago, return
$query = "SELECT TIMESTAMPDIFF(SECOND, created, NOW()) AS secs_ago FROM contact_msgs WHERE sender_ip = :sender_ip ORDER BY created DESC LIMIT 1";
$stmt  = $conn->prepare($query);
$stmt->bindValue(':sender_ip', $sender_ip);
$stmt->execute();
$row = $stmt->fetch(PDO::FETCH_ASSOC);
$secs_ago = !empty($row['secs_ago']) ? $row['secs_ago'] : $cgf_min_secs + 1;

if($secs_ago < $cgf_min_secs) {
	echo '2';
	return;
}

// get post data
$params = array();
parse_str($_POST['params'], $params);

// posted vars
$from_page    = !empty($params['from_page'   ]) ? $params['from_page'   ] : 'listing';
$listing_id   = !empty($params['listing_id'  ]) ? $params['listing_id'  ] : '';
$listing_url  = !empty($params['listing_url' ]) ? $params['listing_url' ] : '';
$recipient_id = !empty($params['recipient_id']) ? $params['recipient_id'] : '';
$sender_email = !empty($params['sender_email']) ? $params['sender_email'] : '';
$sender_name  = !empty($params['sender_name' ]) ? $params['sender_name' ] : '';
$sender_msg   = !empty($params['sender_msg'  ]) ? $params['sender_msg'  ] : '';

// if from listing page
if($from_page == 'listing') {
	// check vars
	if(empty($listing_id) || empty($sender_email)) {
		echo '3';
		return;
	}

	// append listing url
	$sender_msg .= "\n\n" . $listing_url;

	// get subject
	$query = "SELECT * FROM config WHERE property = 'cfg_contact_seller_subject'";
	$stmt  = $conn->prepare($query);
	$stmt->execute();
	$row = $stmt->fetch(PDO::FETCH_ASSOC);
	$contact_seller_subject = !empty($row['value']) ? $row['value'] : 'A message from ' . $site_name;

	// get listing owner email
	$query = "SELECT
				u.email
				FROM listings p
				LEFT JOIN users u ON p.userid = u.id
				WHERE p.listing_id = :listing_id";
	$stmt  = $conn->prepare($query);
	$stmt->bindValue(':listing_id', $listing_id);
	$stmt->execute();
	$row = $stmt->fetch(PDO::FETCH_ASSOC);
	$listing_owner_email = !empty($row['email']) ?  $row['email'] : '';

	// send message
	if(filter_var($sender_email, FILTER_VALIDATE_EMAIL) && filter_var($listing_owner_email, FILTER_VALIDATE_EMAIL)) {
		try {
			// mailer params
			$PHPMailer->clearAllRecipients();
			$PHPMailer->clearReplyTos();
			$PHPMailer->AllowEmpty = true;
			$PHPMailer->setFrom($admin_email, $site_name);
			$PHPMailer->addAddress($listing_owner_email);
			$PHPMailer->addReplyTo($sender_email);
			$PHPMailer->isHTML(false);
			$PHPMailer->Subject = $contact_seller_subject;
			$PHPMailer->Body = $sender_msg;

			// send
			if($PHPMailer->send()) {
				// write to db
				$query = "INSERT INTO contact_msgs(
							sender_email,
							sender_ip,
							listing_id,
							msg)
					VALUES(
							:sender_email,
							:sender_ip,
							:listing_id,
							:msg)";

				$stmt = $conn->prepare($query);
				$stmt->bindValue(':sender_email', $sender_email);
				$stmt->bindValue(':sender_ip',    $sender_ip);
				$stmt->bindValue(':listing_id',   $listing_id);
				$stmt->bindValue(':msg',          $sender_msg);
				$stmt->execute();
			}

			// result
			echo '1';
		} catch (Exception $e) {
			echo '4';
		}
	}

	else {
		echo '5';
	}
}

// if from profile page
else if($from_page == 'profile') {
	// check vars
	if(empty($recipient_id) || empty($sender_email) || empty($sender_msg)) {
		echo '3';
		return;
	}

	// get plugin settings from db
	$query = "SELECT * FROM config WHERE property = 'cfg_contact_user_subject'";
	$stmt  = $conn->prepare($query);
	$stmt->execute();
	$row = $stmt->fetch(PDO::FETCH_ASSOC);
	$contact_user_subject = !empty($row['value']) ? $row['value'] : '';

	// get user email
	$query = "SELECT email FROM users
				WHERE id = :recipient_id";
	$stmt  = $conn->prepare($query);
	$stmt->bindValue(':recipient_id', $recipient_id);
	$stmt->execute();
	$row = $stmt->fetch(PDO::FETCH_ASSOC);
	$recipient_email = $row['email'];

	// send message
	if(filter_var($sender_email, FILTER_VALIDATE_EMAIL) && filter_var($recipient_email, FILTER_VALIDATE_EMAIL)) {
		try {
			// mailer params
			$PHPMailer->clearAllRecipients();
			$PHPMailer->clearReplyTos();
			$PHPMailer->AllowEmpty = true;
			$PHPMailer->setFrom($admin_email, $site_name);
			$PHPMailer->addAddress($recipient_email);
			$PHPMailer->addReplyTo($sender_email);
			$PHPMailer->isHTML(false);
			$PHPMailer->Subject = $contact_user_subject;
			$PHPMailer->Body = $sender_msg;

			// send
			if($PHPMailer->send()) {
				// write to db
				$query = "INSERT INTO contact_msgs(
							sender_email,
							sender_ip,
							recipient_id,
							msg)
					VALUES(
							:sender_email,
							:sender_ip,
							:recipient_id,
							:msg)";

				$stmt = $conn->prepare($query);
				$stmt->bindValue(':sender_email', $sender_email);
				$stmt->bindValue(':sender_ip'   , $sender_ip);
				$stmt->bindValue(':recipient_id', $recipient_id);
				$stmt->bindValue(':msg'         , $sender_msg);
				$stmt->execute();

				echo '1';
			}
		} catch (Exception $e) {
			echo '4';
		}
	}

	else {
		echo '5';
	}
}

else {
	echo '6';
}