<?php
// prevent direct access
if(basename(__FILE__) == basename($_SERVER['SCRIPT_NAME'])) {
	http_response_code(401);
	die('Invalid access');
}
?><!DOCTYPE html>
<!--[if IE 9]><html class="lt-ie10" lang="<?= $html_lang ?>"> <![endif]-->
<html lang="<?= $html_lang ?>">
<head>
<title><?= $txt_html_title ?></title>
<?php require_once(__DIR__ . '/admin-head.php') ?>
</head>
<body class="tpl-admin-<?= $route[1] ?>">
<?php require_once(__DIR__ . '/../header.php') ?>

<div class="container mt-5">
	<div class="row">
		<div class="col-md-4 col-lg-3 mb-5">
			<?php include_once('admin-menu.php') ?>
		</div>

		<div class="col-md-8 col-lg-9">
			<h2 class="mb-5"><?= $txt_main_title ?></h2>

			<div class="mb-3">
				<strong><?= $txt_installed_lang ?>:</strong><br>

				<?php
				foreach($available_langs as $v) {
					?>
					<a href="<?= $baseurl ?>/admin/language?lang=<?= $v ?><?= isset($_GET['tpl']) ? '&tpl=' . $_GET['tpl'] : '' ?>" class="btn <?= $this_lang == $v ? 'btn-dark' : 'btn-light' ?> btn-sm"><?= $v ?></a>
					<?php
				}
				?>

				<a href="" class="btn btn-light btn-sm" data-toggle="modal" data-target="#create-lang-modal"><?= $txt_create_lang ?></a>

				<a href="" class="btn btn-light btn-sm" data-toggle="modal" data-target="#create-string-modal"><?= $txt_create_string ?></a>

				<a href="" class="btn btn-light btn-sm" data-toggle="modal" data-target="#remove-lang-modal"><i class="las la-trash-alt"></i> <?= $txt_remove_language ?></a>
			</div>

			<div class="mb-5">
				<strong><?= $txt_template ?>:</strong><br>

				<form class="form-inline" action="<?= $baseurl ?>/admin/language" method="get">
					<?php
					if(isset($_GET['lang'])) {
						?>
						<input type="hidden" name="lang" value="<?= $_GET['lang'] ?>">
						<?php
					}
					?>
					<select id="select-template" class="form-control mr-2" name="tpl">
						<?php
						foreach($available_tpls as $v) {
							?>
							<option value="<?= $v ?>" <?= $v == "$this_section/$this_tpl" ? 'selected' : '' ?>>
								<?= $v ?>
							</option>
							<?php
						}
						?>
					</select>
				</form>
			</div>

			<?php
			if(!empty($phrases_arr)) {
				?>
				<strong><?= $txt_vars ?>:</strong> (<?= $iso_639_1_native_names[$this_lang] ?>)<br>

				<form method="post" action="">
					<?php
					foreach($phrases_arr as $v) {
						?>
						<div class="form-group">
							<input type="text" class="form-control" name="txt_<?= $v['id'] ?>" value="<?= $v['translated'] ?>">
							<small class="form-text text-muted">[<?= $v['lang'] ?>][<?= $v['template'] ?>][<?= $v['var_name'] ?>]</small>
						</div>
						<?php
					}
					?>

					<input type="submit" class="btn btn-primary btn-lg">
				</form>
			<?php
			}

			else {
				?>
				<div class="mt-5 mb-3">
					<?= $txt_no_results ?>
				</div>
				<?php
			}
			?>
		</div>
	</div>
</div>

<!-- Create language modal -->
<div id="create-lang-modal" class="modal fade" tabindex="-1" role="dialog" aria-labelledby="modal-title-1">
	<div class="modal-dialog" role="document">
		<div class="modal-content">
			<div class="modal-header">
				<h5 id="modal-title-1" class="modal-title"><?= $txt_create_lang ?></h5>
				<button class="close" data-dismiss="modal" aria-label="<?= a($txt_close) ?>">
					<span aria-hidden="true">&times;</span>
				</button>
			</div>
			<div class="modal-body">
				<div class="mb-5">
					<p><?= $txt_select_lang_create ?>:</p>

					<form id="form-create-lang" class="form-inline" method="post">
						<select id="select-lang" class="form-control form-control-sm mr-2" name="select-lang">
							<?php
							foreach($iso_639_1_native_names as $k => $v) {
								if(!in_array($k, $available_langs)) {
									$selected = '';
									if($k == $html_lang) $selected = 'selected'
									?>
									<option value="<?= $k ?>" <?= $selected ?>><?= $k ?> (<?= $v ?>)</option>
									<?php
								}
							}
							?>
						</select>
						<button type="button" id="create-lang-submit" class="btn btn-primary btn-sm"><?= $txt_create_lang ?></button>
						<small id="create-lang-error" class="ml-2"></small>
					</form>
				</div>

				<?php
				if(!empty($available_sqls)) {
					?>
					<p><?= $txt_install_sql ?>:</p>

					<form id="form-install-lang" class="form-inline" method="post">
						<select id="select-file" class="form-control form-control-sm mr-2" name="install-lang">
							<?php
							foreach($available_sqls as $v) {
								?>
								<option value="<?= $v ?>"><?= $v ?></option>
								<?php
							}
							?>
						</select>
						<button type="button" id="install-lang-submit" class="btn btn-primary btn-sm"><?= $txt_install ?></button>
						<small id="install-lang-error" class="ml-2 text-monospace"></small>
					</form>
					<?php
				}
				?>
			</div>

			<div class="modal-footer">
				<button type="button" id="create-language-cancel" class="btn btn-light btn-sm" data-dismiss="modal"><?= $txt_cancel ?></button>
			</div>
		</div>
	</div>
</div>

<!-- Create string modal -->
<div id="create-string-modal" class="modal fade" tabindex="-1" role="dialog" aria-labelledby="modal-title-2">
	<div class="modal-dialog" role="document">
		<div class="modal-content">
			<div class="modal-header">
				<h5 id="modal-title-2" class="modal-title"><?= $txt_create_string ?></h5>
				<button class="close" data-dismiss="modal" aria-label="<?= a($txt_close) ?>">
					<span aria-hidden="true">&times;</span>
				</button>
			</div>
			<div class="modal-body">
				<form id="form-create-string" class="form" method="post">
					<div class="form-group">
						<div><strong><?= $txt_template ?></strong></div>

						<select class="form-control mr-2" name="template">
							<?php
							foreach($available_tpls as $v) {
								?>
								<option value="<?= $v ?>" <?= $v == "$this_section/$this_tpl" ? 'selected' : '' ?>>
									<?= $v ?>
								</option>
								<?php
							}
							?>
						</select>
					</div>

					<div class="form-group">
						<div><strong><?= $txt_var_name ?></strong></div>
						<input type="text" id="cat_name" class="form-control" name="var_name" required>
					</div>

					<?php
					foreach($available_langs as $v) {
						?>
						<div class="form-group">
							<label class="label" for="string_value_<?= $v ?>">
								<?= $txt_string_value ?>:
								<span class="badge badge-warning"><?= $iso_639_1_native_names[$v] ?></span>
							</label>

							<input type="text" id="string_value_<?= $v ?>" class="form-control" name="string_value[<?= $v ?>]" required>
						</div>
						<?php
					}
					?>
				</form>
			</div>

			<div class="modal-footer">
				<button type="button" id="create-string-cancel" class="btn btn-light btn-sm" data-dismiss="modal"><?= $txt_cancel ?></button>
				<button type="button" id="create-string-submit" class="btn btn-primary btn-sm"><?= $txt_submit ?></button>
			</div>
		</div>
	</div>
</div>

<!-- Remove language modal -->
<div id="remove-lang-modal" class="modal fade" tabindex="-1" role="dialog" aria-labelledby="modal-title-3">
	<div class="modal-dialog" role="document">
		<div class="modal-content">
			<div class="modal-header">
				<h5 id="modal-title-3" class="modal-title">Remove Language</h5>
				<button class="close" data-dismiss="modal" aria-label="<?= a($txt_close) ?>">
					<span aria-hidden="true">&times;</span>
				</button>
			</div>
			<div class="modal-body">
			</div>

			<div class="modal-footer">
				<button type="button" id="remove-lang-cancel" class="btn btn-light btn-sm" data-dismiss="modal"><?= $txt_cancel ?></button>
				<button type="button" id="remove-lang-confirm" class="btn btn-primary btn-sm"><?= $txt_confirm ?></button>
			</div>
		</div>
	</div>
</div>

<!-- admin footer -->
<?php require_once(__DIR__ . '/admin-footer.php') ?>

<!-- javascript -->
<script>
'use strict';

var do_reload = false;

/*--------------------------------------------------
Show strings
--------------------------------------------------*/
(function(){
	// select template change
	$('#select-template').on('change', function(e){
		$(this).closest('form').submit();
	});
}());

/*--------------------------------------------------
Create language
--------------------------------------------------*/
(function(){
	// on show modal
	$('#create-lang-modal').on('show.bs.modal', function (e) {
		// reset reload to false
		var do_reload = false;
	});

	// on hide modal
	$('#create-lang-modal').on('hide.bs.modal', function (e) {
		if(do_reload) location.reload(true);
	});

	// select lang change
	$('#select-lang').on('change', function(e){
		if($('#create-lang-submit').html() == '<?= $txt_done ?>') {
			$('#create-lang-submit').empty();
			$('#create-lang-submit').html('<?= $txt_create_lang ?>');
		}
	});

	// create lang submit
	$('#create-lang-submit').on('click', function(e){
		e.preventDefault();

		// show spinner
		$('#create-lang-submit').empty();
		$('#create-lang-submit').html('<i class="las la-circle-notch la-spin"></i> <?= $txt_installing ?>');

		// disable submit
		$('#create-lang-submit').prop('disabled', true);

		// lang selected
		var selected_lang = $('#select-lang').val();

		// vars
		var post_url = '<?= $baseurl ?>' + '/admin/process-create-lang.php';

		// post
		var request = $.post(post_url, { lang: selected_lang });

		// done create language
		request.done(function(data) {
			// reset submit button
			$('#create-lang-submit').html('<?= $txt_done ?>');
			$('#create-lang-submit').prop('disabled', false);

			// set reload to true
			do_reload = true;

			if(data == '1') {
				// remove installed language option
				$('#select-lang option[value="' + selected_lang + '"]').remove();
			}

			else {
				// show error
				$('#create-lang-error').html(data);
			}
		});
	});

	// select sql file on change
	$('#select-file').on('change', function(e){
		$('#install-lang-submit').html('<?= $txt_install_lang ?>');
	});

	// select sql file on click
	$('#select-file').on('click', function(e){
		// enable submit
		$('#install-lang-submit').prop('disabled', false);

		// change submit text
		$('#install-lang-submit').html('<?= $txt_install ?>');

		$('#install-lang-error').empty();
	});

	// on install language submit
	$('#install-lang-submit').on('click', function(e){
		e.preventDefault();

		// show spinner
		$('#install-lang-submit').html('<i class="las la-circle-notch la-spin"></i> <?= $txt_installing ?>');

		// disable submit
		$('#install-lang-submit').prop('disabled', true);

		// vars
		var post_url = '<?= $baseurl ?>' + '/admin/process-install-lang.php';

		// post
		var request = $.post(post_url, { file: $('#select-file').val() });

		// done
		request.done(function(data) {
			// reset submit button
			$('#install-lang-submit').html('<?= $txt_done ?>');

			// set reload to true
			do_reload = true;

			if(data == '1') {

			}

			else {
				// show error
				$('#install-lang-error').html(data);
			}
		});
	});
}());

/*--------------------------------------------------
Remove language
--------------------------------------------------*/
(function(){
	// on show modal
	$('#remove-lang-modal').on('show.bs.modal', function (e) {
		// reset reload to false
		var do_reload = false;

		// show default message
		$('#remove-lang-modal .modal-body').empty();
		$('#remove-lang-modal .modal-body').html('<?= a($txt_remove_language_sure) ?> <strong>[<?= $iso_639_1_native_names["$this_lang"] ?>]</strong>').fadeIn();
	});

	// on hide modal
	$('#remove-lang-modal').on('hide.bs.modal', function (e) {
		if(do_reload) location.reload(true);
	});

	// remove button in modal clicked
	$('#remove-lang-confirm').on('click', function(e){
		e.preventDefault();

		// vars
		var lang_code = '<?= $this_lang ?>';
		var post_url = '<?= $baseurl ?>' + '/admin/process-remove-lang.php';

		// post
		var request = $.post(post_url, { lang_code: lang_code });

		// done
		request.done(function(data) {
			// define response
			var response = data == '1' ? '<?= $txt_language_removed ?>' : data;

			// hide submit button
			$('#remove-lang-confirm').hide();

			// change cancel button to ok
			$('#remove-lang-cancel').empty().text('<?= $txt_ok ?>');

			// set reload to true
			do_reload = true;

			// show response
			$('#remove-lang-modal .modal-body').empty();
			$('#remove-lang-modal .modal-body').html(response).fadeIn();
		});
	});
}());

/*--------------------------------------------------
Create string
--------------------------------------------------*/
(function(){
	// cache selectors
	var btn_submit = $('#create-string-submit');

	// only reload if form is submitted
	var do_reload = false;

	// on hide modal
	$('#create-string-modal').on('hide.bs.modal', function (event) {
		if(do_reload) location.reload(true);
	});

	// create string form submit
	btn_submit.on('click', function(e){
		e.preventDefault();

		// check validity
		if($('#form-create-string')[0].checkValidity()) {
			// show submit spinner
			btn_submit.prepend('<?php include($cfg_loader_path) ?> ');
			btn_submit.prop('disabled', true);

			// if all required fields filled, process
			var post_url = '<?= $baseurl ?>' + '/admin/process-create-string.php';

			// post
			var request = $.post(post_url, { params: $('#form-create-string').serialize() });

			// done
			request.done(function(data) {
				// define response
				var response = data == '1' ? '<?= a($txt_string_created) ?>' : data;

				// hide submit button
				btn_submit.hide();

				// change cancel button to ok
				$('#create-string-cancel').empty().text('<?= $txt_ok ?>');

				// set reload to true
				do_reload = true;

				// show response
				$('#create-string-modal .modal-body').empty();
				$('#create-string-modal .modal-body').html(response).fadeIn();
			});
		}

		else {
			$('#form-create-string')[0].reportValidity();
		}
	});
}());
</script>
</body>
</html>