<?php
// prevent direct access
if(basename(__FILE__) == basename($_SERVER['SCRIPT_NAME'])) {
	http_response_code(401);
	die('Invalid access');
}
?><!DOCTYPE html>
<!--[if IE 9]><html class="lt-ie10" lang="<?= $html_lang ?>"> <![endif]-->
<html lang="<?= $html_lang ?>">
<head>
<title><?= $txt_html_title ?> - <?= $listing_title ?></title>
<link rel="canonical" href="<?= $canonical ?>">
<?php require_once(__DIR__ . '/../head.php') ?>
<?php require_once('user-head.php') ?>
</head>
<body class="tpl-user-edit-listing">
<?php require_once(__DIR__ . '/../header.php') ?>

<div class="container mt-5">
	<div class="row">
		<div class="col-md-4 col-lg-3 mb-5">
			<?php include_once('user-menu.php') ?>
		</div>

		<div class="col-md-8 col-lg-9">
			<h2 class="mb-5"><?= $txt_main_title ?> - <?= $listing_title ?></h2>

			<form method="post" id="edit-listing-form" action="<?= $baseurl ?>/user/process-edit-listing">
				<input type="hidden" id="submit_token" name="submit_token" value="<?= $submit_token ?>">
				<input type="hidden" name="csrf_token" value="<?= session_id() ?>">
				<input type="hidden" id="latlng" name="latlng" value="(<?= $lat ?>, <?= $lng ?>)">
				<input type="hidden" name="listing_id" value="<?= $listing_id ?>">

				<!-- Title -->
				<div class="form-group">
					<label for="listing_title"><?= $txt_title ?> (*)</label>
					<input type="text" id="listing_title" class="form-control" name="listing_title" value="<?= $listing_title ?>" required>
				</div>

				<!-- Category -->
				<div class="form-group">
					<label for="category_id"><?= $txt_primary_category ?> (*)</label>
					<select id="category_id" name="category_id" class="form-control select2">
						<option value=""><?= $txt_select_cat ?></option>
						<?php show_cat_dropdown(0, 0, $primary_cat, $conn) ?>
					</select>
					<input type="hidden" name="orig_cat_id" value="<?= $primary_cat ?>">
					<input type="hidden" name="orig_cat_slug" value="<?= $primary_slug ?>">
				</div>

				<div class="form-group">
					<label><?= $txt_additional_categories ?></label>

					<?php
					// show the category checkbox tree
					show_cats($cats_grouped_by_parent, 0, $checked_cats, 1);
					?>
				</div>

				<!-- Price -->
				<div class="form-group">
					<label for="listing-price"><?= $txt_price ?> (*)</label>
					<input type="text" id="listing-price" class="form-control" name="price" value="<?= $price ?>" required>
				</div>

				<!-- Main Pic -->
				<div class="form-group block" id="main-pic-row">
					<input type="file" id="main-pic" name="main_pic" style="display:block;visibility:hidden;width:0;height:0;">
					<input type="hidden" id="uploaded-main-pic" name="uploaded_main_pic" value="">

					<!-- this is the main pic that was uploaded during listing creation -->
					<input type="hidden" id="existing-main-pic" name="existing_main_pic" value="<?= $main_pic ?>">

					<label><?= $txt_main_pic ?></label>

					<div class="mb-3">
						<div id="main-pic-container">
							<img src="<?= $main_pic_url ?>" class="rounded" width="132">
						</div>
					</div>

					<div class="main-pic-controls mb-3">
						<button id="upload-main-pic-btn" class="btn btn-light btn-sm pointer">
							<i class="las la-upload"></i> <?= $txt_upload_main_pic ?>
						</button>

						<span id="delete-main-pic-btn" class="btn btn-light btn-sm pointer">
							<i class="las la-trash-alt"></i> <?= $txt_delete ?>
						</span>
					</div>
				</div>

				<!-- Item Description -->
				<div class="form-group">
					<label for="short_desc"><?= $txt_short_desc ?></label>
					<textarea id="short_desc" class="form-control" name="short_desc" rows="2"><?= $short_desc ?></textarea>
					<div class="float-right"><small id="count_message"></small></div>
				</div>

				<div class="form-group">
					<label for="description"><?= $txt_description ?></label>
					<textarea id="description" class="form-control" name="description" rows="10"><?= $description ?></textarea>
				</div>

				<?php
				if($cfg_location_info) {
					?>

					<!-- Location -->
					<div class="form-group">
						<label for="address"><?= $txt_address ?></label>
						<input type="text" id="address" class="form-control" name="address" value="<?= $address ?>">
					</div>

					<div class="form-group">
						<label for="postal_code"><?= $txt_postal_code ?></label>
						<input type="text" id="postal_code" class="form-control" name="postal_code" value="<?= $postal_code ?>">
					</div>

					<div class="form-group">
						<label for="city_id"><?= $txt_city ?></label>
						<select id="city_id" class="form-control" name="city_id">
							<option value="<?= $city_id ?>"><?= $city_name ?>, <?= $state_abbr ?></option>
							<?php
							if(!$cfg_use_select2) {
								$stmt = $conn->prepare("SELECT * FROM cities LIMIT $cfg_city_dropdown_limit");
								$stmt->execute();

								while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
									?>
									<option value="<?= $row['city_id'] ?>"><?= $row['city_name'] ?>, <?= $row['state'] ?></option>
									<?php
								}
							}
							?>
						</select>
					</div>

					<div class="form-group">
						<input type="text" id="city_id_hidden" class="form-control" name="city_id_hidden" style="height:0;padding:0;opacity:0" value="<?= $city_id ?>" required>
					</div>
					<?php
				}
				?>

				<?php
				if($cfg_show_map) {
					?>
					<p><?= $txt_click_map ?> (*)</p>

					<div id="map-wrapper" class="mb-3">
						<div id="map-canvas" style="width:100%; height:100%"></div>
					</div>
					<?php
				}
				?>

				<!-- Contact Info -->
				<label><?= $txt_phone ?></label>
				<div class="form-row mb-3">
					<div class="col-3">
						<select class="custom-select" name="country_code">
							<?php
							include(__DIR__ . '/../../inc/country-calling-codes.php');
							foreach($country_calling_codes as $k => $v) {
								?>
								<option value="<?= $v['value'] ?>" <?= $v['value'] == $country_code ? 'selected' : '' ?>><?= $v['name'] ?></option>
								<?php
							}
							?>
						</select>
					</div>
					<div class="col-2">
						<input type="text" id="area_code" class="form-control" name="area_code" value="<?= $area_code ?>">
					</div>

					<div class="col-7">
						<input type="tel" id="phone" class="form-control" name="phone" value="<?= $phone ?>">
					</div>
				</div>

				<?php
				if($cfg_whatsapp_info) {
					?>
					<label>Whatsapp</label>
					<div class="form-row mb-5">
						<div class="col-3">
							<select class="custom-select" name="wa_country_code">
								<?php
								include(__DIR__ . '/../../inc/country-calling-codes.php');
								foreach($country_calling_codes as $k => $v) {
									?>
									<option value="<?= $v['value'] ?>" <?= $v['value'] == $wa_country_code ? 'selected' : '' ?>><?= $v['name'] ?></option>
									<?php
								}
								?>
							</select>
						</div>
						<div class="col-2">
							<input type="text" id="wa_area_code" class="form-control" name="wa_area_code" value="<?= $wa_area_code ?>">
						</div>

						<div class="col-7">
							<input type="tel" id="wa_phone" class="form-control" name="wa_phone" value="<?= $wa_phone ?>">
						</div>
					</div>
					<?php
				}
				?>

				<!-- Custom Fields -->
				<?php require_once(__DIR__ . '/tpl-custom-fields.php') ?>

				<!-- Photos Upload -->
				<h3><?= $txt_photos ?></h3>

				<input type="file" id="item_img" name="item_img" style="display:block;visibility:hidden;width:0;height:0;" multiple>

				<div class="form-group">
					<button id="upload-button" class="btn btn-light btn-sm"><i class="las la-upload"></i> <?= $txt_upload_btn ?></button>
				</div>

				<div class="form-group">
					<div id="uploaded" class="d-flex flex-row flex-wrap">
						<!-- uploaded pics -->
						<?php
						foreach($listing_photos as $v) {
							?>
							<div class="thumbs mr-3">
								<img src="<?= $pic_baseurl ?>/<?= $listing_thumb_folder ?>/<?= $v['dir'] ?>/<?= $v['filename'] ?>" width="132" class="rounded">
								<div class="btn-light delete_existing_pic"><small><?= $txt_delete ?></small></div>
								<input type="hidden" name="existing_pics[]" value="<?= $v['filename'] ?>">
							</div>
							<?php
						}
						?>
					</div>
				</div>

				<div class="form-group mt-5">
					<button class="btn btn-primary"><?= $txt_save ?></button>
				</div>
			</form>
		</div>
	</div>
</div>

<!-- footer -->
<?php require_once(__DIR__ . '/../footer.php') ?>

</body>
</html>
