<?php
require_once(__DIR__ . '/../inc/config.php');
require_once(__DIR__ . '/_admin_inc.php');

/*--------------------------------------------------
Pagination
--------------------------------------------------*/
$page = !empty($_GET['page']) ? $_GET['page'] : 1;
$limit = $items_per_page;

if($page > 1) {
	$offset = ($page-1) * $limit + 1;
}

else {
	$offset = 1;
}

// sort order
$sort = '';
if(isset($_GET['sort'])) {
	$sort = in_array($_GET['sort'], array('date', 'date-desc', 'title', 'title-desc')) ? $_GET['sort'] :  'date-desc';
}

// page url
$page_url = "$baseurl/admin/listings-trash?sort=$sort&page=";

// init array
$listings_arr = array();

// get listings
$query = "SELECT COUNT(*) AS c FROM listings WHERE status = 'trashed'";
$stmt = $conn->prepare($query);
$stmt->execute();
$row = $stmt->fetch(PDO::FETCH_ASSOC);
$total_rows = $row['c'];

if($total_rows > 0) {
	$pager = new App\PageIterator($limit, $total_rows, $page);
	$start = $pager->getStartRow();

	// where
	$where = "WHERE p.status = 'trashed'";

	// order by
	$orderby = "p.listing_id DESC";

	if($sort == 'date') {
		$orderby = "p.listing_id";
	}

	if($sort == 'title') {
		$orderby = "p.listing_title";
	}

	if($sort == 'title-desc') {
		$orderby = "p.listing_title DESC";
	}

	// the query
	$query = "SELECT
			p.listing_id, p.listing_title, p.submission_date, p.feat_home, p.status, p.paid, p.userid, p.slug AS listing_slug, p.main_pic,
			c.city_name, c.slug, c.state,
			s.state_name, s.slug AS state_slug,
			rel.cat_id,
			cats.id AS cat_id, cats.name AS cat_name, cats.cat_slug,
			u.email,
			plans.plan_name
		FROM listings p
			LEFT JOIN cities c ON p.city_id = c.city_id
			LEFT JOIN states s ON c.state_id = s.state_id
			LEFT JOIN rel_listing_cat rel ON rel.listing_id = p.listing_id AND rel.is_main = 1
			LEFT JOIN cats ON rel.cat_id = cats.id
			LEFT JOIN users u ON u.id = p.userid
			LEFT JOIN plans ON plans.plan_id = p.plan
		$where
		GROUP BY p.listing_id
		ORDER BY $orderby LIMIT :start, :limit";

	$stmt = $conn->prepare($query);
	$stmt->bindValue(':start', $start);
	$stmt->bindValue(':limit', $limit);
	$stmt->execute();

	while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
		$this_cat_id          = !empty($row['cat_id'         ]) ? $row['cat_id'         ] : '';
		$this_cat_name        = !empty($row['cat_name'       ]) ? $row['cat_name'       ] : '';
		$this_cat_slug        = !empty($row['cat_slug'       ]) ? $row['cat_slug'       ] : $this_cat_id;
		$this_city_name       = !empty($row['city_name'      ]) ? $row['city_name'      ] : '';
		$this_city_slug       = !empty($row['slug'           ]) ? $row['slug'           ] : '';
		$this_feat_home       = !empty($row['feat_home'      ]) ? $row['feat_home'      ] : '';
		$this_listing_email   = !empty($row['email'          ]) ? $row['email'          ] : '';
		$this_listing_id      = !empty($row['listing_id'     ]) ? $row['listing_id'     ] : '';
		$this_listing_slug    = !empty($row['listing_slug'   ]) ? $row['listing_slug'   ] : $this_listing_id;
		$this_listing_title   = !empty($row['listing_title'  ]) ? $row['listing_title'  ] : '';
		$this_main_pic        = !empty($row['main_pic'       ]) ? $row['main_pic'       ] : '';
		$this_paid            = !empty($row['paid'           ]) ? $row['paid'           ] : '';
		$this_plan_name       = !empty($row['plan_name'      ]) ? $row['plan_name'      ] : '';
		$this_state_abbr      = !empty($row['state'          ]) ? $row['state'          ] : '';
		$this_state_slug      = !empty($row['state_slug'     ]) ? $row['state_slug'     ] : '';
		$this_status          = !empty($row['status'         ]) ? $row['status'         ] : '';
		$this_submission_date = !empty($row['submission_date']) ? $row['submission_date'] : '';
		$this_listing_owner   = !empty($row['userid'         ]) ? $row['userid'         ] : '';

		// sanitize
		$this_listing_title = e($this_listing_title);
		$this_listing_email = e($this_listing_email);
		$this_listing_slug  = e($this_listing_slug);

		// simplify date
		$this_submission_date = strtotime($this_submission_date);
		$this_date_formatted  = date($cfg_date_format, $this_submission_date );

		// link to each listing
		$this_listing_link = get_listing_link(
							$this_listing_id,
							$this_listing_slug,
							$this_cat_id,
							$this_cat_slug,
							'',
							$this_city_slug,
							$this_state_slug,
							$cfg_permalink_struct);

		// main pic url
		$this_main_pic_url = $baseurl . '/assets/imgs/blank.png';

		if(!empty($this_main_pic)) {
			if(is_file($pic_basepath . '/main-pic/' . substr($this_main_pic, 0, 2) . '/' . $this_main_pic)) {
				$this_main_pic_url = $pic_baseurl . '/main-pic/' . substr($this_main_pic, 0, 2) . '/' . $this_main_pic;
			}
		}

		$cur_loop_arr = array(
			'cat_id'         => $this_cat_id,
			'cat_name'       => $this_cat_name,
			'cat_slug'       => $this_cat_slug,
			'city_name'      => $this_city_name,
			'city_slug'      => $this_city_slug,
			'date_formatted' => $this_date_formatted,
			'feat_home'      => $this_feat_home,
			'listing_id'     => $this_listing_id,
			'listing_link'   => $this_listing_link,
			'listing_slug'   => $this_listing_slug,
			'listing_title'  => $this_listing_title,
			'main_pic_url'   => $this_main_pic_url,
			'paid'           => $this_paid,
			'plan_name'      => $this_plan_name,
			'state_abbr'     => $this_state_abbr,
			'status'         => $this_status,
			'user_email'     => $this_listing_email,
		);

		$listings_arr[] = $cur_loop_arr;
	}
}
