<?php
require_once(__DIR__ . '/inc/config.php');

// check csrf token
require_once(__DIR__ . '/_inc_request_with_ajax.php');

// error codes
/*
1 - $txt_message_sent
2 - $txt_please_wait (submitting messages in less than $cgf_min_secs time
3 - missing required fields
4 - swiftmailer error
5 - $txt_invalid_email invalid email
6 - invalid $from_page
*/

// sender ip
$sender_ip = get_ip();

// if sender ip already submitted less than 30 secs ago, return
$query = "SELECT TIMESTAMPDIFF(SECOND, created, NOW()) AS secs_ago FROM contact_msgs WHERE sender_ip = :sender_ip ORDER BY created DESC LIMIT 1";
$stmt  = $conn->prepare($query);
$stmt->bindValue(':sender_ip', $sender_ip);
$stmt->execute();
$row = $stmt->fetch(PDO::FETCH_ASSOC);
$secs_ago = !empty($row['secs_ago']) ? $row['secs_ago'] : $cgf_min_secs + 1;

if($secs_ago < $cgf_min_secs) {
	echo '2';
	return;
}

// define smtp transport
$transport_smtp = (new Swift_SmtpTransport($smtp_server, $smtp_port, $cfg_smtp_encryption))
  ->setUsername($smtp_user)
  ->setPassword($smtp_pass);

// define mailer obj
$mailer = new Swift_Mailer($transport_smtp);

// get post data
$params = array();
parse_str($_POST['params'], $params);

// posted vars
$from_page    = !empty($params['from_page'   ]) ? $params['from_page'   ] : 'listing';
$listing_id   = !empty($params['listing_id'  ]) ? $params['listing_id'  ] : '';
$listing_url  = !empty($params['listing_url' ]) ? $params['listing_url' ] : '';
$recipient_id = !empty($params['recipient_id']) ? $params['recipient_id'] : '';
$sender_email = !empty($params['sender_email']) ? $params['sender_email'] : '';
$sender_name  = !empty($params['sender_name' ]) ? $params['sender_name' ] : '';
$sender_msg   = !empty($params['sender_msg'  ]) ? $params['sender_msg'  ] : '';

// if from listing page
if($from_page == 'listing') {
	// check vars
	if(empty($listing_id) || empty($sender_email)) {
		echo '3';
		return;
	}

	// append listing url
	$sender_msg .= "\n\n" . $listing_url;

	// get subject
	$query = "SELECT * FROM config WHERE property = 'cfg_contact_seller_subject'";
	$stmt  = $conn->prepare($query);
	$stmt->execute();
	$row = $stmt->fetch(PDO::FETCH_ASSOC);
	$contact_seller_subject = !empty($row['value']) ? $row['value'] : 'A message from ' . $site_name;

	// get listing owner email
	$query = "SELECT
				u.email
				FROM listings p
				LEFT JOIN users u ON p.userid = u.id
				WHERE p.listing_id = :listing_id";
	$stmt  = $conn->prepare($query);
	$stmt->bindValue(':listing_id', $listing_id);
	$stmt->execute();
	$row = $stmt->fetch(PDO::FETCH_ASSOC);
	$listing_owner_email = !empty($row['email']) ?  $row['email'] : '';

	// send message
	if(filter_var($sender_email, FILTER_VALIDATE_EMAIL) && filter_var($listing_owner_email, FILTER_VALIDATE_EMAIL)) {
		$message = (new Swift_Message())
			->setSubject($contact_seller_subject)
			->setFrom(array($admin_email => $site_name))
			->setTo($listing_owner_email)
			->setBody($sender_msg)
			->setReplyTo($sender_email)
			->setReturnPath($admin_email)
			;

		// Send the message
		if($mailer->send($message)) {
			// write to db
			$query = "INSERT INTO contact_msgs(
						sender_email,
						sender_ip,
						listing_id,
						msg)
				VALUES(
						:sender_email,
						:sender_ip,
						:listing_id,
						:msg)";

			$stmt = $conn->prepare($query);
			$stmt->bindValue(':sender_email', $sender_email);
			$stmt->bindValue(':sender_ip',    $sender_ip);
			$stmt->bindValue(':listing_id',   $listing_id);
			$stmt->bindValue(':msg',          $sender_msg);
			$stmt->execute();

			echo '1';
		}

		else {
			echo '4';
		}
	}

	else {
		echo '5';
	}
}

// if from profile page
else if($from_page == 'profile') {
	// check vars
	if(empty($recipient_id) || empty($sender_email) || empty($sender_msg)) {
		echo '3';
		return;
	}

	// get plugin settings from db
	$query = "SELECT * FROM config WHERE property = 'cfg_contact_user_subject'";
	$stmt  = $conn->prepare($query);
	$stmt->execute();
	$row = $stmt->fetch(PDO::FETCH_ASSOC);
	$contact_user_subject = !empty($row['value']) ? $row['value'] : '';

	// get user email
	$query = "SELECT email FROM users
				WHERE id = :recipient_id";
	$stmt  = $conn->prepare($query);
	$stmt->bindValue(':recipient_id', $recipient_id);
	$stmt->execute();
	$row = $stmt->fetch(PDO::FETCH_ASSOC);
	$recipient_email = $row['email'];

	// send message
	if(filter_var($sender_email, FILTER_VALIDATE_EMAIL) && filter_var($recipient_email, FILTER_VALIDATE_EMAIL)) {
		$message = (new Swift_Message())
			->setSubject($contact_user_subject)
			->setFrom(array($sender_email => $site_name))
			->setTo($recipient_email)
			->setBody($sender_msg)
			->setReplyTo($sender_email)
			->setReturnPath($admin_email)
			;

		// Send the message
		if($mailer->send($message)) {
			// write to db
			$query = "INSERT INTO contact_msgs(
						sender_email,
						sender_ip,
						recipient_id,
						msg)
				VALUES(
						:sender_email,
						:sender_ip,
						:recipient_id,
						:msg)";

			$stmt = $conn->prepare($query);
			$stmt->bindValue(':sender_email', $sender_email);
			$stmt->bindValue(':sender_ip'   , $sender_ip);
			$stmt->bindValue(':recipient_id', $recipient_id);
			$stmt->bindValue(':msg'         , $sender_msg);
			$stmt->execute();

			echo '1';
		}

		else {
			echo '4';
		}
	}

	else {
		echo '5';
	}
}

else {
	echo '6';
}