<?php
require_once(__DIR__ . '/../inc/config.php');

// csrf check
require_once(__DIR__ . '/_user_inc_request_with_ajax.php');

// error codes
/*
1 - register success
2 - user exists
3 - insert error
4 - invalid email
5 - empty fields
*/

// define smtp transport
$transport_smtp = (new Swift_SmtpTransport($smtp_server, $smtp_port, $cfg_smtp_encryption))
  ->setUsername($smtp_user)
  ->setPassword($smtp_pass);

// define mailer obj
$mailer = new Swift_Mailer($transport_smtp);

// get post data
$params = array();
parse_str($_POST['params'], $params);

// posted vars
$fname    = !empty($params['fname'   ]) ? $params['fname'   ] : '';
$lname    = !empty($params['lname'   ]) ? $params['lname'   ] : '';
$email    = !empty($params['email'   ]) ? $params['email'   ] : '';
$password = !empty($params['password']) ? $params['password'] : '';

// validate email
if(!filter_var($email, FILTER_VALIDATE_EMAIL)){
	echo '4';
	die();
}

// check empty fields
if(empty($fname) || empty($email) || empty($password)){
	echo '5';
	die();
}

// honeypot
if(!empty($_REQUEST['password2']) && (bool)$_REQUEST['password2'] == TRUE) {
	die();
}

// if all fields submitted
if(!empty($fname) && !empty($email) && !empty($password)) {
	$empty_fields = 0;

	// user ip
	$ip = get_ip();

	// check to see if email already exists
	$stmt = $conn->prepare("SELECT COUNT(*) FROM users WHERE email = :email");
	$stmt->bindValue(':email', $email);
	$stmt->execute();
	$count = $stmt->fetchColumn();

	// user exists?
	if($count > 0) {
		// 2 - user already exists
		echo '2';
		die();
	}

	// else user doesn't exist, so create entry in db
	else {
		// hash
		$password_hashed = password_hash($password, PASSWORD_BCRYPT);

		// insert into db
		$stmt = $conn->prepare('
		INSERT INTO users(
			first_name,
			last_name,
			email,
			password,
			created,
			hybridauth_provider_name,
			ip_addr,
			status
			)
		VALUES(
			:first_name,
			:last_name,
			:email,
			:password,
			NOW(),
			:hybridauth_provider_name,
			:ip,
			:status
			)
		');

		$stmt->bindValue(':first_name'              , $fname);
		$stmt->bindValue(':last_name'               , $lname);
		$stmt->bindValue(':email'                   , $email);
		$stmt->bindValue(':password'                , $password_hashed);
		$stmt->bindValue(':hybridauth_provider_name', 'local');
		$stmt->bindValue(':ip'                      , $ip);
		$stmt->bindValue(':status'                  , 'pending');

		// if query executed fine
		if($stmt->execute()) {
			$confirm_str = generatePassword(16);
			$user_id = $conn->lastInsertId();

			// insert confirmation string into db
			$stmt2 = $conn->prepare('
			INSERT INTO signup_confirm(
				user_id,
				confirm_str,
				created
				)
			VALUES(
				:user_id,
				:confirm_str,
				NOW()
				)
			');

			$stmt2->bindValue(':user_id'    , $user_id);
			$stmt2->bindValue(':confirm_str', $confirm_str);

			// if insert into signup confirm table executed...
			if($stmt2->execute()) {
				// email user
				$query = "SELECT * FROM email_templates WHERE type = 'signup_confirm'";
				$stmt = $conn->prepare($query);
				$stmt->execute();
				$row = $stmt->fetch(PDO::FETCH_ASSOC);
				$email_subject = $row['subject'];
				$email_body    = $row['body'];

				$confirm_link = $baseurl . "/user/register-confirm/" . $user_id . "," . $confirm_str;
				$email_body = str_replace('%confirm_link%', $confirm_link, $email_body);

				// string replacements
				$email_subject = str_replace('%site_name%', $site_name, $email_subject);
				$email_subject = str_replace('%site_url%', $baseurl, $email_subject);
				$email_body = str_replace('%site_name%', $site_name, $email_body);
				$email_body = str_replace('%site_url%', $baseurl, $email_body);
				$email_body = str_replace('%confirm_link%', $confirm_link, $email_body);

				$message = (new Swift_Message())
					->setSubject($email_subject)
					->setFrom(array($admin_email => $site_name))
					->setTo($email)
					->setBody($email_body)
					->setReplyTo($admin_email)
					->setReturnPath($admin_email)
					;

				// Send the message
				try {
					$mailer->send($message);

					// 1 - register success
					echo '1';
				}

				catch(exception $e) {
					echo $e->getMessage();
				}
			}

			// send email to admin
			if($user_created_notify) {
				$query = "SELECT * FROM email_templates WHERE type = 'user_signup'";
				$stmt = $conn->prepare($query);
				$stmt->execute();
				$row = $stmt->fetch(PDO::FETCH_ASSOC);
				$email_subject = !empty($row['subject']) ? $row['subject'] : '';
				$email_body    = !empty($row['body'   ]) ? $row['body'   ] : '';

				// string replacements
				$email_body = str_replace('%signup_email%', $email, $email_body);

				$message = (new Swift_Message())
					->setSubject($email_subject)
					->setFrom(array($admin_email => $site_name))
					->setTo($admin_email)
					->setBody($email_body)
					->setReplyTo($admin_email)
					->setReturnPath($admin_email)
					;

				try {
					$mailer->send($message);
				}

				catch(exception $e) {
					echo $e->getMessage();
				}
			}
		}

		else {
			// 3 - insert error
			echo '3';
		}
	}
}
