<?php
require_once(__DIR__ . '/../inc/config.php');

// csrf check
require_once(__DIR__ . '/_user_inc_request_with_ajax.php');

// define smtp transport
$transport_smtp = (new Swift_SmtpTransport($smtp_server, $smtp_port, $cfg_smtp_encryption))
  ->setUsername($smtp_user)
  ->setPassword($smtp_pass);

// define mailer obj
$mailer = new Swift_Mailer($transport_smtp);

// post vars
$email = !empty($_POST['email']) ? $_POST['email'] : '';

// validate email
if(!filter_var($email, FILTER_VALIDATE_EMAIL)){
	echo 'invalid_email';
	die();
}

// user ip
$ip = get_ip();

// check if exists
$stmt = $conn->prepare("SELECT COUNT(*) FROM users WHERE email = :email");
$stmt->bindValue(':email', $email);
$stmt->execute();
$count = $stmt->fetchColumn();

// user exists?
if($count > 0) {
	// get user id
	$stmt = $conn->prepare("SELECT id FROM users WHERE email = :email");
	$stmt->bindValue(':email', $email);
	$stmt->execute();
	$row = $stmt->fetch(PDO::FETCH_ASSOC);
	$user_id = $row['id'];

	// get confirmation string
	$stmt = $conn->prepare("SELECT confirm_str FROM signup_confirm WHERE user_id = :user_id");
	$stmt->bindValue(':user_id', $user_id);
	$stmt->execute();
	$row = $stmt->fetch(PDO::FETCH_ASSOC);
	$confirm_str = $row['confirm_str'];

	if(empty($confirm_str)) {
		$confirm_str = generatePassword(16);

		// insert confirmation string into db
		$stmt = $conn->prepare('
		INSERT INTO signup_confirm(
			user_id,
			confirm_str,
			created
			)
		VALUES(
			:user_id,
			:confirm_str,
			NOW()
			)
		');

		$stmt->bindValue(':user_id'    , $user_id);
		$stmt->bindValue(':confirm_str', $confirm_str);
		$stmt->execute();
	}

	$confirm_link = $baseurl . "/user/register-confirm/" . $user_id . "," . $confirm_str;

	// email user
	$query = "SELECT * FROM email_templates WHERE type = 'signup_confirm'";
	$stmt = $conn->prepare($query);
	$stmt->execute();
	$row = $stmt->fetch(PDO::FETCH_ASSOC);
	$email_subject = $row['subject'];
	$email_body    = $row['body'];

	// string replacements
	$email_subject = str_replace('%site_name%', $site_name, $email_subject);
	$email_subject = str_replace('%site_url%', $baseurl, $email_subject);
	$email_body = str_replace('%site_name%', $site_name, $email_body);
	$email_body = str_replace('%site_url%', $baseurl, $email_body);
	$email_body = str_replace('%confirm_link%', $confirm_link, $email_body);

	$message = (new Swift_Message())
		->setSubject($email_subject)
		->setFrom(array($admin_email => $site_name))
		->setTo($email)
		->setBody($email_body)
		->setReplyTo($admin_email)
		->setReturnPath($admin_email)
		;

	// Send the message
	try {
		$mailer->send($message);
		echo 'request_sent';
	}

	catch(exception $e) {
		$exception = utf8_encode ($e->getMessage());
		echo 'mailer_problem';
	}
}