<?php
require_once(__DIR__ . '/../inc/config.php');
require_once(__DIR__ . '/user_area_inc.php');

/*
This file is requested by the js-create-listing.php and js-edit-listing.php files when the category is changed
*/
$cat_ids    = !empty($_POST['cat_id'    ]) ? $_POST['cat_id'    ] : '';
$listing_id = !empty($_POST['listing_id']) ? $_POST['listing_id'] : '';
$from       = !empty($_POST['from'      ]) ? $_POST['from'      ] : '';

$custom_fields_ids = array();

if(!is_array($cat_ids)) {
	$arr = array($cat_ids);
	$cat_ids = $arr;
}

if(empty($cat_ids)) {
	return;
}

// build string for IN statement in mysql, since it's not possible to use parameters with IN statement
$in = '';

foreach($cat_ids as $v) {
	if(is_numeric($v)) {
		$in .= "$v,";
	}
}

$in = rtrim($in, ',');

/*--------------------------------------------------
Global fields
--------------------------------------------------*/

// init
$custom_fields_ids = array();

// find global fields and get just the ids
$query = "SELECT f.*
			FROM custom_fields f
			LEFT JOIN rel_cat_custom_fields r
				ON f.field_id = r.field_id
			WHERE r.rel_id IS NULL AND field_status = 1
			GROUP BY f.field_id
			ORDER BY f.field_order";

$stmt = $conn->prepare($query);
$stmt->execute();

while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
	$field_id = !empty($row['field_id']) ? $row['field_id'] : 0;
	$custom_fields_ids[] = $field_id;
}

/*--------------------------------------------------
Category fields
--------------------------------------------------*/

// init
$custom_fields = array();

// listing id and field values if called from the edit listing form
// query
if(!empty($in)) {
	$query = "SELECT f.*,
		tr.field_name AS tr_field_name, tr.tooltip AS tr_tooltip, tr.values_list AS tr_values_list
		FROM rel_cat_custom_fields r
		LEFT JOIN custom_fields f ON r.field_id = f.field_id
		LEFT JOIN translation_cf tr ON f.field_id = tr.field_id AND tr.lang = :html_lang
		WHERE r.cat_id IN($in) AND field_status = 1
		ORDER BY f.field_order";

	if(!empty($listing_id)) {
		$query = "SELECT f.*,
			rpcf.field_value,
			tr.field_name AS tr_field_name, tr.tooltip AS tr_tooltip, tr.values_list AS tr_values_list
			FROM rel_cat_custom_fields r
			LEFT JOIN custom_fields f ON r.field_id = f.field_id
			LEFT JOIN rel_listing_custom_fields rpcf ON rpcf.field_id = f.field_id AND rpcf.listing_id = :listing_id
			LEFT JOIN translation_cf tr ON f.field_id = tr.field_id AND tr.lang = :html_lang
			WHERE r.cat_id IN($in) AND field_status = 1
			GROUP BY f.field_id
			ORDER BY f.field_order";
	}

	$stmt = $conn->prepare($query);
	$stmt->bindValue(':html_lang', $html_lang);
	if(!empty($listing_id)) {
		$stmt->bindValue(':listing_id', $listing_id);
	}
	$stmt->execute();

	while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
		$this_field_id    = !empty($row['field_id'   ]) ? $row['field_id'   ] : '';
		$this_field_name  = !empty($row['field_name' ]) ? $row['field_name' ] : '';
		$this_field_type  = !empty($row['field_type' ]) ? $row['field_type' ] : '';
		$this_values_list = !empty($row['values_list']) ? $row['values_list'] : '';
		$this_value_unit  = !empty($row['value_unit' ]) ? $row['value_unit' ] : '';
		$this_tooltip     = !empty($row['tooltip'    ]) ? $row['tooltip'    ] : '';
		$this_icon        = !empty($row['icon'       ]) ? $row['icon'       ] : '';
		$this_required    = !empty($row['required'   ]) ? 'required'          : '';
		$this_searchable  = !empty($row['searchable' ]) ? $row['searchable' ] : 0;
		$this_field_order = !empty($row['field_order']) ? $row['field_order'] : 0;
		$this_field_value = !empty($row['field_value']) ? $row['field_value'] : '';

		// field translation values
		$this_tr_field_name  = !empty($row['tr_field_name' ]) ? $row['tr_field_name' ] : $this_field_name;
		$this_tr_tooltip     = !empty($row['tr_tooltip'    ]) ? $row['tr_tooltip'    ] : $this_tooltip;
		$this_tr_values_list = !empty($row['tr_values_list']) ? $row['tr_values_list'] : $this_values_list;

		// add to category custom fields array
		// make sure to sanitize field value in the template
		$custom_fields[$this_field_id] = array(
			'field_id'       => $this_field_id,
			'field_name'     => $this_field_name,
			'tr_field_name'  => $this_tr_field_name,
			'field_type'     => $this_field_type,
			'values_list'    => $this_values_list,
			'value_unit'     => $this_value_unit,
			'tr_values_list' => $this_tr_values_list,
			'tooltip'        => $this_tooltip,
			'tr_tooltip'     => $this_tr_tooltip,
			'icon'           => $this_icon,
			'required'       => $this_required,
			'searchable'     => $this_searchable,
			'field_order'    => $this_field_order,
			'field_value'    => $this_field_value,
		);

		$custom_fields_ids[] = $this_field_id;
	}
}

// fields ids hidden field
if(!empty($custom_fields_ids)) {
	$custom_fields_ids = implode(',', $custom_fields_ids);
}

else {
	$custom_fields_ids = '';
}
?>
<input type="hidden" name="custom_fields_ids" id="custom_fields_ids" value="<?= $custom_fields_ids ?>">

<div id="cat-fields">
	<?php
	foreach($custom_fields as $v) {
		// build tooltip
		if(!empty($v['tr_tooltip'])) {
			$v['tr_tooltip'] = '<a class="the-tooltip" data-toggle="tooltip" data-placement="top" title="' . $v['tr_tooltip'] . '"><i class="far fa-question-circle"></i></a>';
		}

		// explode values
		$values_arr = array();

		if($v['field_type'] == 'radio' || $v['field_type'] == 'select' || $v['field_type'] == 'checkbox') {
			$values_arr = explode(';', $v['values_list']);
			$tr_values_arr = explode(';', $v['tr_values_list']);

			foreach($values_arr as $k2 => $v2) {
				if(empty($tr_values_arr[$k2])) {
					$tr_values_arr[$k2] = $values_arr[$k2];
				}
			}
		}

		if($v['field_type'] == 'radio') {
			?>
			<div class="form-group">
				<div><label><?= $v['tr_field_name'] ?> <?= $v['tr_tooltip'] ?></label></div>

				<?php
				$i = 1;
				foreach($values_arr as $k2 => $v2) {
					$checked = '';

					if($v['field_value'] == $v2) {
						$checked = 'checked';
					}

					$v2 = e(trim($v2));
					?>
					<div class="form-check form-check-inline">
						<input type="radio" id="field_<?= $v['field_id'] ?>_<?= $i ?>" class="form-check-input" name="field_<?= $v['field_id'] ?>" value="<?= $v2 ?>" <?= $v['required'] ?> <?= $checked ?>>
						<label for="field_<?= $v['field_id'] ?>_<?= $i ?>" class="font-weight-normal"><?= e($tr_values_arr[$k2]) ?> <?= $v['value_unit'] ?></label>
					</div>
					<?php
					$i++;
				}
				?>
			</div>
			<?php
		}

		if($v['field_type'] == 'select') {
			?>
			<div class="form-group">
				<div><label for="field_<?= $v['field_id'] ?>"><?= $v['tr_field_name'] ?> <?= $v['tr_tooltip'] ?></label></div>
				<select id="field_<?= $v['field_id'] ?>" class="form-control" name="field_<?= $v['field_id'] ?>" <?= $v['required'] ?>>
				<?php
				foreach($values_arr as $k2 => $v2) {
					$selected = '';

					if($v['field_value'] == $v2) {
						$selected = 'selected';
					}

					$v2 = e(trim($v2));
					?>
					<option value="<?= $v2 ?>" <?= $selected ?>><?= isset($tr_values_arr[$k2]) ? e($tr_values_arr[$k2]) : $v2 ?> <?= $v['value_unit'] ?></option>
					<?php
				}
				?>
				</select>
			</div>
			<?php
		}

		if($v['field_type'] == 'checkbox') {
			?>
			<div class="form-group">
				<div><label><?= $v['tr_field_name'] ?> <?= $v['tr_tooltip'] ?></label></div>

				<?php
				$i = 1;
				foreach($values_arr as $k2 => $v2) {
					$checked = '';

					if($v['field_value'] == $v2) {
						$checked = 'checked';
					}

					$v2 = e(trim($v2));
					?>
					<div class="form-check form-check-inline">
						<input type="checkbox" id="field_<?= $v['field_id'] ?>_<?= $i ?>" class="form-check-input" name="field_<?= $v['field_id'] ?>[]" value="<?= $v2 ?>" <?= $v['required'] ?> <?= $checked ?>>
						<label for="field_<?= $v['field_id'] ?>_<?= $i ?>" class="font-weight-normal"><?= e($tr_values_arr[$k2]) ?> <?= $v['value_unit'] ?></label>
					</div>
					<?php
					$i++;
				}
				?>
			</div>
			<?php
		}

		if($v['field_type'] == 'text') {
			?>
			<div class="form-group">
				<div><label for="field_<?= $v['field_id'] ?>"><?= $v['tr_field_name'] ?> <?= $v['value_unit'] ?> <?= $v['tr_tooltip'] ?></label></div>
				<input type="text" id="field_<?= $v['field_id'] ?>" class="form-control" name="field_<?= $v['field_id'] ?>" <?= $v['required'] ?> value="<?= e($v['field_value']) ?>">
			</div>
			<?php
		}

		if($v['field_type'] == 'multiline') {
			?>
			<div class="form-group">
				<div><label for="field_<?= $v['field_id'] ?>"><?= $v['tr_field_name'] ?> <?= $v['value_unit'] ?> <?= $v['tr_tooltip'] ?></label></div>
				<textarea id="field_<?= $v['field_id'] ?>" class="form-control" name="field_<?= $v['field_id'] ?>" <?= $v['required'] ?>><?= e($v['field_value']) ?></textarea>
			</div>
			<?php
		}

		if($v['field_type'] == 'url') {
			?>
			<div class="form-group">
				<div><label for="field_<?= $v['field_id'] ?>"><?= $v['tr_field_name'] ?> <?= $v['value_unit'] ?> <?= $v['tr_tooltip'] ?></label></div>
				<input type="text" id="field_<?= $v['field_id'] ?>" class="form-control" name="field_<?= $v['field_id'] ?>" <?= $v['required'] ?> value="<?= e($v['field_value']) ?>">
			</div>
			<?php
		}

		if($v['field_type'] == 'number') {
			?>
			<div class="form-group">
				<div><label for="field_<?= $v['field_id'] ?>"><?= $v['tr_field_name'] ?> <?= $v['value_unit'] ?> <?= $v['tr_tooltip'] ?></label></div>
				<input type="number" id="field_<?= $v['field_id'] ?>" class="form-control" name="field_<?= $v['field_id'] ?>" <?= $v['required'] ?> value="<?= e($v['field_value']) ?>">
			</div>
			<?php
		}
	}
	?>
</div>

<script>
(function(){
	$('[data-toggle="tooltip"]').tooltip()
}());
</script>