<?php
require_once(__DIR__ . '/inc/config.php');

// coupons enabled check
if(!$cfg_enable_coupons) {
	http_response_code(404);
	include($install_dir . '/templates/404.php');
	die();
}

// validate url
if(!ctype_digit($route[1])) {
	http_response_code(404);
	include($install_dir . '/templates/404.php');
	die();
}

// coupon id
$coupon_id = $route[1];

// get coupon details
$query = "SELECT *, IF(CURDATE() < expire, 'valid', 'expired') AS valid FROM coupons WHERE id = :coupon_id AND coupon_status > 0";
$stmt = $conn->prepare($query);
$stmt->bindValue(':coupon_id', $coupon_id);
$stmt->execute();
$row = $stmt->fetch(PDO::FETCH_ASSOC);

if(empty($row)) {
	http_response_code(404);
	include($install_dir . '/templates/404.php');
	die();
}

$coupon_title       = !empty($row['title'      ]) ? $row['title'      ] : '';
$coupon_description = !empty($row['description']) ? $row['description'] : '';
$coupon_listing_id  = !empty($row['listing_id' ]) ? $row['listing_id' ] : '';
$coupon_expire      = !empty($row['expire'     ]) ? $row['expire'     ] : '';
$coupon_img         = !empty($row['img'        ]) ? $row['img'        ] : '';
$coupon_valid       = !empty($row['valid'      ]) ? $row['valid'      ] : 'expired';

// sanitize
$coupon_title       = e($coupon_title      );
$coupon_description = e($coupon_description);
$coupon_listing_id  = e($coupon_listing_id );
$coupon_expire      = e($coupon_expire     );
$coupon_img         = e($coupon_img        );
$coupon_valid       = e($coupon_valid      );

// format expire data
$coupon_expire = new DateTime($coupon_expire);
$coupon_expire = $coupon_expire->format("Y-m-d");

// coupon image
$coupon_img_url = $baseurl . '/assets/imgs/blank.png';

if(!empty($coupon_img)) {
	$coupon_folder = substr($coupon_img, 0, 2);
	$coupon_img_url = $baseurl . '/pictures/coupons/' . $coupon_folder . '/' . $coupon_img;
}

// get city details to build listing link
$query = "SELECT  p.slug AS listing_slug, p.listing_title, p.listing_id, p.status, p.paid,
			c.slug AS city_slug,
			s.slug AS state_slug,
			cats.cat_slug, cats.id AS cat_id
			FROM listings p
			LEFT JOIN cities c ON p.city_id = c.city_id
			LEFT JOIN states s ON c.state_id = s.state_id
			LEFT JOIN rel_listing_cat r ON r.listing_id = p.listing_id AND r.is_main = 1
			LEFT JOIN cats ON cats.id = r.cat_id
			WHERE p.listing_id = :listing_id";
$stmt = $conn->prepare($query);
$stmt->bindValue(':listing_id', $coupon_listing_id);
$stmt->execute();
$row = $stmt->fetch(PDO::FETCH_ASSOC);

$city_slug      = !empty($row['city_slug'    ]) ? $row['city_slug'    ] : 'location';
$state_slug     = !empty($row['state_slug'   ]) ? $row['state_slug'   ] : '';
$cat_id         = !empty($row['cat_id'       ]) ? $row['cat_id'       ] : '';
$cat_slug       = !empty($row['cat_slug'     ]) ? $row['cat_slug'     ] : $cat_id;
$listing_id     = !empty($row['listing_id'   ]) ? $row['listing_id'   ] : '';
$listing_slug   = !empty($row['listing_slug' ]) ? $row['listing_slug' ] : $listing_id;
$listing_title  = !empty($row['listing_title']) ? $row['listing_title'] : $listing_id;
$listing_status = !empty($row['status'       ]) ? $row['status'       ] : '';
$listing_paid   = !empty($row['paid'         ]) ? $row['paid'         ] : '';

if(!empty($listing_id) && $listing_paid == 1 && $listing_status == 'approved') {
	$listing_link = get_listing_link($listing_id, $listing_slug, $cat_id, $cat_slug, '', $city_slug, $state_slug, $cfg_permalink_struct);
}

else {
	$listing_link = '';
}

/*--------------------------------------------------
canonical
--------------------------------------------------*/
$canonical = $baseurl . '/coupon/' . $coupon_id;
