<?php
require_once(__DIR__ . '/inc/config.php');
require_once(__DIR__ . '/inc/img-exts.php');

// check if user has city saved in cookie
if(!empty($_COOKIE['city_id'])) {
	$loc_id     = !empty($_COOKIE['city_id']) ? $_COOKIE['city_id'] : '';
	$loc_type   = 'c';
	$loc_name   = !empty($_COOKIE['city_name' ]) ? $_COOKIE['city_name' ] : '';
	$loc_slug   = !empty($_COOKIE['city_slug' ]) ? $_COOKIE['city_slug' ] : '';
	$state_abbr = !empty($_COOKIE['state_abbr']) ? $_COOKIE['state_abbr'] : '';
	$near_query = urlencode("$loc_name,$state_abbr");
}

else {
	$loc_id     = 0;
	$loc_type   = 'n';
	$loc_name   = '';
	$state_abbr = '';
	$loc_slug   = $default_country_code;
	$near_query = $default_country_code;
}

/*--------------------------------------------------
categories
--------------------------------------------------*/
$query = "SELECT * FROM cats WHERE cat_status = 1 AND parent_id = 0 ORDER BY cat_order";
$stmt = $conn->prepare($query);
$stmt->execute();

$cats = array();
while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
	// vars
	$this_cat_id          = !empty($row['id'         ]) ? $row['id'         ] : '';
	$this_cat_name        = !empty($row['name'       ]) ? $row['name'       ] : '';
	$this_cat_slug        = !empty($row['cat_slug'   ]) ? $row['cat_slug'   ] : '';
	$this_cat_plural_name = !empty($row['plural_name']) ? $row['plural_name'] : '';
	$this_cat_icon        = !empty($row['cat_icon'   ]) ? $row['cat_icon'   ] : '';
	$this_cat_order       = !empty($row['cat_order'  ]) ? $row['cat_order'  ] : '';

	// sanitize
	$this_cat_name        = e($this_cat_name);
	$this_cat_slug        = e($this_cat_slug);
	$this_cat_plural_name = e($this_cat_plural_name);

	// img path
	$cat_img_path = $pic_basepath . '/category/cat-' . $this_cat_id;

	// check if file exists
	$arr = glob("$cat_img_path.*");

	if(!empty($arr)) {
		$cat_img_filename = basename($arr[0]);
		$cat_img_filename_url = $pic_baseurl . '/category/' . $cat_img_filename;
	}

	else {
		$cat_img_filename = '';
		$cat_img_filename_url = $baseurl . '/assets/imgs/blank.png';
	}

	// get translated cat name if user language cookie is set
	if(!empty($user_cookie_lang)) {
		$this_cat_name = cat_name_transl($this_cat_id, $user_cookie_lang, 'singular', $this_cat_name);
		$this_cat_plural_name = cat_name_transl($this_cat_id, $user_cookie_lang, 'plural', $this_cat_plural_name);
	}

	$cur_loop = array(
		'cat_id'     => $this_cat_id,
		'cat_name'   => $this_cat_name,
		'cat_slug'   => $this_cat_slug,
		'cat_plural' => $this_cat_plural_name,
		'cat_icon'   => $this_cat_icon,
		'cat_order'  => $this_cat_order,
		'cat_img'    => $cat_img_filename_url,
		);

	$cats[] = $cur_loop;
}

/*--------------------------------------------------
featured listings
--------------------------------------------------*/
$featured_listings = array();

// array of listings ids in this result set
$featured_listings_ids = array();

$query = "SELECT
	p.listing_id, p.userid, p.listing_title, p.city_id, p.price, p.short_desc, p.address,
	p.feat, p.slug AS listing_slug, p.main_pic,
	ph.dir, ph.filename,
	c.city_name, c.slug,
	s.slug AS state_slug, s.state_abbr,
	cats.cat_slug, cats.id AS cat_id, cats.name AS cat_name, cats.cat_icon, cats.cat_bg
	FROM listings p
	LEFT JOIN photos ph ON p.listing_id = ph.listing_id
	LEFT JOIN cities c ON c.city_id = p.city_id
	LEFT JOIN states s ON c.state_id = s.state_id
	LEFT JOIN rel_listing_cat rpc ON rpc.listing_id = p.listing_id AND rpc.is_main = 1
	LEFT JOIN cats ON cats.id = rpc.cat_id
	WHERE (p.feat_home = 1 OR (p.feat = 1 AND p.city_id = :city_id)) AND p.status = 'approved' AND paid = 1
	GROUP BY p.listing_id";
$stmt = $conn->prepare($query);
$stmt->bindValue(':city_id', $loc_id);
$stmt->execute();

while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
	// assign vars from query result
	$feat_listing_id     = !empty($row['listing_id'   ]) ? $row['listing_id'   ] : '';
	$feat_userid         = !empty($row['userid'       ]) ? $row['userid'       ] : '';
	$feat_listing_title  = !empty($row['listing_title']) ? $row['listing_title'] : '';
	$feat_listing_slug   = !empty($row['listing_slug' ]) ? $row['listing_slug' ] : $feat_listing_id;
	$feat_price          = !empty($row['price'        ]) ? $row['price'        ] : '';
	$feat_short_desc     = !empty($row['short_desc'   ]) ? $row['short_desc'   ] : '';
	$feat_listing_addr   = !empty($row['address'      ]) ? $row['address'      ] : '';
	$feat_cat_id         = !empty($row['cat_id'       ]) ? $row['cat_id'       ] : '';
	$feat_cat_name       = !empty($row['cat_name'     ]) ? $row['cat_name'     ] : $feat_cat_id;
	$feat_cat_slug       = !empty($row['cat_slug'     ]) ? $row['cat_slug'     ] : $feat_cat_id;
	$feat_cat_icon       = !empty($row['cat_icon'     ]) ? $row['cat_icon'     ] : $cfg_default_cat_icon;
	$feat_cat_bg         = !empty($row['cat_bg'       ]) ? $row['cat_bg'       ] : $cfg_default_cat_bg;
	$feat_city_name      = !empty($row['city_name'    ]) ? $row['city_name'    ] : '';
	$feat_city_slug      = !empty($row['slug'         ]) ? $row['slug'         ] : '';
	$feat_state_slug     = !empty($row['state_slug'   ]) ? $row['state_slug'   ] : '';
	$feat_state_abbr     = !empty($row['state_abbr'   ]) ? $row['state_abbr'   ] : '';
	$feat_photo_dir      = !empty($row['dir'          ]) ? $row['dir'          ] : '';
	$feat_photo_filename = !empty($row['filename'     ]) ? $row['filename'     ] : '';
	$feat_main_pic       = !empty($row['main_pic'     ]) ? $row['main_pic'     ] : '';

	// sanitize
	$feat_listing_id     = e($feat_listing_id    );
	$feat_userid         = e($feat_userid        );
	$feat_listing_title  = e($feat_listing_title );
	$feat_listing_slug   = e($feat_listing_slug  );
	$feat_price          = e($feat_price         );
	$feat_short_desc     = e($feat_short_desc    );
	$feat_listing_addr   = e($feat_listing_addr  );
	$feat_cat_id         = e($feat_cat_id        );
	$feat_cat_name       = e($feat_cat_name      );
	$feat_cat_slug       = e($feat_cat_slug      );
	//$feat_cat_icon     = e($feat_cat_icon      );
	//$feat_cat_bg       = e($feat_cat_bg        );
	$feat_city_name      = e($feat_city_name     );
	$feat_city_slug      = e($feat_city_slug     );
	$feat_state_slug     = e($feat_state_slug    );
	$feat_state_abbr     = e($feat_state_abbr    );
	$feat_photo_dir      = e($feat_photo_dir     );
	$feat_photo_filename = e($feat_photo_filename);
	$feat_main_pic       = e($feat_main_pic      );

	// title
	$endash = html_entity_decode('&#x2013;', ENT_COMPAT, 'UTF-8');
	$feat_listing_title = str_replace($endash, "-", $feat_listing_title);

	// limit description text length
	if(!empty($feat_listing_desc)) {
		$feat_listing_desc = mb_substr($feat_listing_desc, 0, 96);
	}

	// limit short_desc text length
	if(!empty($feat_short_desc)) {
		$feat_short_desc = mb_substr($feat_short_desc, 0, 96);
	}

	// feat_photo_url
	$feat_photo_url = $baseurl . '/assets/imgs/blank.png';

	if(!empty($feat_main_pic)) {
		if(is_file($pic_basepath . '/main-pic/' . substr($feat_main_pic, 0, 2) . '/' . $feat_main_pic)) {
			$feat_photo_url = $pic_baseurl . '/main-pic/' . substr($feat_main_pic, 0, 2) . '/' . $feat_main_pic;
		}
	}

	// owner profile pic
	$feat_profile_pic = $baseurl . '/assets/imgs/blank.png';
	$folder = floor($feat_userid / 1000) + 1;

	if(strlen($folder) < 1) {
		$folder = '999';
	}

	// get profile pic filename
	$profile_pic_path = $profile_thumb_folder . '/' . $folder . '/' . $feat_userid;

	foreach($img_exts as $v) {
		if(file_exists($pic_basepath . '/' . $profile_pic_path . '.' . $v)) {
			$feat_profile_pic = $pic_baseurl . '/' . $profile_pic_path . '.' . $v;
			break;
		}
	}

	// link
	$feat_listing_link = get_listing_link($feat_listing_id, $feat_listing_slug, $feat_cat_id, $feat_cat_slug, '', $feat_city_slug, $feat_state_slug, $cfg_permalink_struct);

	// populate array
	$cur_loop = array(
		'cat_bg'        => $feat_cat_bg,
		'cat_icon'      => $feat_cat_icon,
		'cat_name'      => $feat_cat_name,
		'cat_slug'      => $feat_cat_slug,
		'city_name'     => $feat_city_name,
		'city_slug'     => $feat_city_slug,
		'listing_addr'  => $feat_listing_addr,
		'price'         => $feat_price,
		'listing_id'    => $feat_listing_id,
		'listing_link'  => $feat_listing_link,
		'listing_slug'  => $feat_listing_slug,
		'listing_title' => $feat_listing_title,
		'photo_url'     => $feat_photo_url,
		'profile_pic'   => $feat_profile_pic,
		'short_desc'    => $feat_short_desc,
		'state_abbr'    => $feat_state_abbr,
		'state_slug'    => $feat_state_slug,
		'avg_rating'    => 0,
		);

	// get translated cat name if user language cookie is set
	if(!empty($user_cookie_lang)) {
		$cur_loop['cat_name'] = cat_name_transl($feat_cat_id , $user_cookie_lang, 'singular', $feat_cat_name);
	}

	$featured_listings[$feat_listing_id] = $cur_loop;

	// populate array of listings ids for this results set
	$featured_listings_ids[$feat_listing_id] = $feat_listing_id;
}

/*--------------------------------------------------
Featured listings ratings
--------------------------------------------------*/

if(!empty($featured_listings)) {
	$featured_listings_ids_str = implode(",", $featured_listings_ids);

	$query = "SELECT listing_id, AVG(reviews.rating) AS avg_rating
				FROM reviews
				WHERE listing_id IN($featured_listings_ids_str)
				GROUP BY listing_id";

	$stmt = $conn->prepare($query);
	$stmt->execute();

	while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
		$listing_id = $row['listing_id'];
		$avg_rating = $row['avg_rating'];
		$avg_rating = number_format((float)$avg_rating, 2, isset($cfg_decimal_separator) ? $cfg_decimal_separator : '.', '');

		$featured_listings[$listing_id]['avg_rating'] = $avg_rating;
	}
}

/*--------------------------------------------------
latest listings
--------------------------------------------------*/
$latest_listings = array();

// array of listings ids in this result set
$latest_listings_ids = array();

$query = "SELECT
	p.listing_id, p.userid, p.listing_title, p.city_id, p.price, p.short_desc, p.address,
	p.feat, p.slug AS listing_slug, p.main_pic,
	ph.dir, ph.filename,
	c.city_name, c.slug,
	s.slug AS state_slug, s.state_abbr,
	cats.cat_slug, cats.id AS cat_id, cats.name AS cat_name, cats.cat_icon, cats.cat_bg
	FROM listings p
	LEFT JOIN photos ph ON p.listing_id = ph.listing_id
	LEFT JOIN cities c ON c.city_id = p.city_id
	LEFT JOIN states s ON c.state_id = s.state_id
	LEFT JOIN rel_listing_cat rpc ON rpc.listing_id = p.listing_id AND rpc.is_main = 1
	LEFT JOIN cats ON cats.id = rpc.cat_id
	WHERE p.status = 'approved' AND paid = 1
	GROUP BY p.listing_id
	ORDER BY p.listing_id DESC LIMIT :limit";
$stmt = $conn->prepare($query);
$stmt->bindValue(':limit', $cfg_latest_listings_count);
$stmt->execute();

while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
	// assign vars from query result
	$latest_listing_id     = !empty($row['listing_id'   ]) ? $row['listing_id'   ] : '';
	$latest_userid         = !empty($row['userid'       ]) ? $row['userid'       ] : '';
	$latest_listing_title  = !empty($row['listing_title']) ? $row['listing_title'] : '';
	$latest_listing_slug   = !empty($row['listing_slug' ]) ? $row['listing_slug' ] : $latest_listing_id ;
	$latest_listing_price  = !empty($row['price'        ]) ? $row['price'        ] : '';
	$latest_short_desc     = !empty($row['short_desc'   ]) ? $row['short_desc'   ] : '';
	$latest_listing_addr   = !empty($row['address'      ]) ? $row['address'      ] : '';
	$latest_cat_id         = !empty($row['cat_id'       ]) ? $row['cat_id'       ] : '';
	$latest_cat_name       = !empty($row['cat_name'     ]) ? $row['cat_name'     ] : $latest_cat_id;
	$latest_cat_slug       = !empty($row['cat_slug'     ]) ? $row['cat_slug'     ] : $latest_cat_id;
	$latest_cat_icon       = !empty($row['cat_icon'     ]) ? $row['cat_icon'     ] : $cfg_default_cat_icon;
	$latest_cat_bg         = !empty($row['cat_bg'       ]) ? $row['cat_bg'       ] : $cfg_default_cat_bg;
	$latest_city_name      = !empty($row['city_name'    ]) ? $row['city_name'    ] : '';
	$latest_city_slug      = !empty($row['slug'         ]) ? $row['slug'         ] : '';
	$latest_state_slug     = !empty($row['state_slug'   ]) ? $row['state_slug'   ] : '';
	$latest_state_abbr     = !empty($row['state_abbr'   ]) ? $row['state_abbr'   ] : '';
	$latest_photo_dir      = !empty($row['dir'          ]) ? $row['dir'          ] : '';
	$latest_photo_filename = !empty($row['filename'     ]) ? $row['filename'     ] : '';
	$latest_main_pic       = !empty($row['main_pic'     ]) ? $row['main_pic'     ] : '';
	$latest_is_feat        = !empty($row['feat'         ]) ? $row['feat'         ] : false;

	// sanitize
	$latest_listing_id     = e($latest_listing_id    );
	$latest_userid         = e($latest_userid        );
	$latest_listing_title  = e($latest_listing_title );
	$latest_listing_slug   = e($latest_listing_slug  );
	$latest_listing_price  = e($latest_listing_price );
	$latest_short_desc     = e($latest_short_desc    );
	$latest_listing_addr   = e($latest_listing_addr  );
	$latest_cat_id         = e($latest_cat_id        );
	$latest_cat_name       = e($latest_cat_name      );
	$latest_cat_slug       = e($latest_cat_slug      );
	//$latest_cat_icon     = e($latest_cat_icon      );
	//$latest_cat_bg       = e($latest_cat_bg        );
	$latest_city_name      = e($latest_city_name     );
	$latest_city_slug      = e($latest_city_slug     );
	$latest_state_slug     = e($latest_state_slug    );
	$latest_state_abbr     = e($latest_state_abbr    );
	$latest_photo_dir      = e($latest_photo_dir     );
	$latest_photo_filename = e($latest_photo_filename);
	$latest_main_pic       = e($latest_main_pic      );

	// title
	$endash = html_entity_decode('&#x2013;', ENT_COMPAT, 'UTF-8');
	$latest_listing_title = str_replace($endash, "-", $latest_listing_title);

	// limit short_desc text length
	if(!empty($latest_short_desc)) {
		$latest_short_desc = mb_substr($latest_short_desc, 0, 96);
	}

	// latest_photo_url
	$latest_photo_url = $baseurl . '/assets/imgs/blank.png';

	if(!empty($latest_main_pic)) {
		if(is_file($pic_basepath . '/main-pic/' . substr($latest_main_pic, 0, 2) . '/' . $latest_main_pic)) {
			$latest_photo_url = $pic_baseurl . '/main-pic/' . substr($latest_main_pic, 0, 2) . '/' . $latest_main_pic;
		}
	}

	// owner profile pic
	$latest_profile_pic = $baseurl . '/assets/imgs/blank.png';
	$folder = floor($latest_userid / 1000) + 1;

	if(strlen($folder) < 1) {
		$folder = '999';
	}

	// get profile pic filename
	$profile_pic_path = $profile_thumb_folder . '/' . $folder . '/' . $latest_userid;

	foreach($img_exts as $v) {
		if(file_exists($pic_basepath . '/' . $profile_pic_path . '.' . $v)) {
			$latest_profile_pic = $pic_baseurl . '/' . $profile_pic_path . '.' . $v;
			break;
		}
	}

	// link
	$latest_listing_link = get_listing_link($latest_listing_id, $latest_listing_slug, $latest_cat_id, $latest_cat_slug, '', $latest_city_slug, $latest_state_slug, $cfg_permalink_struct);

	// populate array
	$cur_loop = array(
		'cat_bg'        => $latest_cat_bg,
		'cat_icon'      => $latest_cat_icon,
		'cat_name'      => $latest_cat_name,
		'cat_slug'      => $latest_cat_slug,
		'city_name'     => $latest_city_name,
		'city_slug'     => $latest_city_slug,
		'listing_addr'  => $latest_listing_addr,
		'listing_price' => $latest_listing_price,
		'listing_id'    => $latest_listing_id,
		'listing_link'  => $latest_listing_link,
		'listing_slug'  => $latest_listing_slug,
		'listing_title' => $latest_listing_title,
		'photo_url'     => $latest_photo_url,
		'profile_pic'   => $latest_profile_pic,
		'short_desc'    => $latest_short_desc,
		'state_abbr'    => $latest_state_abbr,
		'state_slug'    => $latest_state_slug,
		'is_feat'       => $latest_is_feat,
		'avg_rating'    => 0,
		);

	// get translated cat name if user language cookie is set
	if(!empty($user_cookie_lang)) {
		$cur_loop['cat_name'] = cat_name_transl($latest_cat_id , $user_cookie_lang, 'singular', $latest_cat_name);
	}

	$latest_listings[$latest_listing_id] = $cur_loop;

	// populate array of listings ids for this results set
	$latest_listings_ids[$latest_listing_id] = $latest_listing_id;
}

/*--------------------------------------------------
Latest listings ratings
--------------------------------------------------*/

if(!empty($latest_listings)) {
	$latest_listings_ids_str = implode(",", $latest_listings_ids);

	$query = "SELECT listing_id, AVG(reviews.rating) AS avg_rating
				FROM reviews
				WHERE listing_id IN($latest_listings_ids_str)
				GROUP BY listing_id";

	$stmt = $conn->prepare($query);
	$stmt->execute();

	while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
		$listing_id = $row['listing_id'];
		$avg_rating = $row['avg_rating'];
		$avg_rating = number_format((float)$avg_rating, 2, isset($cfg_decimal_separator) ? $cfg_decimal_separator : '.', '');

		$latest_listings[$listing_id]['avg_rating'] = $avg_rating;
	}
}

/*--------------------------------------------------
featured cities
--------------------------------------------------*/
$featured_cities = array();

$query = "SELECT
	c.*, s.slug AS state_slug, s.state_name, x.num_listings
	FROM cities c
	LEFT JOIN states s ON c.state_id = s.state_id
	LEFT JOIN (SELECT city_id, COUNT(*) AS num_listings FROM `listings` GROUP BY city_id) x ON x.city_id = c.city_id
	RIGHT JOIN cities_feat f ON c.city_id = f.city_id
	ORDER BY c.city_name";
$stmt = $conn->prepare($query);
$stmt->execute();

while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
	// default city pic
	$city_pic = $baseurl . '/assets/imgs/dark.jpg';

	// city image if exists
	foreach($img_exts as $v) {
		if(file_exists($pic_basepath . '/city/' . $row['city_id'] . '.' . $v)) {
			$city_pic = $pic_baseurl . '/city/' . $row['city_id'] . '.' . $v;
			break;
		}
	}

	$num_listings = empty($row['num_listings']) ? 0 : $row['num_listings'];

	$cur_loop = array(
		'city_id'      => $row['city_id'],
		'city_name'    => $row['city_name'],
		'state_slug'   => $row['state_slug'],
		'state_id'     => $row['state_id'],
		'city_slug'    => $row['slug'],
		'state_name'   => $row['state_name'],
		'state_abbr'   => $row['state'],
		'num_listings' => $num_listings,
		'city_pic'     => $city_pic,
	);

	$featured_cities[] = $cur_loop;
}

/*--------------------------------------------------
near listings
--------------------------------------------------*/
$near_listings = array();
$max_dist = isset($cgf_near_listings_radius) ? $cgf_near_listings_radius : 150;

// array of listings ids in this result set
$near_listings_ids = array();

$user_lat = !empty($_COOKIE['user_lat']) ? $_COOKIE['user_lat'] : '0.0';
$user_lng = !empty($_COOKIE['user_lng']) ? $_COOKIE['user_lng'] : '0.0';

$query = "SELECT
	p.listing_id, p.userid, p.listing_title, p.city_id, p.price, p.short_desc, p.address, p.feat, p.slug AS listing_slug,
	ph.dir, ph.filename,
	c.city_name, c.slug,
	s.slug AS state_slug, s.state_abbr,
	cats.cat_slug, cats.id AS cat_id, cats.name AS cat_name, cats.cat_icon, cats.cat_bg,
	3956 * 2 *
	ASIN(SQRT( POWER(SIN((:user_lat1 - p.lat) * pi() / 180 / 2), 2)
	+ COS(:user_lat2 * pi() / 180 ) * COS(p.lat * pi() / 180)
	*POWER(SIN((:user_lng1 - p.lng) * pi() / 180 / 2), 2))) AS distance
	FROM listings p
	LEFT JOIN photos ph ON p.listing_id = ph.listing_id
	LEFT JOIN cities c ON c.city_id = p.city_id
	LEFT JOIN states s ON c.state_id = s.state_id
	LEFT JOIN rel_listing_cat rpc ON rpc.listing_id = p.listing_id AND rpc.is_main = 1
	LEFT JOIN cats ON cats.id = rpc.cat_id
	WHERE p.status = 'approved' AND paid = 1
	AND
	p.lng BETWEEN (:user_lng2 - $max_dist / COS(RADIANS(:user_lat3)) * 69)
	AND (:user_lng3 + $max_dist / COS(RADIANS(:user_lat4)) * 69)
	AND p.lat BETWEEN (:user_lat5 - ($max_dist / 69))
	AND (:user_lat6 + ($max_dist / 69))
	GROUP BY p.listing_id
	HAVING distance < $max_dist";
$stmt = $conn->prepare($query);
$stmt->bindValue(':user_lat1', $user_lat);
$stmt->bindValue(':user_lat2', $user_lat);
$stmt->bindValue(':user_lat3', $user_lat);
$stmt->bindValue(':user_lat4', $user_lat);
$stmt->bindValue(':user_lat5', $user_lat);
$stmt->bindValue(':user_lat6', $user_lat);
$stmt->bindValue(':user_lng1', $user_lng);
$stmt->bindValue(':user_lng2', $user_lng);
$stmt->bindValue(':user_lng3', $user_lng);
$stmt->execute();

while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
	// assign vars from query result
	$near_listing_id     = !empty($row['listing_id'   ]) ? $row['listing_id'   ] : '';
	$near_userid         = !empty($row['userid'       ]) ? $row['userid'       ] : '';
	$near_listing_title  = !empty($row['listing_title']) ? $row['listing_title'] : '';
	$near_listing_slug   = !empty($row['listing_slug' ]) ? $row['listing_slug' ] : $near_listing_id ;
	$near_listing_price  = !empty($row['price'        ]) ? $row['price'        ] : '';
	$near_short_desc     = !empty($row['short_desc'   ]) ? $row['short_desc'   ] : '';
	$near_listing_addr   = !empty($row['address'      ]) ? $row['address'      ] : '';
	$near_cat_id         = !empty($row['cat_id'       ]) ? $row['cat_id'       ] : '';
	$near_cat_name       = !empty($row['cat_name'     ]) ? $row['cat_name'     ] : $near_cat_id;
	$near_cat_slug       = !empty($row['cat_slug'     ]) ? $row['cat_slug'     ] : $near_cat_id;
	$near_cat_icon       = !empty($row['cat_icon'     ]) ? $row['cat_icon'     ] : $cfg_default_cat_icon;
	$near_cat_bg         = !empty($row['cat_bg'       ]) ? $row['cat_bg'       ] : $cfg_default_cat_bg;
	$near_city_name      = !empty($row['city_name'    ]) ? $row['city_name'    ] : '';
	$near_city_slug      = !empty($row['slug'         ]) ? $row['slug'         ] : '';
	$near_state_slug     = !empty($row['state_slug'   ]) ? $row['state_slug'   ] : '';
	$near_state_abbr     = !empty($row['state_abbr'   ]) ? $row['state_abbr'   ] : '';
	$near_photo_dir      = !empty($row['dir'          ]) ? $row['dir'          ] : '';
	$near_photo_filename = !empty($row['filename'     ]) ? $row['filename'     ] : '';
	$near_is_feat        = !empty($row['feat'         ]) ? $row['feat'         ] : false;

	// sanitize
	$near_listing_id     = e($near_listing_id    );
	$near_userid         = e($near_userid        );
	$near_listing_title  = e($near_listing_title );
	$near_listing_slug   = e($near_listing_slug  );
	$near_listing_price  = e($near_listing_price );
	$near_short_desc     = e($near_short_desc    );
	$near_listing_addr   = e($near_listing_addr  );
	$near_cat_id         = e($near_cat_id        );
	$near_cat_name       = e($near_cat_name      );
	$near_cat_slug       = e($near_cat_slug      );
	//$near_cat_icon     = e($near_cat_icon      );
	//$near_cat_bg       = e($near_cat_bg        );
	$near_city_name      = e($near_city_name     );
	$near_city_slug      = e($near_city_slug     );
	$near_state_slug     = e($near_state_slug    );
	$near_state_abbr     = e($near_state_abbr    );
	$near_photo_dir      = e($near_photo_dir     );
	$near_photo_filename = e($near_photo_filename);

	// title
	$endash = html_entity_decode('&#x2013;', ENT_COMPAT, 'UTF-8');
	$near_listing_title = str_replace($endash, "-", $near_listing_title);

	// limit description text length
	if(!empty($near_listing_desc)) {
		$near_listing_desc = mb_substr($near_listing_desc, 0, 96);
	}

	// limit short_desc text length
	if(!empty($near_short_desc)) {
		$near_short_desc = mb_substr($near_short_desc, 0, 96);
	}

	// near_photo_url
	$near_photo_url = $baseurl . '/assets/imgs/blank.png';

	if(!empty($near_photo_filename)) {
		if(is_file($pic_basepath . '/' . $listing_thumb_folder . '/' . $near_photo_dir . '/' . $near_photo_filename)) {
			$near_photo_url = $pic_baseurl . '/' . $listing_thumb_folder . '/' . $near_photo_dir . '/' . $near_photo_filename;
		}
	}

	// owner profile pic
	$near_profile_pic = $baseurl . '/assets/imgs/blank.png';
	$folder = floor($near_userid / 1000) + 1;

	if(strlen($folder) < 1) {
		$folder = '999';
	}

	// get profile pic filename
	$profile_pic_path = $profile_thumb_folder . '/' . $folder . '/' . $near_userid;

	foreach($img_exts as $v) {
		if(file_exists($pic_basepath . '/' . $profile_pic_path . '.' . $v)) {
			$near_profile_pic = $pic_baseurl . '/' . $profile_pic_path . '.' . $v;
			break;
		}
	}

	// link
	$near_listing_link = get_listing_link($near_listing_id, $near_listing_slug, $near_cat_id, $near_cat_slug, '', $near_city_slug, $near_state_slug, $cfg_permalink_struct);

	// populate array
	$cur_loop = array(
		'cat_bg'        => $near_cat_bg,
		'cat_icon'      => $near_cat_icon,
		'cat_name'      => $near_cat_name,
		'cat_slug'      => $near_cat_slug,
		'city_name'     => $near_city_name,
		'city_slug'     => $near_city_slug,
		'listing_addr'  => $near_listing_addr,
		'listing_price' => $near_listing_price,
		'listing_id'    => $near_listing_id,
		'listing_link'  => $near_listing_link,
		'listing_slug'  => $near_listing_slug,
		'listing_title' => $near_listing_title,
		'photo_url'     => $near_photo_url,
		'profile_pic'   => $near_profile_pic,
		'short_desc'    => $near_short_desc,
		'state_abbr'    => $near_state_abbr,
		'state_slug'    => $near_state_slug,
		'is_feat'       => $near_is_feat,
		'avg_rating'    => 0,
		);

	// get translated cat name if user language cookie is set
	if(!empty($user_cookie_lang)) {
		$cur_loop['cat_name'] = cat_name_transl($near_cat_id , $user_cookie_lang, 'singular', $near_cat_name);
	}

	$near_listings[$near_listing_id] = $cur_loop;

	// populate array of listings ids for this results set
	$near_listings_ids[$near_listing_id] = $near_listing_id;
}

/*--------------------------------------------------
Near listings ratings
--------------------------------------------------*/

if(!empty($near_listings)) {
	$near_listings_ids_str = implode(",", $near_listings_ids);

	$query = "SELECT listing_id, AVG(reviews.rating) AS avg_rating
				FROM reviews
				WHERE listing_id IN($near_listings_ids_str)
				GROUP BY listing_id";

	$stmt = $conn->prepare($query);
	$stmt->execute();

	while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
		$listing_id = $row['listing_id'];
		$avg_rating = $row['avg_rating'];
		$avg_rating = number_format((float)$avg_rating, 2, isset($cfg_decimal_separator) ? $cfg_decimal_separator : '.', '');

		$near_listings[$listing_id]['avg_rating'] = $avg_rating;
	}
}

/*--------------------------------------------------
Favorites array
--------------------------------------------------*/
$listings_ids = array();
$favorites = array();

if(!empty($userid)) {
	foreach($latest_listings as $v) {
		$listings_ids[] = $v['listing_id'];
	}

	foreach($near_listings as $v) {
		$listings_ids[] = $v['listing_id'];
	}

	if(!empty($listings_ids)) {
		$listings_ids = implode(',', $listings_ids);

		$query = "SELECT * FROM rel_favorites WHERE listing_id IN ($listings_ids) AND userid = :userid";
		$stmt  = $conn->prepare($query);
		$stmt->bindValue(':userid', $userid);
		$stmt->execute();

		while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
			$favorites[] = $row['listing_id'];
		}
	}
}

/*--------------------------------------------------
canonical
--------------------------------------------------*/
$canonical = $baseurl;
