<?php
require_once(__DIR__ . '/inc/config.php');
require_once(__DIR__ . '/inc/img-exts.php');

/*--------------------------------------------------
Valid routes (below starting at index[1]

profile/id
--------------------------------------------------*/
if(empty($route[1]) || !ctype_digit($route[1])) {
	http_response_code(404);
	include($install_dir . '/templates/404.php');
	die();
}

$profile_id = $route[1];

/*--------------------------------------------------
Pagination
--------------------------------------------------*/
$page = !empty($route[2]) ? $route[2] : 1;
$limit = $items_per_page;

if($page > 1) {
	$offset = ($page-1) * $limit + 1;
}

else {
	$offset = 1;
}

$page_url = "$baseurl/profile/$profile_id/";

/*--------------------------------------------------
Profile details
--------------------------------------------------*/
$query = "SELECT * FROM users WHERE id = :profile_id";
$stmt = $conn->prepare($query);
$stmt->bindValue(':profile_id', $profile_id);
$stmt->execute();
$row = $stmt->fetch(PDO::FETCH_ASSOC);

// rows
$prof_first_name    = !empty($row['first_name'        ]) ? $row['first_name'        ] : '';
$prof_last_name     = !empty($row['last_name'         ]) ? $row['last_name'         ] : '';
$prof_city_name     = !empty($row['city_name'         ]) ? $row['city_name'         ] : '';
$prof_country_name  = !empty($row['country_name'      ]) ? $row['country_name'      ] : '';
$prof_created       = !empty($row['created'           ]) ? $row['created'           ] : '';
$prof_email         = !empty($row['email'             ]) ? $row['email'             ] : '';
$profile_pic_status = !empty($row['profile_pic_status']) ? $row['profile_pic_status'] : '';

// sanitize
$prof_first_name    = e($prof_first_name   );
$prof_last_name     = e($prof_last_name    );
$prof_city_name     = e($prof_city_name    );
$prof_country_name  = e($prof_country_name );
$prof_created       = e($prof_created      );
$prof_email         = e($prof_email        );
$profile_pic_status = e($profile_pic_status);

// prepare vars
$email_frags = explode('@', $prof_email);
$email_prefix = $email_frags[0];

if(!empty($prof_first_name) && !empty($prof_last_name)) {
	$profile_display_name = $prof_first_name . ' ' . $prof_last_name;
}
elseif(!empty($prof_first_name) && empty($prof_last_name)) {
	$profile_display_name = $prof_first_name;
}
elseif(empty($prof_first_name) && !empty($prof_last_name)) {
	$profile_display_name = $prof_last_name;
}
else {
	$profile_display_name = $email_prefix;
}

$join_date = date("F j, Y", strtotime($prof_created));

/*--------------------------------------------------
Count items
--------------------------------------------------*/
$query = "SELECT COUNT(*) AS c FROM listings WHERE userid = :profile_id AND status = 'approved' AND paid = 1";
$stmt = $conn->prepare($query);
$stmt->bindValue(':profile_id', $profile_id);
$stmt->execute();
$row = $stmt->fetch(PDO::FETCH_ASSOC);
$total_rows = $row['c'];

/*--------------------------------------------------
Get items
--------------------------------------------------*/
$seller_items = array();

// array of listings ids in this result set
$seller_items_ids = array();

if($total_rows > 0) {
	$pager = new App\PageIterator($limit, $total_rows, $page);
	$start = $pager->getStartRow();

	$query = "SELECT
				p.listing_id, p.listing_title, p.main_pic, p.slug AS listing_slug, p.address, p.main_pic,
				p.postal_code, p.phone, p.area_code, p.lat, p.lng, p.state_id, p.feat, p.short_desc, p.price,
				c.city_name, c.slug, c.state,
				s.state_name, s.slug AS state_slug, s.state_abbr,
				cats.cat_icon, cats.name AS cat_name, cats.cat_slug, cats.id AS cat_id,
				ph.dir, ph.filename
			FROM listings p
			LEFT JOIN rel_listing_cat r ON p.listing_id = r.listing_id AND r.is_main = 1
			LEFT JOIN cities c ON c.city_id = p.city_id
			LEFT JOIN states s ON c.state_id = s.state_id
			LEFT JOIN cats ON r.cat_id = cats.id
			LEFT JOIN photos ph ON p.listing_id = ph.listing_id
			WHERE p.status = 'approved' AND p.paid = 1 AND userid = :userid
			ORDER BY p.feat DESC, p.listing_id DESC
			LIMIT :start, :limit";

	$stmt = $conn->prepare($query);
	$stmt->bindValue(':userid', $profile_id);
	$stmt->bindValue(':start', $start);
	$stmt->bindValue(':limit', $limit);
	$stmt->execute();

	while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
		$this_listing_id         = !empty($row['listing_id'   ]) ? $row['listing_id'   ] : '';
		$this_address            = !empty($row['address'      ]) ? $row['address'      ] : '';
		$this_area_code          = !empty($row['area_code'    ]) ? $row['area_code'    ] : '';
		$this_cat_id             = !empty($row['cat_id'       ]) ? $row['cat_id'       ] : '';
		$this_cat_icon           = !empty($row['cat_icon'     ]) ? $row['cat_icon'     ] : '';
		$this_cat_name           = !empty($row['cat_name'     ]) ? $row['cat_name'     ] : '';
		$this_cat_slug           = !empty($row['cat_slug'     ]) ? $row['cat_slug'     ] : '';
		$this_is_feat            = !empty($row['feat'         ]) ? $row['feat'         ] : '';
		$this_lat                = !empty($row['lat'          ]) ? $row['lat'          ] : '';
		$this_lng                = !empty($row['lng'          ]) ? $row['lng'          ] : '';
		$this_main_pic           = !empty($row['main_pic'     ]) ? $row['main_pic'     ] : '';
		$this_phone              = !empty($row['phone'        ]) ? $row['phone'        ] : '';
		$this_listing_city_name  = !empty($row['city_name'    ]) ? $row['city_name'    ] : '';
		$this_listing_city_slug  = !empty($row['slug'         ]) ? $row['slug'         ] : 'city';
		$this_listing_title      = !empty($row['listing_title']) ? $row['listing_title'] : '';
		$this_listing_slug       = !empty($row['listing_slug' ]) ? $row['listing_slug' ] : $listing_id;
		$this_listing_state_abbr = !empty($row['state'        ]) ? $row['state'        ] : '';
		$this_listing_state_id   = !empty($row['state_id'     ]) ? $row['state_id'     ] : '';
		$this_listing_state_slug = !empty($row['state_slug'   ]) ? $row['state_slug'   ] : '';
		$this_postal_code        = !empty($row['postal_code'  ]) ? $row['postal_code'  ] : '';
		$this_short_desc         = !empty($row['short_desc'   ]) ? $row['short_desc'   ] : '';
		$this_listing_price      = !empty($row['price'        ]) ? $row['price'        ] : '';

		// sanitize
		$this_listing_id         = e($this_listing_id        );
		$this_address            = e($this_address           );
		$this_area_code          = e($this_area_code         );
		$this_cat_name           = e($this_cat_name          );
		$this_cat_slug           = e($this_cat_slug          );
		$this_is_feat            = e($this_is_feat           );
		$this_lat                = e($this_lat               );
		$this_lng                = e($this_lng               );
		$this_main_pic           = e($this_main_pic          );
		$this_phone              = e($this_phone             );
		$this_listing_city_name  = e($this_listing_city_name );
		$this_listing_city_slug  = e($this_listing_city_slug );
		$this_listing_title      = e($this_listing_title     );
		$this_listing_slug       = e($this_listing_slug      );
		$this_listing_state_abbr = e($this_listing_state_abbr);
		$this_listing_state_id   = e($this_listing_state_id  );
		$this_listing_state_slug = e($this_listing_state_slug);
		$this_postal_code        = e($this_postal_code       );
		$this_short_desc         = e($this_short_desc        );
		$this_listing_price      = e($this_listing_price     );

		// get translated cat name if user language cookie is set
		if(!empty($user_cookie_lang)) {
			$this_cat_name = cat_name_transl($this_cat_id , $user_cookie_lang, 'singular', $this_cat_name);
		}

		// photo url (not being used, main pic is used instead)
		$this_photo_url = $baseurl . '/assets/imgs/blank.png';

		if(!empty($row['filename'])) {
			$this_photo_url = $pic_baseurl . '/' . $listing_thumb_folder . '/' . $row['dir'] . '/' . $row['filename'];
		}

		// main pic
		$this_main_pic_url = $baseurl . '/assets/imgs/blank.png';

		if(!empty($this_photo_url)) {
			$this_main_pic_url = $this_photo_url;
		}

		if(!empty($this_main_pic) && file_exists($pic_basepath . '/main-pic/' . substr($this_main_pic, 0, 2) . '/' . $this_main_pic)) {
			$this_main_pic_url = $pic_baseurl . '/main-pic/' . substr($this_main_pic, 0, 2) . '/' . $this_main_pic;
		}

		// clean listing_title
		$this_endash = html_entity_decode('&#x2013;', ENT_COMPAT, 'UTF-8');
		$this_listing_title = str_replace($this_endash, "-", $this_listing_title);

		// link
		$this_listing_link = get_listing_link($this_listing_id, $this_listing_slug, $this_cat_id, $this_cat_slug, '', $this_listing_city_slug, $this_listing_state_slug, $cfg_permalink_struct);

		// items array
		$seller_items[$this_listing_id] = array(
			'address'       => $this_address,
			'area_code'     => $this_area_code,
			'cat_icon'      => $this_cat_icon,
			'cat_name'      => $this_cat_name,
			'cat_slug'      => $this_cat_slug,
			'city_name'     => $this_listing_city_name,
			'city_slug'     => $this_listing_city_slug,
			'is_feat'       => $this_is_feat,
			'lat'           => $this_lat,
			'listing_id'    => $this_listing_id,
			'listing_link'  => $this_listing_link,
			'listing_price' => $this_listing_price,
			'listing_slug'  => $this_listing_slug,
			'listing_title' => $this_listing_title,
			'lng'           => $this_lng,
			'main_pic_url'  => $this_main_pic_url,
			'phone'         => $this_phone,
			'photo_url'     => $this_photo_url,
			'postal_code'   => $this_postal_code,
			'rating'        => 0,
			'short_desc'    => $this_short_desc,
			'state_abbr'    => $this_listing_state_abbr,
			'state_slug'    => $this_listing_state_slug,
		);

		// populate array of listings ids for this results set
		$seller_items_ids[$this_listing_id] = $this_listing_id;
	}
}

/*--------------------------------------------------
Items ratings
--------------------------------------------------*/

if(!empty($seller_items)) {
	$seller_items_ids_str = implode(",", $seller_items_ids);

	$query = "SELECT listing_id, AVG(reviews.rating) AS avg_rating
				FROM reviews
				WHERE listing_id IN($seller_items_ids_str)
				GROUP BY listing_id";

	$stmt = $conn->prepare($query);
	$stmt->execute();

	while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
		$listing_id = $row['listing_id'];
		$avg_rating = $row['avg_rating'];
		$avg_rating = number_format((float)$avg_rating, 2, isset($cfg_decimal_separator) ? $cfg_decimal_separator : '.', '');

		$seller_items[$listing_id]['rating'] = $avg_rating;
	}
}

/*--------------------------------------------------
Current visitor favorites array
--------------------------------------------------*/
$listings_ids = array();
$favorites = array();

if(!empty($userid)) {
	foreach($seller_items as $v) {
		$listings_ids[] = $v['listing_id'];
	}

	if(!empty($listings_ids)) {
		$listings_ids = implode(',', $listings_ids);

		$query = "SELECT * FROM rel_favorites WHERE listing_id IN ($listings_ids) AND userid = :userid";
		$stmt  = $conn->prepare($query);
		$stmt->bindValue(':userid', $userid);
		$stmt->execute();

		while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
			$favorites[] = $row['listing_id'];
		}
	}
}

/*--------------------------------------------------
Profile pic
--------------------------------------------------*/
// init default
$profile_pic = $baseurl . '/assets/imgs/blank.png';

// folder
$folder = floor($profile_id / 1000) + 1;

if(strlen($folder) < 1) {
	$folder = '999';
}

// get profile pic filename
$profile_pic_path = $profile_full_folder . '/' . $folder . '/' . $profile_id;

foreach($img_exts as $v) {
	if(file_exists($pic_basepath . '/' . $profile_pic_path . '.' . $v)) {
		$profile_pic = $pic_baseurl . '/' . $profile_pic_path . '.' . $v;
		break;
	}
}

if(!empty($profile_pic)) {
	$profile_pic_tag = '<div class="dummy container-img rounded" style="background-image:url(\'' . $profile_pic . '?' . uniqid() . '\');"></div>';
}

else {
	$profile_pic_tag = '<img src="' . $baseurl . '/assets/imgs/blank.png" width="150" height="150">';
}

/*--------------------------------------------------
language var substitution
--------------------------------------------------*/
$txt_joined_on = str_replace('%join_date%', $join_date, $txt_joined_on);
$txt_html_title = str_replace('%profile_display_name%', $profile_display_name, $txt_html_title);
$txt_meta_desc = str_replace('%profile_display_name%', $profile_display_name, $txt_meta_desc);

/*--------------------------------------------------
canonical
--------------------------------------------------*/
$canonical = $baseurl . '/profile/' . $profile_id;