<?php
/*
Cancel subscription
This file is called from the /admin/users.php file. Cancels Stripe subscription if needed. Paypal cancellation is not possible as it would need access to the Paypal's dashboard.

since v.3.03
*/

require_once(__DIR__ . '/../inc/config.php');
require_once(__DIR__ . '/_admin_inc.php');

// csrf check
require_once(__DIR__ . '/_admin_inc_request_with_ajax.php');

// post data
$this_uniq_id = !empty($_POST['uniq_id']) ? $_POST['uniq_id'] : '';
$this_user_id = !empty($_POST['user_id']) ? $_POST['user_id'] : '';
$this_gateway = !empty($_POST['gateway']) ? $_POST['gateway'] : '';

// get user email
$query = "SELECT * FROM users WHERE id = :userid";
$stmt = $conn->prepare($query);
$stmt->bindValue(':userid', $this_user_id);
$stmt->execute();
$row = $stmt->fetch(PDO::FETCH_ASSOC);
$user_email = !empty($row['email']) ? $row['email'] : '';

if($this_gateway == 'stripe') {
	// get subscription id
	$query = "SELECT * FROM credits WHERE uniq_id = :uniq_id AND user = :userid";
	$stmt = $conn->prepare($query);
	$stmt->bindValue(':uniq_id', $this_uniq_id);
	$stmt->bindValue(':userid', $this_user_id);
	$stmt->execute();
	$row = $stmt->fetch(PDO::FETCH_ASSOC);

	$this_subscr_id = $row['subscr_id'];

	// cancel
	if(!empty($this_subscr_id)) {
		try {
			$conn->beginTransaction();

			// set api key
			// if live mode
			if($stripe_mode == 1) {
				$stripe_key = $stripe_live_secret_key;
			}

			// else test mode
			else {
				$stripe_key = $stripe_test_secret_key;
			}

			\Stripe\Stripe::setApiKey($stripe_key);
			\Stripe\Stripe::setApiVersion("2016-10-19");

			// cancel subscription
			$subscription = \Stripe\Subscription::retrieve($this_subscr_id);
			if(!$subscription->cancel()) {
				die('Problem terminating Stripe subscription');
			}

			// remove credits
			$query = 'DELETE FROM credits WHERE user = :userid AND uniq_id = :uniq_id';
			$stmt = $conn->prepare($query);
			$stmt->bindValue(':userid', $this_user_id);
			$stmt->bindValue(':uniq_id', $this_uniq_id);
			$stmt->execute();

			// update listings status to unpaid
			$query = 'UPDATE listings SET paid = 0 WHERE userid = :userid AND credits_uniq_id = :uniq_id';
			$stmt = $conn->prepare($query);
			$stmt->bindValue(':userid', $this_user_id);
			$stmt->bindValue(':uniq_id', $this_uniq_id);
			$stmt->execute();

			// email user informing subscription ended
			$query = "SELECT * FROM email_templates WHERE type = 'subscr_eot'";
			$stmt = $conn->prepare($query);
			$stmt->execute();
			$row = $stmt->fetch(PDO::FETCH_ASSOC);
			$email_subject = !empty($row['subject']) ? $row['subject'] : '';
			$email_body    = !empty($row['body'   ]) ? $row['body'   ] : '';

			// string replacements
			$email_subject = str_replace('%site_name%', $site_name, $email_subject);
			$email_subject = str_replace('%site_url%', $baseurl, $email_subject);
			$email_body = str_replace('%site_name%', $site_name, $email_body);
			$email_body = str_replace('%site_url%', $baseurl, $email_body);

			// send email to user
			if(!empty($email_body)) {
				try {
					// mailer params
					$PHPMailer->clearAllRecipients();
					$PHPMailer->clearReplyTos();
					$PHPMailer->AllowEmpty = true;
					$PHPMailer->setFrom($admin_email, $site_name);
					$PHPMailer->addAddress($user_email);
					$PHPMailer->addReplyTo($admin_email);
					$PHPMailer->isHTML(false);
					$PHPMailer->Subject = $email_subject;
					$PHPMailer->Body = $email_body;

					// send
					$PHPMailer->send();
				} catch (Exception $e) {
					echo "Message could not be sent. Mailer Error: {$PHPMailer->ErrorInfo}";
				}
			}

			$conn->commit();
		}

		catch(PDOException $e) {
			$conn->rollBack();
			echo $e->getMessage();
		}
	}

	else {
		echo "Empty subscription id";
	}
}

if($this_gateway == 'admin') {
	try {
		$conn->beginTransaction();

		// remove credits
		$query = 'DELETE FROM credits WHERE uniq_id = :uniq_id AND user = :userid';
		$stmt = $conn->prepare($query);
		$stmt->bindValue(':uniq_id', $this_uniq_id);
		$stmt->bindValue(':userid', $this_user_id);
		$stmt->execute();

		// update listings status to unpaid
		$query = 'UPDATE listings SET paid = 0 WHERE credits_uniq_id = :uniq_id';
		$stmt = $conn->prepare($query);
		$stmt->bindValue(':uniq_id', $this_uniq_id);
		$stmt->execute();

		// get user info
		$query = "SELECT * FROM users WHERE id = :userid";
		$stmt = $conn->prepare($query);
		$stmt->bindValue(':userid', $this_user_id);
		$stmt->execute();
		$row = $stmt->fetch(PDO::FETCH_ASSOC);

		$user_firstname = !empty($row['first_name']) ? $row['first_name'] : '';
		$user_email     = !empty($row['email'     ]) ? $row['email'     ] : '';

		// get email template
		$query = "SELECT * FROM email_templates WHERE type = 'subscr_eot'";
		$stmt = $conn->prepare($query);
		$stmt->execute();
		$row = $stmt->fetch(PDO::FETCH_ASSOC);
		$email_subject = !empty($row['subject']) ? $row['subject'] : '';
		$email_body    = !empty($row['body'   ]) ? $row['body'   ] : '';

		// string replacements
		$email_subject = str_replace('%site_name%', $site_name, $email_subject);
		$email_subject = str_replace('%site_url%', $baseurl, $email_subject);
		$email_body = str_replace('%site_name%', $site_name, $email_body);
		$email_body = str_replace('%site_url%', $baseurl, $email_body);

		// send email to user
		if(!empty($email_body)) {
			try {
				// mailer params
				$PHPMailer->clearAllRecipients();
				$PHPMailer->clearReplyTos();
				$PHPMailer->AllowEmpty = true;
				$PHPMailer->setFrom($admin_email, $site_name);
				$PHPMailer->addAddress($user_email);
				$PHPMailer->addReplyTo($admin_email);
				$PHPMailer->isHTML(false);
				$PHPMailer->Subject = $email_subject;
				$PHPMailer->Body = $email_body;

				// send
				$PHPMailer->send();
			} catch (Exception $e) {
				echo "Message could not be sent. Mailer Error: {$PHPMailer->ErrorInfo}";
			}
		}

		$conn->commit();
	}

	catch(PDOException $e) {
		$conn->rollBack();
		echo $e->getMessage();
	}
}