<?php
require_once(__DIR__ . '/../inc/config.php');

// debug switch
$debug = false;

// debug
if($debug) {
	try {
		// mailer params
		$PHPMailer->clearAllRecipients();
		$PHPMailer->clearReplyTos();
		$PHPMailer->AllowEmpty = true;
		$PHPMailer->setFrom($admin_email, $site_name);
		$PHPMailer->addAddress($dev_email);
		$PHPMailer->addReplyTo($admin_email);
		$PHPMailer->isHTML(false);
		$PHPMailer->Subject = 'First stripe';
		$PHPMailer->Body = 'Stripe debug';

		// send
		$PHPMailer->send();
	} catch (Exception $e) {
		echo "Message could not be sent. Mailer Error: {$PHPMailer->ErrorInfo}";
	}
}

/*--------------------------------------------------
API config
--------------------------------------------------*/

// if stripe live mode
if($stripe_mode == 1) {
	$stripe_key = $stripe_live_secret_key;
}

// else is stripe test mode
else {
	$stripe_key = $stripe_test_secret_key;
}

\Stripe\Stripe::setApiKey($stripe_key);
\Stripe\Stripe::setApiVersion("2016-10-19");

// Retrieve the request's body and parse it as JSON
$input = @file_get_contents("php://input");

// extract json str into assoc array
//$event_json = json_decode($input); --> object
$event_arr = json_decode($input, true); // --> array

// Check against Stripe to confirm that the ID is valid
if(!empty($event_arr['id'])) {
	$event_obj = \Stripe\Event::retrieve($event_arr['id']);

	// convert $event into assoc array
	$event = $event_obj->toArray(true);
}

// check if it's proper event
if(!isset($event)) {
	die();
}

/*--------------------------------------------------
Transaction table vars
--------------------------------------------------*/
$parent_txn_id   = '';
$ipn_vars        = $input;
$ipn_response    = $input;
$ipn_description = !empty($event['data']['object']['object']) ? $event['data']['object']['object'] : '';
$txn_type        = !empty($event['type']                    ) ? $event['type']                     : '';
$payment_status  = !empty($event['data']['object']['status']) ? $event['data']['object']['status'] : '';
$txn_id          = !empty($event['id']                      ) ? $event['id']                       : '';
$txn_date        = !empty($event['created']                 ) ? $event['created']                  : '';

/*--------------------------------------------------
Event types
--------------------------------------------------*/
$events = array(
	'charge.succeeded',
	'charge.refunded',
	'charge.failed',
	'customer.subscription.created',
	'customer.subscription.deleted',
	'invoice.payment_succeeded',
	'invoice.payment_failed'
);

// act only on the event types above
if(!in_array($txn_type, $events)) {
	die();
}

/*--------------------------------------------------
Check if it's subscription
--------------------------------------------------*/
$is_subscription = null;

if($txn_type == 'charge.succeeded') {
	if(empty($event['data']['object']['invoice'])) {
		$is_subscription = false;
	}

	else {
		$is_subscription = true;
	}
}

if( $txn_type == 'customer.subscription.created' ||
	$txn_type == 'customer.subscription.deleted' ||
	$txn_type == 'invoice.payment_succeeded'
	) {
	$is_subscription = true;
}

if($txn_type == 'charge.failed') {
	// if charge failed, it could be either subscription or buy now
	// but if metadata is empty, it means it's subscription, if contains metadata, it's buy now
	if(!empty($event['data']['object']['metadata'])) {
		$is_subscription = false;
	}

	else {
		$is_subscription = true;
	}
}

/*--------------------------------------------------
Metadata
--------------------------------------------------*/
// for 'buy now', metadata data is sent with \Stripe\Charge::create and received in webhook of type 'charge.succeeded'
// for 'subscriptions', metadata data is sent with \Stripe\Subscription::create and received in webhook type 'customer.subscription.created' and 'customer.subscription.deleted', also in 'invoice.payment_succeeded', 'invoice.created'

if(in_array($txn_type, array('charge.succeeded', 'charge.failed', 'charge.refunded'))) {
	if(!$is_subscription) {
		$plan_id   = !empty($event['data']['object']['metadata']['plan_id'  ]) ? $event['data']['object']['metadata']['plan_id'  ] : 0;
		$payer_id  = !empty($event['data']['object']['metadata']['payer_id' ]) ? $event['data']['object']['metadata']['payer_id' ] : 0;
		$uniq_id   = !empty($event['data']['object']['metadata']['uniq_id'  ]) ? $event['data']['object']['metadata']['uniq_id'  ] : '';
		$user_id   = !empty($event['data']['object']['metadata']['user_id'  ]) ? $event['data']['object']['metadata']['user_id'  ] : '';
	}
}

if($txn_type == 'customer.subscription.created' || $txn_type == 'customer.subscription.deleted') {
	$plan_id   = !empty($event['data']['object']['metadata']['plan_id'  ]) ? $event['data']['object']['metadata']['plan_id']   : 0;
	$payer_id  = !empty($event['data']['object']['metadata']['payer_id' ]) ? $event['data']['object']['metadata']['payer_id']  : 0;
	$uniq_id   = !empty($event['data']['object']['metadata']['uniq_id'  ]) ? $event['data']['object']['metadata']['uniq_id']   : '';
	$user_id   = !empty($event['data']['object']['metadata']['user_id'  ]) ? $event['data']['object']['metadata']['user_id']   : '';
}

/*--------------------------------------------------
Plan details
--------------------------------------------------*/
$query = "SELECT * FROM plans WHERE plan_id = :plan_id";
$stmt = $conn->prepare($query);
$stmt->bindValue(':plan_id', $plan_id);
$stmt->execute();
$row = $stmt->fetch(PDO::FETCH_ASSOC);

$plan_price   = !empty($row['plan_price'  ]) ? $row['plan_price'  ] : '';
$plan_credits = !empty($row['plan_credits']) ? $row['plan_credits'] : '';
$plan_type    = !empty($row['plan_type'   ]) ? $row['plan_type'   ] : '';

$plan_price = str_replace(',', '', $plan_price);
$plan_price = str_replace('.', '', $plan_price);

// stripe always uses non-decimal amount in minimum currency unit (e.g. cents for USD and yen for JPY)
// plan_price is always decimal so if $stripe_min_unit_is_cent is false(for eg. JPY), then divide amount by 100
if(!$stripe_min_unit_is_cent) {
	$plan_price = $plan_price / 100;
}

// stripe currency
$query = "SELECT * FROM config WHERE property = 'stripe_data_currency'";
$stmt = $conn->prepare($query);
$stmt->execute();
$row = $stmt->fetch(PDO::FETCH_ASSOC);

$stripe_currency = !empty($row['value']) ? $row['value'] : '';
$stripe_currency = mb_strtolower($stripe_currency);

/*--------------------------------------------------
subscr_id
--------------------------------------------------*/
$subscr_id = '';

if($plan_type == 'one_time' || $plan_type == 'one_time_feat') {
	$subscr_id = '';
}

else {
	$subscr_id = !empty($event['data']['object']['id']) ? $event['data']['object']['id'] : '';
}

/*--------------------------------------------------
Customer info
--------------------------------------------------*/
$customer_obj   = \Stripe\Customer::retrieve($event['data']['object']['customer']);
$customer       = $customer_obj->toArray(true);
$customer_email = $customer['email'];
$customer_id    = $customer['id'];

/*--------------------------------------------------
Amount
--------------------------------------------------*/
if($plan_type == 'one_time' || $plan_type == 'one_time_feat') {
	$amount = !empty($event['data']['object']['amount']) ? $event['data']['object']['amount'] : '';
	$amount_currency = !empty($event['data']['object']['currency']) ? $event['data']['object']['currency'] : '';
}

else {
	$amount = !empty($event['data']['object']['plan']['amount']) ? $event['data']['object']['plan']['amount'] : '';
	$amount_currency = !empty($event['data']['object']['plan']['currency']) ? $event['data']['object']['plan']['currency'] : '';
}

$amount_currency = mb_strtolower($amount_currency);

/*--------------------------------------------------
Debug
--------------------------------------------------*/
$debug_msg = "
amount          = $amount
customer_id     = $customer_id
ipn_description = $ipn_description
ipn_response    = $ipn_response
ipn_vars        = $ipn_vars
is_subscription = $is_subscription
parent_txn_id   = $parent_txn_id
customer_email  = $customer_email
payment_status  = $payment_status
plan_id         = $plan_id
plan_type       = $plan_type
subscr_id       = $subscr_id
txn_date        = $txn_date
txn_id          = $txn_id
txn_type        = $txn_type
uniq_id         = $uniq_id
user_id         = $user_id
";

if($debug) {
	try {
		// mailer params
		$PHPMailer->clearAllRecipients();
		$PHPMailer->clearReplyTos();
		$PHPMailer->AllowEmpty = true;
		$PHPMailer->setFrom($admin_email, $site_name);
		$PHPMailer->addAddress($dev_email);
		$PHPMailer->addReplyTo($admin_email);
		$PHPMailer->isHTML(false);
		$PHPMailer->Subject = 'Second stripe';
		$PHPMailer->Body = 'Second Stripe debug';

		// send
		$PHPMailer->send();
	} catch (Exception $e) {
		echo "Message could not be sent. Mailer Error: {$PHPMailer->ErrorInfo}";
	}
}

/*--------------------------------------------------
User details
--------------------------------------------------*/
$query = "SELECT * FROM users WHERE id = :user_id";
$stmt = $conn->prepare($query);
$stmt->bindValue(':user_id', $user_id);
$stmt->execute();
$row = $stmt->fetch(PDO::FETCH_ASSOC);

$user_email     = !empty($row['email'     ]) ? $row['email'     ] : $customer_email;
$user_firstname = !empty($row['first_name']) ? $row['first_name'] : $first_name;

/*--------------------------------------------------
Init email vars
--------------------------------------------------*/
$email_subject = '';
$email_body = '';

/*--------------------------------------------------
HANDLE EVENT
--------------------------------------------------*/
// if buy now
if(!$is_subscription) {
	if($txn_type == 'charge.succeeded') {
		// verify amount
		if($plan_price == $amount && $stripe_currency == $amount_currency) {
			// check if this webhook was not sent before
			$query = "SELECT COUNT(*) AS c FROM credits WHERE user = :userid AND uniq_id = :uniq_id";
			$stmt = $conn->prepare($query);
			$stmt->bindValue(':uniq_id', $uniq_id);
			$stmt->bindValue(':userid', $user_id);
			$stmt->execute();
			$row = $stmt->fetch(PDO::FETCH_ASSOC);
			$total_count = !empty($row['c']) ? $row['c'] : 0;

			// add credits
			if($total_count < 1) {
				$query = 'INSERT INTO credits(user, plan, credits, uniq_id, paym_email, gateway) VALUES(:user, :plan, :credits, :uniq_id, :paym_email, :gateway)';
				$stmt = $conn->prepare($query);
				$stmt->bindValue(':user', $user_id);
				$stmt->bindValue(':plan', $plan_id);
				$stmt->bindValue(':credits', $plan_credits);
				$stmt->bindValue(':uniq_id', $uniq_id);
				$stmt->bindValue(':paym_email', $customer_email);
				$stmt->bindValue(':gateway', 'stripe');
				$stmt->execute();

				// get email template
				$query = "SELECT * FROM email_templates WHERE type = 'credits_added'";
				$stmt = $conn->prepare($query);
				$stmt->execute();
				$row = $stmt->fetch(PDO::FETCH_ASSOC);
				$email_subject = !empty($row['subject']) ? $row['subject'] : '';
				$email_body    = !empty($row['body'   ]) ? $row['body'   ] : '';

				// string replacements
				$email_subject = str_replace('%site_name%', $site_name, $email_subject);
				$email_subject = str_replace('%site_url%', $baseurl, $email_subject);
				$email_body = str_replace('%site_name%', $site_name, $email_body);
				$email_body = str_replace('%site_url%', $baseurl, $email_body);

				// send email
				try {
					// mailer params
					$PHPMailer->clearAllRecipients();
					$PHPMailer->clearReplyTos();
					$PHPMailer->AllowEmpty = true;
					$PHPMailer->setFrom($admin_email, $site_name);
					$PHPMailer->addAddress($user_email);
					$PHPMailer->addReplyTo($admin_email);
					$PHPMailer->isHTML(false);
					$PHPMailer->Subject = $email_subject;
					$PHPMailer->Body = $email_body;

					// send
					$PHPMailer->send();
				} catch (Exception $e) {
					echo "Message could not be sent. Mailer Error: {$PHPMailer->ErrorInfo}";
				}
			}

			else {
				echo 'webhook already received';
			}
		}

		else {
			$debug_msg .= "\n---$plan_price <> $amount --- $stripe_currency <> $amount_currency";
			// send email to admin about plan price not matching amount paid
			try {
				// mailer params
				$PHPMailer->clearAllRecipients();
				$PHPMailer->clearReplyTos();
				$PHPMailer->AllowEmpty = true;
				$PHPMailer->setFrom($admin_email, $site_name);
				$PHPMailer->addAddress($dev_email);
				$PHPMailer->addReplyTo($admin_email);
				$PHPMailer->isHTML(false);
				$PHPMailer->Subject = 'charge.succeeded - plan price <> amount';
				$PHPMailer->Body = $debug_msg;

				// send
				$PHPMailer->send();
			} catch (Exception $e) {
				echo "Message could not be sent. Mailer Error: {$PHPMailer->ErrorInfo}";
			}
		}

		if($debug) {
			echo 'charge.succeeded';
		}
	}

	else if($txn_type == 'charge.failed') {
		// define email informing user of charge.failed
		$query = "SELECT * FROM email_templates WHERE type = 'charge_failed'";
		$stmt = $conn->prepare($query);
		$stmt->execute();
		$row = $stmt->fetch(PDO::FETCH_ASSOC);
		$email_subject = !empty($row['subject']) ? $row['subject'] : '';
		$email_body    = !empty($row['body'   ]) ? $row['body'   ] : '';

		// string replacements
		$email_subject = str_replace('%site_name%', $site_name, $email_subject);
		$email_subject = str_replace('%site_url%', $baseurl, $email_subject);
		$email_body = str_replace('%site_name%', $site_name, $email_body);
		$email_body = str_replace('%site_url%', $baseurl, $email_body);

		// send email
		try {
			// mailer params
			$PHPMailer->clearAllRecipients();
			$PHPMailer->clearReplyTos();
			$PHPMailer->AllowEmpty = true;
			$PHPMailer->setFrom($admin_email, $site_name);
			$PHPMailer->addAddress($user_email);
			$PHPMailer->addReplyTo($admin_email);
			$PHPMailer->isHTML(false);
			$PHPMailer->Subject = $email_subject;
			$PHPMailer->Body = $email_body;

			// send
			$PHPMailer->send();
		} catch (Exception $e) {
			echo "Message could not be sent. Mailer Error: {$PHPMailer->ErrorInfo}";
		}
	}

	else if($txn_type == 'charge.refunded') {
		// remove credits
		$query = 'DELETE FROM credits WHERE user = :user AND plan = :plan AND uniq_id = :uniq_id';
		$stmt = $conn->prepare($query);
		$stmt->bindValue(':user', $user_id);
		$stmt->bindValue(':plan', $plan_id);
		$stmt->bindValue(':uniq_id', $uniq_id);
		$stmt->execute();

		// update listings status to unpaid
		$query = 'UPDATE listings SET paid = 0 WHERE userid = :userid AND plan = :plan AND credits_uniq_id = :uniq_id';
		$stmt = $conn->prepare($query);
		$stmt->bindValue(':userid', $user_id);
		$stmt->bindValue(':plan', $plan_id);
		$stmt->bindValue(':uniq_id', $uniq_id);
		$stmt->execute();
	}

	else {
		// log transaction
		error_log("Webhook data is a one-off purchase but charge neither succeeded nor failed/refunded");
	}
}

// else is subscription
else {
	// webhook types to act on:
		// 'customer.subscription.created'
		// 'customer.subscription.deleted'
		// 'invoice.payment_succeeded'
		// 'invoice.payment_failed'
	// if subscription succeeded
	if($txn_type == 'customer.subscription.created') {
		// verify amount
		if($plan_price == $amount && $stripe_currency == $amount_currency) {
			// check if this webhook was not sent before
			$query = "SELECT COUNT(*) AS c FROM credits WHERE user = :userid AND uniq_id = :uniq_id";
			$stmt = $conn->prepare($query);
			$stmt->bindValue(':uniq_id', $uniq_id);
			$stmt->bindValue(':userid', $user_id);
			$stmt->execute();
			$row = $stmt->fetch(PDO::FETCH_ASSOC);
			$total_count = !empty($row['c']) ? $row['c'] : 0;

			// add credits
			if($total_count < 1) {
				$query = 'INSERT INTO credits(user, plan, credits, uniq_id, paym_email, gateway, subscr_id) VALUES(:user, :plan, :credits, :uniq_id, :paym_email, :gateway, :subscr_id)';
				$stmt = $conn->prepare($query);
				$stmt->bindValue(':user', $user_id);
				$stmt->bindValue(':plan', $plan_id);
				$stmt->bindValue(':credits', $plan_credits);
				$stmt->bindValue(':uniq_id', $uniq_id);
				$stmt->bindValue(':paym_email', $customer_email);
				$stmt->bindValue(':gateway', 'stripe');
				$stmt->bindValue(':subscr_id', $subscr_id);
				$stmt->execute();

				// subscr_signup email
				$query = "SELECT * FROM email_templates WHERE type = 'subscr_signup'";
				$stmt = $conn->prepare($query);
				$stmt->execute();
				$row = $stmt->fetch(PDO::FETCH_ASSOC);
				$email_subject = !empty($row['subject']) ? $row['subject'] : '';
				$email_body    = !empty($row['body'   ]) ? $row['body'   ] : '';

				// string replacements
				$email_subject = str_replace('%site_name%', $site_name, $email_subject);
				$email_subject = str_replace('%site_url%', $baseurl, $email_subject);
				$email_body = str_replace('%site_name%', $site_name, $email_body);
				$email_body = str_replace('%site_url%', $baseurl, $email_body);

				// send email
				try {
					// mailer params
					$PHPMailer->clearAllRecipients();
					$PHPMailer->clearReplyTos();
					$PHPMailer->AllowEmpty = true;
					$PHPMailer->setFrom($admin_email, $site_name);
					$PHPMailer->addAddress($user_email);
					$PHPMailer->addReplyTo($admin_email);
					$PHPMailer->isHTML(false);
					$PHPMailer->Subject = $email_subject;
					$PHPMailer->Body = $email_body;

					// send
					$PHPMailer->send();
				} catch (Exception $e) {
					echo "Message could not be sent. Mailer Error: {$PHPMailer->ErrorInfo}";
				}
			}

			else {
				echo 'webhook already received';
			}
		}

		else {
			// send email to admin about diverging price
			$debug_msg .= "\n---$plan_price <> $amount --- $stripe_currency <> $amount_currency";

			try {
				// mailer params
				$PHPMailer->clearAllRecipients();
				$PHPMailer->clearReplyTos();
				$PHPMailer->AllowEmpty = true;
				$PHPMailer->setFrom($admin_email, $site_name);
				$PHPMailer->addAddress($dev_email);
				$PHPMailer->addReplyTo($admin_email);
				$PHPMailer->isHTML(false);
				$PHPMailer->Subject = 'charge.succeeded - plan price <> amount';
				$PHPMailer->Body = $debug_msg;

				// send
				$PHPMailer->send();
			} catch (Exception $e) {
				echo "Message could not be sent. Mailer Error: {$PHPMailer->ErrorInfo}";
			}
		}
	}

	else if($txn_type == 'charge.succeeded') {
		// log transaction
	}

	else if($txn_type == 'invoice.payment_succeeded') {
		// log transaction
	}

	else if($txn_type == 'invoice.payment_failed') {
		// define email informing user of invoice.payment_failed
		$query = "SELECT * FROM email_templates WHERE type = 'subscr_failed'";
		$stmt = $conn->prepare($query);
		$stmt->execute();
		$row = $stmt->fetch(PDO::FETCH_ASSOC);
		$email_subject = !empty($row['subject']) ? $row['subject'] : '';
		$email_body    = !empty($row['body'   ]) ? $row['body'   ] : '';

		// string replacements
		$email_subject = str_replace('%site_name%', $site_name, $email_subject);
		$email_subject = str_replace('%site_url%', $baseurl, $email_subject);
		$email_body = str_replace('%site_name%', $site_name, $email_body);
		$email_body = str_replace('%site_url%', $baseurl, $email_body);

		// send email
		try {
			// mailer params
			$PHPMailer->clearAllRecipients();
			$PHPMailer->clearReplyTos();
			$PHPMailer->AllowEmpty = true;
			$PHPMailer->setFrom($admin_email, $site_name);
			$PHPMailer->addAddress($user_email);
			$PHPMailer->addReplyTo($admin_email);
			$PHPMailer->isHTML(false);
			$PHPMailer->Subject = $email_subject;
			$PHPMailer->Body = $email_body;

			// send
			$PHPMailer->send();
		} catch (Exception $e) {
			echo "Message could not be sent. Mailer Error: {$PHPMailer->ErrorInfo}";
		}
	}

	else if($txn_type == 'customer.subscription.deleted') {
		// remove credits
		$query = 'DELETE FROM credits WHERE user = :user AND plan = :plan AND uniq_id = :uniq_id';
		$stmt = $conn->prepare($query);
		$stmt->bindValue(':user', $user_id);
		$stmt->bindValue(':plan', $plan_id);
		$stmt->bindValue(':uniq_id', $uniq_id);
		$stmt->execute();

		// update listings status to unpaid
		$query = 'UPDATE listings SET paid = 0 WHERE userid = :userid AND plan = :plan AND credits_uniq_id = :uniq_id';
		$stmt = $conn->prepare($query);
		$stmt->bindValue(':userid', $user_id);
		$stmt->bindValue(':plan', $plan_id);
		$stmt->bindValue(':uniq_id', $uniq_id);
		$stmt->execute();

		// email user informing subscription ended
		$query = "SELECT * FROM email_templates WHERE type = 'subscr_eot'";
		$stmt = $conn->prepare($query);
		$stmt->execute();
		$row = $stmt->fetch(PDO::FETCH_ASSOC);
		$email_subject = (!empty($row['subject'])) ? $row['subject'] : '';
		$email_body    = (!empty($row['body']   )) ? $row['body']    : '';

		// string replacements
		$email_subject = str_replace('%site_name%', $site_name, $email_subject);
		$email_subject = str_replace('%site_url%', $baseurl, $email_subject);
		$email_body = str_replace('%site_name%', $site_name, $email_body);
		$email_body = str_replace('%site_url%', $baseurl, $email_body);

		// send email
		try {
			// mailer params
			$PHPMailer->clearAllRecipients();
			$PHPMailer->clearReplyTos();
			$PHPMailer->AllowEmpty = true;
			$PHPMailer->setFrom($admin_email, $site_name);
			$PHPMailer->addAddress($user_email);
			$PHPMailer->addReplyTo($admin_email);
			$PHPMailer->isHTML(false);
			$PHPMailer->Subject = $email_subject;
			$PHPMailer->Body = $email_body;

			// send
			$PHPMailer->send();
		} catch (Exception $e) {
			echo "Message could not be sent. Mailer Error: {$PHPMailer->ErrorInfo}";
		}
	}

	else {
		// log transaction
	}
}

/*--------------------------------------------------
INSERT INTO TRANSACTIONS TABLE
--------------------------------------------------*/

$query = "INSERT INTO transactions(
		txn_type,
		uniq_id,
		user,
		paym_email,
		gateway,
		amount,
		txn_data
	)
	VALUES(
		:txn_type,
		:uniq_id,
		:user_id,
		:paym_email,
		:gateway,
		:amount,
		:txn_data
	)";

$stmt = $conn->prepare($query);

$stmt->bindValue(':txn_type'   , $txn_type);
$stmt->bindValue(':uniq_id'    , $uniq_id);
$stmt->bindValue(':user_id'    , $user_id);
$stmt->bindValue(':paym_email' , $customer_email);
$stmt->bindValue(':gateway'    , 'stripe');
$stmt->bindValue(':amount'     , $amount);
$stmt->bindValue(':txn_data'   , $ipn_vars);

$stmt->execute();
