<?php
require_once(__DIR__ . '/../inc/config.php');
require_once(__DIR__ . '/user_area_inc.php');

/*--------------------------------------------------
Plan details
--------------------------------------------------*/

$plan_id = !empty($route[2]) ? $route[2] : '';

if(empty($plan_id)) {
	trigger_error("Invalid plan selection", E_USER_ERROR);
	die();
}

// get plan details
$query = "SELECT * FROM plans WHERE plan_id = :plan_id";
$stmt = $conn->prepare($query);
$stmt->bindValue(':plan_id', $plan_id);
$stmt->execute();
$row = $stmt->fetch(PDO::FETCH_ASSOC);

$plan_type    = !empty($row['plan_type'   ]) ? $row['plan_type'   ] : '';
$plan_name    = !empty($row['plan_name'   ]) ? $row['plan_name'   ] : '';
$plan_period  = !empty($row['plan_period' ]) ? $row['plan_period' ] : 0;
$plan_price   = !empty($row['plan_price'  ]) ? $row['plan_price'  ] : 0;
$plan_status  = !empty($row['plan_status' ]) ? $row['plan_status' ] : '';
$plan_credits = !empty($row['plan_credits']) ? $row['plan_credits'] : 1;

// trim
$plan_type    = trim($plan_type   );
$plan_name    = trim($plan_name   );
$plan_period  = trim($plan_period );
$plan_price   = trim($plan_price  );
$plan_status  = trim($plan_status );
$plan_credits = trim($plan_credits);

// validate plan credits
$plan_credits = is_numeric($plan_credits) ? $plan_credits : 1;

// check plan id selection
if(empty($plan_type)) {
	trigger_error("Invalid plan selection", E_USER_ERROR);
	die();
}

/*--------------------------------------------------
If free plan, add credits only once for each user
--------------------------------------------------*/

if($plan_type == 'free' || $plan_type == 'free_feat') {
	// check if user already has this plan
	$query = "SELECT COUNT(*) AS c FROM credits WHERE plan = :plan_id AND user = :userid";
	$stmt = $conn->prepare($query);
	$stmt->bindValue(':plan_id', $plan_id);
	$stmt->bindValue(':userid', $userid);
	$stmt->execute();
	$row = $stmt->fetch(PDO::FETCH_ASSOC);

	if($row['c'] < 1) {
		// add credits
		$query = 'INSERT INTO credits(user, plan, credits, uniq_id) VALUES(:user, :plan, :credits, :uniq_id)';
		$stmt = $conn->prepare($query);
		$stmt->bindValue(':user', $userid);
		$stmt->bindValue(':plan', $plan_id);
		$stmt->bindValue(':credits', $plan_credits);
		$stmt->bindValue(':uniq_id', uniqid());
		$stmt->execute();
	}
}

/*--------------------------------------------------
Paypal integration
--------------------------------------------------*/

// if not a free plan
if($plan_type != 'free' && $plan_type != 'free_feat') {
	// if it's a monthly plan
	if($plan_type == 'monthly' || $plan_type == 'monthly_feat') {
		// init vars
		$cmd = "_xclick-subscriptions";
		$p3  = '1';
		$t3  = 'M';
		$src = '1';
		$srt = '52';
		$a3 = $plan_price;
		$amount = $plan_price;
	}

	// if it's an annual plan
	if($plan_type == 'annual' || $plan_type == 'annual_feat') {
		// init vars
		$cmd = "_xclick-subscriptions";
		$p3  = '1';
		$t3  = 'Y';
		$src = '1';
		$srt = '52';
		$a3 = $plan_price;
		$amount = $plan_price;
	}

	// if it's a one time plan
	if($plan_type == 'one_time' || $plan_type == 'one_time_feat') {
		// init vars
		$cmd = "_xclick";
		$amount = $plan_price;
	}

	// bn (<Company>_<Service>_<Product>_<Country>)
	$bn = $paypal_bn . '_Subscribe_WPS_' . $default_country_code;
}

// payment gateway vars
// notify url
$notify_url = $baseurl . '/payment-gateways/paypal-new.php';

// if paypal live
if($paypal_mode == 1) {
	$paypal_url = 'https://www.paypal.com/cgi-bin/webscr';
}

// else is paypal sandbox
else {
	$paypal_url = 'https://www.sandbox.paypal.com/cgi-bin/webscr';
	$paypal_merchant_id = $paypal_sandbox_merch_id;
}

/*--------------------------------------------------
Stripe integration - Setup
--------------------------------------------------*/

// if stripe live mode
if($stripe_mode == 1) {
	$stripe_key = $stripe_live_secret_key;
}

// else is stripe test mode
else {
	$stripe_key = $stripe_test_secret_key;
}

// init stripe object
if($stripe_mode > -1) {
	$stripe = new \Stripe\StripeClient($stripe_key);
}

/*--------------------------------------------------
Stripe Integration - Params
--------------------------------------------------*/

// product id
$stripe_prod_id = 'prod_plan_id_' . $plan_id;

// product name
$stripe_prod_name = $plan_name;

// price or amount, also remove non-numeric characters
$stripe_amount_cents = filter_var($plan_price, FILTER_SANITIZE_NUMBER_FLOAT);

// currency (Stripe requires lowercase)
$stripe_currency = strtolower($stripe_data_currency);

// is subscription
$is_subscription = false;
$subscription_interval = 'month';

if(in_array($plan_type, array('monthly', 'monthly_feat', 'annual', 'annual_feat'))) {
	$is_subscription = true;

	if($plan_type == 'annual' || $plan_type == 'annual_feat') {
		$subscription_interval = 'year';
	}
}

// checkout session create mode
$stripe_checkout_mode = $is_subscription ? 'subscription' : 'payment';

// the link to checkout
$checkout_session_url = '';

/*--------------------------------------------------
Stripe Integration - Retrieve or create product
--------------------------------------------------*/

// if stripe is not disabled
if($stripe_mode > -1) {
	$stripe_prod_retrieved = false;
	$stripe_prod_created = false;
	$stripe_api_error = '';

	// retrieve prod if exists
	try {
		$stripe_prod_retrieved = $stripe->products->retrieve(
			$stripe_prod_id,
			[]
		);
	} catch(Exception $e) {
		// set prod to false
		$stripe_prod_retrieved = false;
		$stripe_api_error .= $e->getMessage();
	}

	// create prod if retrieve fails
	if(!$stripe_prod_retrieved) {
		try {
			$stripe_prod_created = $stripe->products->create([
				'id' => $stripe_prod_id,
				'name' => $stripe_prod_name,
			]);
		} catch(Exception $e) {
			// set prod to false
			$stripe_prod_created = false;
			$stripe_api_error .= $e->getMessage();
		}
	}

	if(!$stripe_prod_created && !$stripe_prod_retrieved) {
		throw new Exception('Could not create or retrieve product. ' . $stripe_api_error);
	}
}

/*--------------------------------------------------
Stripe Integration - Checkout Session Payment Mode
--------------------------------------------------*/

// if stripe is not disabled
if($stripe_mode > -1 && $stripe_checkout_mode == 'payment') {
	$checkout_session = $stripe->checkout->sessions->create([
		'line_items' => [
			[
				'price_data' => [
					'unit_amount' => $stripe_amount_cents,
					'currency' => $stripe_currency,
					'product' => $stripe_prod_id,
				],
				'quantity' => 1,
			]
		],
		'mode' => 'payment',
		'client_reference_id' => $userid,
		'payment_intent_data' => [
			'metadata' => [
				'plan_id' => $plan_id,
				'user_id' => $userid,
				'uniq_id' => uniqid(),
			],
		],
		'success_url' => $baseurl . '/msg',
		'cancel_url' => $baseurl . '/user/select-plan',
	]);

	$checkout_session_url = $checkout_session->url;
}

/*--------------------------------------------------
Stripe Integration - Checkout Session Subscription Mode
--------------------------------------------------*/

// In subscription mode, metadata should be passed in subscription_data.metadata instead of payment_intent_data.metadata

// if stripe is not disabled
if($stripe_mode > -1 && $stripe_checkout_mode == 'subscription') {
	$checkout_session = $stripe->checkout->sessions->create([
		'line_items' => [
			[
				'price_data' => [
					'unit_amount' => $stripe_amount_cents,
					'currency' => $stripe_currency,
					'product' => $stripe_prod_id,
					'recurring' => [
						'interval' => $subscription_interval,
					],
				],
				'quantity' => 1,
			]
		],
		'mode' => 'subscription',
		'client_reference_id' => $userid,
		'subscription_data' => [
			'metadata' => [
				'plan_id' => $plan_id,
				'user_id' => $userid,
				'uniq_id' => uniqid(),
			],
		],
		'success_url' => $baseurl . '/msg',
		'cancel_url' => $baseurl . '/user/select-plan',
	]);

	$checkout_session_url = $checkout_session->url;
}

/*--------------------------------------------------
Language
--------------------------------------------------*/

// txt_checkout
$txt_checkout = empty($txt_checkout) ? 'Proceed to checkout' : $txt_checkout;

/*--------------------------------------------------
canonical
--------------------------------------------------*/

$canonical = $baseurl . '/user/process-select-plan';
