<?php
require_once(__DIR__ . '/../inc/config.php');
require_once(__DIR__ . '/user_area_inc.php');

// pagination
$page = !empty($_GET['page']) ? $_GET['page'] : 1;
$limit = $items_per_page;

if($page > 1) {
	$offset = ($page-1) * $limit + 1;
}

else {
	$offset = 1;
}

$page_url = "$baseurl/user/my-favorites?page=";

/*--------------------------------------------------
Pagination
--------------------------------------------------*/

/*--------------------------------------------------
Count favorites
--------------------------------------------------*/
$query = "SELECT COUNT(*) AS c FROM rel_favorites WHERE userid = :userid";
$stmt = $conn->prepare($query);
$stmt->bindValue(':userid', $userid);
$stmt->execute();
$row = $stmt->fetch(PDO::FETCH_ASSOC);
$total_rows = $row['c'];

/*--------------------------------------------------
Get favorites
--------------------------------------------------*/
$my_favorites = array();

if($total_rows > 0) {
	$pager = new App\PageIterator($limit, $total_rows, $page);
	$start = $pager->getStartRow();

	$query = "SELECT
				p.listing_id, p.listing_title, p.main_pic, p.slug AS listing_slug, p.address, p.main_pic, p.submission_date,
				p.postal_code, p.phone, p.area_code, p.lat, p.lng, p.state_id, p.feat, p.short_desc, p.price,
				c.city_name, c.slug, c.state,
				s.state_name, s.slug AS state_slug, s.state_abbr,
				cats.cat_icon, cats.name AS cat_name, cats.cat_slug, cats.id AS cat_id,
				ph.dir, ph.filename,
				rev_table.text, rev_table.avg_rating
			FROM rel_favorites f
			LEFT JOIN listings p ON p.listing_id = f.listing_id
			LEFT JOIN rel_listing_cat r ON p.listing_id = r.listing_id AND r.is_main = 1
			LEFT JOIN cities c ON c.city_id = p.city_id
			LEFT JOIN states s ON c.state_id = s.state_id
			LEFT JOIN cats ON r.cat_id = cats.id
			LEFT JOIN photos ph ON p.listing_id = ph.listing_id
			LEFT JOIN (
				SELECT *,
					AVG(rev.rating) AS avg_rating
					FROM reviews rev
					GROUP BY listing_id
				) rev_table ON p.listing_id = rev_table.listing_id
			WHERE p.status = 'approved' AND p.paid = 1 AND f.userid = :userid
			GROUP BY p.listing_id
			ORDER BY p.feat DESC, p.listing_id DESC
			LIMIT :start, :limit";

	$stmt = $conn->prepare($query);
	$stmt->bindValue(':userid', $userid);
	$stmt->bindValue(':start', $start);
	$stmt->bindValue(':limit', $limit);
	$stmt->execute();

	while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
		$this_address            = !empty($row['address'        ]) ? $row['address'        ] : '';
		$this_area_code          = !empty($row['area_code'      ]) ? $row['area_code'      ] : '';
		$this_cat_icon           = !empty($row['cat_icon'       ]) ? $row['cat_icon'       ] : '';
		$this_cat_id             = !empty($row['cat_id'         ]) ? $row['cat_id'         ] : '';
		$this_cat_name           = !empty($row['cat_name'       ]) ? $row['cat_name'       ] : '';
		$this_cat_slug           = !empty($row['cat_slug'       ]) ? $row['cat_slug'       ] : '';
		$this_dir                = !empty($row['dir'            ]) ? $row['dir'            ] : '';
		$this_filename           = !empty($row['filename'       ]) ? $row['filename'       ] : '';
		$this_is_feat            = !empty($row['feat'           ]) ? $row['feat'           ] : '';
		$this_lat                = !empty($row['lat'            ]) ? $row['lat'            ] : '';
		$this_listing_city_name  = !empty($row['city_name'      ]) ? $row['city_name'      ] : '';
		$this_listing_city_slug  = !empty($row['slug'           ]) ? $row['slug'           ] : 'city';
		$this_listing_id         = !empty($row['listing_id'     ]) ? $row['listing_id'     ] : '';
		$this_listing_price      = !empty($row['price'          ]) ? $row['price'          ] : '';
		$this_listing_slug       = !empty($row['listing_slug'   ]) ? $row['listing_slug'   ] : $listing_id;
		$this_listing_state_abbr = !empty($row['state'          ]) ? $row['state'          ] : '';
		$this_listing_state_id   = !empty($row['state_id'       ]) ? $row['state_id'       ] : '';
		$this_listing_state_slug = !empty($row['state_slug'     ]) ? $row['state_slug'     ] : '';
		$this_listing_title      = !empty($row['listing_title'  ]) ? $row['listing_title'  ] : '';
		$this_lng                = !empty($row['lng'            ]) ? $row['lng'            ] : '';
		$this_main_pic           = !empty($row['main_pic'       ]) ? $row['main_pic'       ] : '';
		$this_phone              = !empty($row['phone'          ]) ? $row['phone'          ] : '';
		$this_postal_code        = !empty($row['postal_code'    ]) ? $row['postal_code'    ] : '';
		$this_rating             = !empty($row['avg_rating'     ]) ? $row['avg_rating'     ] : 5;
		$this_short_desc         = !empty($row['short_desc'     ]) ? $row['short_desc'     ] : '';
		$this_submission_date    = !empty($row['submission_date']) ? $row['submission_date'] : '';

		// sanitize
		$this_address            = e($this_address           );
		$this_area_code          = e($this_area_code         );
		$this_cat_name           = e($this_cat_name          );
		$this_cat_slug           = e($this_cat_slug          );
		$this_dir                = e($this_dir               );
		$this_filename           = e($this_filename          );
		$this_is_feat            = e($this_is_feat           );
		$this_lat                = e($this_lat               );
		$this_listing_city_name  = e($this_listing_city_name );
		$this_listing_city_slug  = e($this_listing_city_slug );
		$this_listing_id         = e($this_listing_id        );
		$this_listing_price      = e($this_listing_price     );
		$this_listing_slug       = e($this_listing_slug      );
		$this_listing_state_abbr = e($this_listing_state_abbr);
		$this_listing_state_id   = e($this_listing_state_id  );
		$this_listing_state_slug = e($this_listing_state_slug);
		$this_listing_title      = e($this_listing_title     );
		$this_lng                = e($this_lng               );
		$this_main_pic           = e($this_main_pic          );
		$this_phone              = e($this_phone             );
		$this_postal_code        = e($this_postal_code       );
		$this_rating             = e($this_rating            );
		$this_short_desc         = e($this_short_desc        );
		$this_submission_date    = e($this_submission_date   );

		// get translated cat name if user language cookie is set
		if(!empty($user_cookie_lang)) {
			$this_cat_name = cat_name_transl($this_cat_id , $user_cookie_lang, 'singular', $this_cat_name);
		}

		// photo url (not being used, main pic is used instead)
		$this_photo_url = $baseurl . '/assets/imgs/blank.png';

		if(!empty($row['filename'])) {
			$this_photo_url = $pic_baseurl . '/' . $listing_thumb_folder . '/' . $this_dir . '/' . $this_filename;
		}

		// main pic
		$this_main_pic_url = $baseurl . '/assets/imgs/blank.png';

		if(!empty($this_photo_url)) {
			$this_main_pic_url = $this_photo_url;
		}

		if(!empty($this_main_pic) && file_exists($pic_basepath . '/main-pic/' . substr($this_main_pic, 0, 2) . '/' . $this_main_pic)) {
			$this_main_pic_url = $pic_baseurl . '/main-pic/' . substr($this_main_pic, 0, 2) . '/' . $this_main_pic;
		}

		// clean listing_title
		$this_endash = html_entity_decode('&#x2013;', ENT_COMPAT, 'UTF-8');
		$this_listing_title = str_replace($this_endash, "-", $this_listing_title);

		// rating
		$this_rating = number_format((float)$this_rating, 2, $cfg_decimal_sep, '');

		// listing link
		$this_listing_link = get_listing_link(
							$this_listing_id,
							$this_listing_slug,
							$this_cat_id,
							$this_cat_slug,
							'',
							$this_listing_city_slug,
							$this_listing_state_slug,
							$cfg_permalink_struct);

		// items array
		$my_favorites[] = array(
			'listing_id'      => $this_listing_id,
			'address'         => $this_address,
			'area_code'       => $this_area_code,
			'cat_icon'        => $this_cat_icon,
			'cat_name'        => $this_cat_name,
			'cat_slug'        => $this_cat_slug,
			'city_name'       => $this_listing_city_name,
			'city_slug'       => $this_listing_city_slug,
			'is_feat'         => $this_is_feat,
			'lat'             => $this_lat,
			'listing_link'    => $this_listing_link,
			'listing_price'   => $this_listing_price,
			'listing_slug'    => $this_listing_slug,
			'listing_title'   => $this_listing_title,
			'lng'             => $this_lng,
			'main_pic_url'    => $this_main_pic_url,
			'phone'           => $this_phone,
			'photo_url'       => $this_photo_url,
			'postal_code'     => $this_postal_code,
			'rating'          => $this_rating,
			'short_desc'      => $this_short_desc,
			'state_abbr'      => $this_listing_state_abbr,
			'state_slug'      => $this_listing_state_slug,
			'submission_date' => $this_submission_date,
		);
	}
}

/*--------------------------------------------------
canonical
--------------------------------------------------*/
$canonical = $baseurl . '/user/my-favorites';
