<?php
require_once(__DIR__ . '/../inc/config.php');
require_once(__DIR__ . '/user_area_inc.php');

// pagination
$page = !empty($_GET['page']) ? $_GET['page'] : 1;
$limit = $items_per_page;

if($page > 1) {
	$offset = ($page-1) * $limit + 1;
}

else {
	$offset = 1;
}

$page_url = "$baseurl/user/my-listings?page=";

// query ads, count total listings for current user
$query = "SELECT COUNT(*) AS c FROM listings
	WHERE status != 'trashed' AND userid = :userid";
$stmt = $conn->prepare($query);
$stmt->bindValue(':userid', $userid);
$stmt->execute();
$row = $stmt->fetch(PDO::FETCH_ASSOC);
$total_rows = $row['c'];

// if user has listings
if($total_rows > 0) {
	$pager = new App\PageIterator($limit, $total_rows, $page);
	$start = $pager->getStartRow();

	$query = "SELECT p.listing_id, p.listing_title, p.slug AS listing_slug, p.description, p.main_pic, p.submission_date, p.status, IF(p.valid_until < CURRENT_TIMESTAMP, 'yes', 'no') AS is_expired,
				c.city_id, c.city_name, c.slug AS city_slug,
				s.state_name, s.slug AS state_slug,
				rel.cat_id,
				cats.name AS cat_name, cats.cat_slug, cats.id AS cat_id,
				ph.filename, ph.dir
				FROM listings p
				LEFT JOIN cities c ON p.city_id = c.city_id
				LEFT JOIN states s ON c.state_id = s.state_id
				LEFT JOIN rel_listing_cat rel ON rel.listing_id = p.listing_id AND rel.is_main = 1
				LEFT JOIN cats ON rel.cat_id = cats.id
				LEFT JOIN photos ph ON p.listing_id = ph.listing_id
				WHERE p.userid = :userid AND p.status != 'trashed'
				GROUP BY p.listing_id
				ORDER BY p.listing_id DESC
				LIMIT :start, :limit";
	$stmt = $conn->prepare($query);
	$stmt->bindValue(':userid', $userid);
	$stmt->bindValue(':start', $start);
	$stmt->bindValue(':limit', $limit);
	$stmt->execute();

	$list_items = array();

	while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
		$this_cat_id          = !empty($row['cat_id'         ]) ? $row['cat_id'         ] : '';
		$this_cat_slug        = !empty($row['cat_slug'       ]) ? $row['cat_slug'       ] : '';
		$this_city_id         = !empty($row['city_id'        ]) ? $row['city_id'        ] : '';
		$this_city_name       = !empty($row['city_name'      ]) ? $row['city_name'      ] : '';
		$this_city_slug       = !empty($row['city_slug'      ]) ? $row['city_slug'      ] : '';
		$this_description     = !empty($row['description'    ]) ? $row['description'    ] : '';
		$this_dir             = !empty($row['dir'            ]) ? $row['dir'            ] : '';
		$this_filename        = !empty($row['filename'       ]) ? $row['filename'       ] : '';
		$this_listing_id      = !empty($row['listing_id'     ]) ? $row['listing_id'     ] : '';
		$this_listing_slug    = !empty($row['listing_slug'   ]) ? $row['listing_slug'   ] : '';
		$this_listing_title   = !empty($row['listing_title'  ]) ? $row['listing_title'  ] : '';
		$this_main_pic        = !empty($row['main_pic'       ]) ? $row['main_pic'       ] : '';
		$this_state_id        = !empty($row['state_id'       ]) ? $row['state_id'       ] : '';
		$this_state_slug      = !empty($row['state_slug'     ]) ? $row['state_slug'     ] : '';
		$this_status          = !empty($row['status'         ]) ? $row['status'         ] : '';
		$this_submission_date = !empty($row['submission_date']) ? $row['submission_date'] : '';
		$this_is_expired      = !empty($row['is_expired'     ]) ? $row['is_expired'     ] : '';

		// sanitize
		$this_cat_slug        = e($this_cat_slug       );
		$this_city_id         = e($this_city_id        );
		$this_city_name       = e($this_city_name      );
		$this_city_slug       = e($this_city_slug      );
		$this_description     = e($this_description    );
		$this_dir             = e($this_dir            );
		$this_filename        = e($this_filename       );
		$this_listing_id      = e($this_listing_id     );
		$this_listing_slug    = e($this_listing_slug   );
		$this_listing_title   = e($this_listing_title  );
		$this_main_pic        = e($this_main_pic       );
		$this_state_id        = e($this_state_id       );
		$this_state_slug      = e($this_state_slug     );
		$this_status          = e($this_status         );
		$this_submission_date = e($this_submission_date);
		$this_is_expired      = e($this_is_expired     );

		// listing link
		$this_listing_link = get_listing_link(
							$this_listing_id,
							$this_listing_slug,
							$this_cat_id,
							$this_cat_slug,
							'',
							$this_city_slug,
							$this_state_slug,
							$cfg_permalink_struct);

		// photo_url
		$this_photo_url = $baseurl . '/assets/imgs/blank.png';

		if(!empty($this_filename)) {
			if(file_exists($pic_basepath . '/listing-thumb/' . $this_dir . '/' . $this_filename)) {
				$this_photo_url = $pic_baseurl . '/listing-thumb/' . $this_dir . '/' . $this_filename;
			}
		}

		if(!empty($this_main_pic)) {
			if(file_exists($pic_basepath . '/main-pic/' . substr($this_main_pic, 0, 2) . '/' . $this_main_pic)) {
				$this_photo_url = $pic_baseurl . '/main-pic/' . substr($this_main_pic, 0, 2) . '/' . $this_main_pic;
			}
		}

		// description
		if(!empty($this_description)) {
			$this_description = mb_substr($this_description, 0, 75) . '...';
		}

		// status
		$this_status = mb_strtolower($this_status);

		// populate array
		$cur_loop_arr = array(
			'cat_slug'        => $this_cat_slug,
			'city_id'         => $this_city_id,
			'city_name'       => $this_city_name,
			'city_slug'       => $this_city_slug,
			'description'     => $this_description,
			'listing_id'      => $this_listing_id,
			'listing_link'    => $this_listing_link,
			'listing_slug'    => $this_listing_slug,
			'listing_title'   => $this_listing_title,
			'photo_url'       => $this_photo_url,
			'state_id'        => $this_state_id,
			'state_slug'      => $this_state_slug,
			'status'          => $this_status,
			'submission_date' => $this_submission_date,
			'is_expired'      => $this_is_expired,
		);

		// add cur loop to listings array
		$list_items[] = $cur_loop_arr;
	} // end while
}

// translation substitutions
$txt_html_title = str_replace('%site_name%', $site_name, $txt_html_title);

/*--------------------------------------------------
canonical
--------------------------------------------------*/
$canonical = $baseurl . '/user/my-listings';
