<?php
/**
 * Cancel subscription
 * This file is called from the /user/my-plans.php file
 *
 * since v.3.03
 */

require_once(__DIR__ . '/../inc/config.php');
require_once(__DIR__ . '/user_area_inc.php');

// csrf check
require_once(__DIR__ . '/_user_inc_request_with_ajax.php');

// post data
$uniq_id = $_POST['uniq_id'];
$gateway = $_POST['gateway'];

// get user email
$query = "SELECT * FROM users WHERE id = :userid";
$stmt = $conn->prepare($query);
$stmt->bindValue(':userid', $userid);
$stmt->execute();
$row = $stmt->fetch(PDO::FETCH_ASSOC);
$user_email = !empty($row['email']) ? $row['email'] : '';

if(mb_strtolower($gateway) == 'stripe') {
	// get subscription id
	$query = "SELECT * FROM credits WHERE uniq_id = :uniq_id AND user = :userid";
	$stmt = $conn->prepare($query);
	$stmt->bindValue(':uniq_id', $uniq_id);
	$stmt->bindValue(':userid', $userid);
	$stmt->execute();
	$row = $stmt->fetch(PDO::FETCH_ASSOC);

	$subscr_id = !empty($row['subscr_id']) ? $row['subscr_id'] : '';

	// cancel
	if(!empty($subscr_id)) {
		try {
			$conn->beginTransaction();

			// if stripe live mode
			if($stripe_mode == 1) {
				$stripe_key = $stripe_live_secret_key;
			}

			// else is stripe test mode
			else {
				$stripe_key = $stripe_test_secret_key;
			}

			// init stripe object
			$stripe = new \Stripe\StripeClient($stripe_key);

			// cancel subscription
			$subscription = $stripe->subscriptions->cancel($subscr_id, []);

			// convert to array
			$subscription = $event->toArray(true);

			// cancel subscription
			if($subscription['status'] !== 'canceled') {
				die('Problem terminating Stripe subscription: ' . $subscription['status']);
			}

			// remove credits
			$query = 'DELETE FROM credits WHERE user = :userid AND uniq_id = :uniq_id';
			$stmt = $conn->prepare($query);
			$stmt->bindValue(':userid', $userid);
			$stmt->bindValue(':uniq_id', $uniq_id);
			$stmt->execute();

			// update listings status to unpaid
			$query = 'UPDATE listings SET paid = 0 WHERE userid = :userid AND credits_uniq_id = :uniq_id';
			$stmt = $conn->prepare($query);
			$stmt->bindValue(':userid', $userid);
			$stmt->bindValue(':uniq_id', $uniq_id);
			$stmt->execute();

			// email user informing subscription ended
			if(!empty($user_email )) {
				$query = "SELECT * FROM email_templates WHERE type = 'subscr_eot'";
				$stmt = $conn->prepare($query);
				$stmt->execute();
				$row = $stmt->fetch(PDO::FETCH_ASSOC);
				$email_subject = !empty($row['subject']) ? $row['subject'] : '';
				$email_body    = !empty($row['body'   ]) ? $row['body'   ] : '';

				// string replacements
				$email_subject = str_replace('%site_name%', $site_name, $email_subject);
				$email_subject = str_replace('%site_url%', $baseurl, $email_subject);
				$email_body = str_replace('%site_name%', $site_name, $email_body);
				$email_body = str_replace('%site_url%', $baseurl, $email_body);

				// send email to user
				if(!empty($email_body)) {
					try {
						// mailer params
						$PHPMailer->clearAllRecipients();
						$PHPMailer->clearReplyTos();
						$PHPMailer->AllowEmpty = true;
						$PHPMailer->setFrom($admin_email, $site_name);
						$PHPMailer->addAddress($admin_email);
						$PHPMailer->addReplyTo($admin_email);
						$PHPMailer->isHTML(false);
						$PHPMailer->Subject = $email_subject;
						$PHPMailer->Body = $email_body;

						// send
						$PHPMailer->send();
					} catch (Exception $e) {
						echo "Message could not be sent. Mailer Error: {$PHPMailer->ErrorInfo}";
					}
				}
			}

			$conn->commit();
		}

		catch(PDOException $e) {
			$conn->rollBack();
			$result_message =  $e->getMessage();

			echo $result_message;
		}
	}

	else {
		echo "Empty subscription id";
	}
}

if(mb_strtolower($gateway) == 'admin') {
	try {
		$conn->beginTransaction();

		// remove credits
		$query = 'DELETE FROM credits WHERE user = :userid AND uniq_id = :uniq_id';
		$stmt = $conn->prepare($query);
		$stmt->bindValue(':userid', $userid);
		$stmt->bindValue(':uniq_id', $uniq_id);
		$stmt->execute();

		// update listings status to unpaid
		$query = 'UPDATE listings SET paid = 0 WHERE userid = :userid AND credits_uniq_id = :uniq_id';
		$stmt = $conn->prepare($query);
		$stmt->bindValue(':userid', $userid);
		$stmt->bindValue(':uniq_id', $uniq_id);
		$stmt->execute();

		// email user informing subscription ended
		$query = "SELECT * FROM email_templates WHERE type = 'subscr_eot'";
		$stmt = $conn->prepare($query);
		$stmt->execute();
		$row = $stmt->fetch(PDO::FETCH_ASSOC);
		$email_subject = !empty($row['subject']) ? $row['subject'] : '';
		$email_body    = !empty($row['body'   ]) ? $row['body'   ] : '';

		// string replacements
		$email_subject = str_replace('%site_name%', $site_name, $email_subject);
		$email_subject = str_replace('%site_url%', $baseurl, $email_subject);
		$email_body = str_replace('%site_name%', $site_name, $email_body);
		$email_body = str_replace('%site_url%', $baseurl, $email_body);

		// send email to user
		if(!empty($user_email )) {
			if(!empty($email_body)) {
				try {
					// mailer params
					$PHPMailer->clearAllRecipients();
					$PHPMailer->clearReplyTos();
					$PHPMailer->AllowEmpty = true;
					$PHPMailer->setFrom($admin_email, $site_name);
					$PHPMailer->addAddress($user_email);
					$PHPMailer->addReplyTo($admin_email);
					$PHPMailer->isHTML(false);
					$PHPMailer->Subject = $email_subject;
					$PHPMailer->Body = $email_body;

					// send
					$PHPMailer->send();
				} catch (Exception $e) {
					echo "Message could not be sent. Mailer Error: {$PHPMailer->ErrorInfo}";
				}
			}
		}

		$conn->commit();
	}

	catch(PDOException $e) {
		$conn->rollBack();
		$result_message =  $e->getMessage();

		echo $result_message;
	}
}