<?php
require_once(__DIR__ . '/../inc/config.php');
require_once(__DIR__ . '/user_area_inc.php');
require_once(__DIR__ . '/../inc/smart_resize_image.php');
require_once(__DIR__ . '/../sitemaps/sitemap-functions.php');

// csrf check
require_once(__DIR__ . '/_user_inc_request_with_php.php');

/*--------------------------------------------------
init vars
--------------------------------------------------*/
$errors = array();
$amount = 0;

// has errors
$has_errors = false;

// default assume listing submitted successfully
$result_message = '';

/*--------------------------------------------------
Post vars
--------------------------------------------------*/
$address           = !empty($_POST['address'          ]) ? $_POST['address'          ] : '';
$area_code         = !empty($_POST['area_code'        ]) ? $_POST['area_code'        ] : '';
$cat_id            = !empty($_POST['category_id'      ]) ? $_POST['category_id'      ] : '';
$city_id           = !empty($_POST['city_id'          ]) ? $_POST['city_id'          ] : $default_loc_id;
$country_code      = !empty($_POST['country_code'     ]) ? $_POST['country_code'     ] : '';
$custom_fields_ids = !empty($_POST['custom_fields_ids']) ? $_POST['custom_fields_ids'] : '';
$delete_temp_pics  = !empty($_POST['delete_temp_pics' ]) ? $_POST['delete_temp_pics' ] : array();
$description       = !empty($_POST['description'      ]) ? $_POST['description'      ] : '';
$latlng            = !empty($_POST['latlng'           ]) ? $_POST['latlng'           ] : '';
$listing_title     = !empty($_POST['listing_title'    ]) ? $_POST['listing_title'    ] : '';
$main_pic          = !empty($_POST['uploaded_main_pic']) ? $_POST['uploaded_main_pic'] : '';
$phone             = !empty($_POST['phone'            ]) ? $_POST['phone'            ] : '';
$plan_uniqid       = !empty($_POST['plan_uniqid'      ]) ? $_POST['plan_uniqid'      ] : null;
$postal_code       = !empty($_POST['postal_code'      ]) ? $_POST['postal_code'      ] : '';
$price             = !empty($_POST['price'            ]) ? $_POST['price'            ] : 0;
$short_desc        = !empty($_POST['short_desc'       ]) ? $_POST['short_desc'       ] : '';
$uploads           = !empty($_POST['uploads'          ]) ? $_POST['uploads'          ] : array();
$wa_area_code      = !empty($_POST['wa_area_code'     ]) ? $_POST['wa_area_code'     ] : '';
$wa_country_code   = !empty($_POST['wa_country_code'  ]) ? $_POST['wa_country_code'  ] : '';
$wa_phone          = !empty($_POST['wa_phone'         ]) ? $_POST['wa_phone'         ] : '';
$cats_arr          = !empty($_POST['cats'             ]) ? $_POST['cats'             ] : array();

/*--------------------------------------------------
prepare vars
--------------------------------------------------*/
// trim
$address           = trim($address);
$area_code         = trim($area_code);
$city_id           = trim($city_id);
$custom_fields_ids = trim($custom_fields_ids);
$description       = trim($description);
$short_desc        = trim($short_desc);
$latlng            = trim($latlng);
$main_pic          = trim($main_pic);
$phone             = trim($phone);
$listing_title     = trim($listing_title);
$plan_uniqid       = trim($plan_uniqid);
$postal_code       = trim($postal_code);
$price             = trim($price);
$wa_area_code      = trim($wa_area_code);
$wa_country_code   = trim($wa_country_code);
$wa_phone          = trim($wa_phone);

// price
$price = preg_replace("/[^0-9]/", "", $price);
$price = (int)$price;

if(!is_int($price)) {
	$price = 0;
}

// remove non numeric chars from whatsapp number
$wa_area_code = preg_replace("/[^0-9]/", "", $wa_area_code);
$wa_country_code = preg_replace("/[^0-9]/", "", $wa_country_code);
$wa_phone = preg_replace("/[^0-9]/", "", $wa_phone);

/*--------------------------------------------------
Check if user has credits for selected plan
--------------------------------------------------*/
if(!$is_admin) {
	$user_credits = 0;

	$query = "SELECT * FROM credits WHERE user = :userid AND uniq_id = :uniq_id";
	$stmt = $conn->prepare($query);
	$stmt->bindValue(':userid', $userid);
	$stmt->bindValue(':uniq_id', $plan_uniqid);
	$stmt->execute();
	$row = $stmt->fetch(PDO::FETCH_ASSOC);

	$credits = !empty($row['credits']) ? $row['credits'] : 0;

	if($credits < 1) {
		$has_errors = true;
		$result_message .= "<br>- No available credits";
	}
}

/*--------------------------------------------------
Plan info
--------------------------------------------------*/

if(!$is_admin) {
	// check plan id selection
	if(empty($plan_uniqid)) {
		$has_errors = true;
		$result_message .= "<br>- Invalid Plan Selection";
	}

	// get plan details
	$query = "SELECT * FROM plans p LEFT JOIN credits c ON p.plan_id = c.plan WHERE c.uniq_id = :plan_uniqid";
	$stmt = $conn->prepare($query);
	$stmt->bindValue(':plan_uniqid', $plan_uniqid);
	$stmt->execute();
	$row = $stmt->fetch(PDO::FETCH_ASSOC);

	$plan_id     = !empty($row['plan_id'    ]) ? $row['plan_id'    ] : '';
	$plan_type   = !empty($row['plan_type'  ]) ? $row['plan_type'  ] : '';
	$plan_name   = !empty($row['plan_name'  ]) ? $row['plan_name'  ] : '';
	$plan_period = !empty($row['plan_period']) ? $row['plan_period'] : 0;
	$plan_price  = !empty($row['plan_price' ]) ? $row['plan_price' ] : 0;
	$plan_status = !empty($row['plan_status']) ? $row['plan_status'] : '';

	// check plan id selection
	if(empty($plan_type) || empty($plan_id)) {
		$has_errors = true;
		$result_message .= "<br>- Invalid Plan Selection";
	}
}

else {
	// get plan details
	$query = "SELECT * FROM plans WHERE plan_id = :plan_id";
	$stmt = $conn->prepare($query);
	$stmt->bindValue(':plan_id', $plan_uniqid);
	$stmt->execute();
	$row = $stmt->fetch(PDO::FETCH_ASSOC);

	$plan_id     = !empty($row['plan_id'    ]) ? $row['plan_id'    ] : '';
	$plan_type   = !empty($row['plan_type'  ]) ? $row['plan_type'  ] : '';
	$plan_name   = !empty($row['plan_name'  ]) ? $row['plan_name'  ] : '';
	$plan_period = !empty($row['plan_period']) ? $row['plan_period'] : 0;
	$plan_price  = !empty($row['plan_price' ]) ? $row['plan_price' ] : 0;
	$plan_status = !empty($row['plan_status']) ? $row['plan_status'] : '';

	// check plan id selection
	if(empty($plan_type) || empty($plan_id)) {
		$has_errors = true;
		$result_message .= "<br>- Invalid Plan Selection";
	}
}

/*--------------------------------------------------
Other vars
--------------------------------------------------*/
// check if is featured;
$feat = 0;
if(	   $plan_type == 'free_feat'
	|| $plan_type == 'monthly_feat'
	|| $plan_type == 'one_time_feat'
	|| $plan_type == 'annual_feat') {
	$feat = 1;
}

// create unique slug
$is_slug_unique = false;
$count = 2;
$listing_slug = to_slug($listing_title);
$new_slug = $listing_slug;

while(!$is_slug_unique) {
	$query = "SELECT COUNT(*) AS total_rows FROM listings WHERE slug = :listing_slug";
	$stmt = $conn->prepare($query);
	$stmt->bindValue(':listing_slug', $new_slug);
	$stmt->execute();
	$row = $stmt->fetch(PDO::FETCH_ASSOC);

	if($row['total_rows'] == 0) {
		$is_slug_unique = true;
	}

	else {
		$new_slug = $listing_slug . '-' . $count;
		$count++;
	}
}

$listing_slug = $new_slug;

// lat/lng
if(!empty($latlng)) {
	$latlng = str_replace('(', '', $latlng);
	$latlng = str_replace(')', '', $latlng);
	$latlng = explode(',', $latlng);
	$lat    = trim($latlng[0]);
	$lng    = trim($latlng[1]);

	settype($lat, 'float');
	settype($lng, 'float');
}

else {
	$lat = null;
	$lng = null;
}

// short_desc length
$short_desc = mb_substr($short_desc, 0, $short_desc_length);

// if city id is empty, try to guess
// use function to get city name using lat lng coords
$state_id = 0;
if(empty($city_id)) {
	if(is_float($lat) && is_float($lng)) {
		$query = "SELECT * , (3959 * ACOS(COS(RADIANS($lat)) * COS(RADIANS(lat)) * COS(RADIANS(lng) - RADIANS($lng)) + SIN(RADIANS($lat)) * SIN( RADIANS(lat)))) AS distance FROM cities ORDER BY distance ASC LIMIT 1";
		$stmt = $conn->prepare($query);
		$stmt->execute();
		$row = $stmt->fetch(PDO::FETCH_ASSOC);
		$city_id  = !empty($row['city_id' ]) ? $row['city_id' ] : '';
		$state_id = !empty($row['state_id']) ? $row['state_id'] : '';
	}

	else {
		$has_errors = true;
		$result_message .= "<br>- Wrong lat/lng value type";
	}
}

// if state_id empty
if(empty($state_id) && !empty($city_id)) {
	$query = "SELECT state_id FROM cities WHERE city_id = :city_id";
	$stmt = $conn->prepare($query);
	$stmt->bindValue(':city_id', $city_id);
	$stmt->execute();
	$row = $stmt->fetch(PDO::FETCH_ASSOC);
	$state_id = !empty($row['state_id']) ? $row['state_id'] : '';
}

// initial status
$status = "pending";
$paid   = 0;

// is auto approve enabled
if($cfg_auto_approve_listing) {
	$status = "approved";
}

// is this user the admin?
if($is_admin == 1) {
	$status = "approved";
	$paid = 1;
}

// if free plan types, set paid to 1
if($plan_type == 'free' || $plan_type == 'free_feat') {
	$paid = 1;
}

/*--------------------------------------------------
Custom fields 1
--------------------------------------------------*/
$custom_fields_ids = explode(',', $custom_fields_ids);
$custom_fields = array();
foreach($custom_fields_ids as $v) {
	$field_key = 'field_' . $v;

	if(!empty($_POST[$field_key])) {
		if(!is_array($_POST[$field_key])) {
			$this_field_value = !empty($_POST[$field_key]) ? $_POST[$field_key] : '';
		}

		else {
			$this_field_value = !empty($_POST[$field_key]) ? $_POST[$field_key] : array();
		}

		$custom_fields[] = array(
			'field_id'    => $v,
			'field_value' => $this_field_value);
	}
}

/*--------------------------------------------------
Submit routine
--------------------------------------------------*/
// check if this page is refreshed/reloaded
// if $_SESSION['submit_token'] and submitted $_POST['submit_token'] match
// it means that the page has not been reloaded,
// process insert, then unset $_SESSION['submit_token'],
// so that if user reloads this page, it doesn't match, so it's not inserted
$post_token    = !empty($_POST['submit_token'  ]) ? $_POST['submit_token'   ] : 'aaa';
$session_token = isset($_SESSION['submit_token']) ? $_SESSION['submit_token'] : '';
$cookie_token  = isset($_COOKIE['submit_token' ]) ? $_COOKIE['submit_token' ] : '';

if(($post_token == $session_token || $post_token == $cookie_token) && !$has_errors) {
	try {
		$conn->beginTransaction();

		/*--------------------------------------------------
		Insert listing
		--------------------------------------------------*/
		$query = "INSERT INTO listings(
			address,
			area_code,
			city_id,
			country_code,
			description,
			short_desc,
			feat,
			lat,
			lng,
			main_pic,
			phone,
			listing_title,
			plan,
			credits_uniq_id,
			postal_code,
			price,
			slug,
			state_id,
			status,
			paid,
			userid,
			valid_until,
			wa_area_code,
			wa_country_code,
			wa_phone
		)
		VALUES(
			:address,
			:area_code,
			:city_id,
			:country_code,
			:description,
			:short_desc,
			:feat,
			:lat,
			:lng,
			:main_pic,
			:phone,
			:listing_title,
			:plan,
			:credits_uniq_id,
			:postal_code,
			:price,
			:slug,
			:state_id,
			:status,
			:paid,
			:userid,
			DATE_ADD(CURRENT_TIMESTAMP, INTERVAL :valid_until DAY),
			:wa_area_code,
			:wa_country_code,
			:wa_phone
		)";

		// set valid until value which is just the number of days of the period
		$valid_until = ($plan_period == 0 || $plan_period > 9999) ? 9999 : $plan_period;

		$stmt = $conn->prepare($query);
		$stmt->bindValue(':address'        , $address);
		$stmt->bindValue(':area_code'      , $area_code);
		$stmt->bindValue(':city_id'        , $city_id);
		$stmt->bindValue(':country_code'   , $country_code);
		$stmt->bindValue(':description'    , $description);
		$stmt->bindValue(':short_desc'     , $short_desc);
		$stmt->bindValue(':feat'           , $feat);
		$stmt->bindValue(':lat'            , $lat);
		$stmt->bindValue(':lng'            , $lng);
		$stmt->bindValue(':main_pic'       , $main_pic);
		$stmt->bindValue(':phone'          , $phone);
		$stmt->bindValue(':listing_title'  , $listing_title);
		$stmt->bindValue(':plan'           , $plan_id);
		$stmt->bindValue(':credits_uniq_id', $plan_uniqid);
		$stmt->bindValue(':postal_code'    , $postal_code);
		$stmt->bindValue(':price'          , $price);
		$stmt->bindValue(':slug'           , $listing_slug);
		$stmt->bindValue(':state_id'       , $state_id);
		$stmt->bindValue(':status'         , $status);
		$stmt->bindValue(':paid'           , 1);
		$stmt->bindValue(':userid'         , $userid);
		$stmt->bindValue(':valid_until'    , $valid_until);
		$stmt->bindValue(':wa_area_code'   , $wa_area_code);
		$stmt->bindValue(':wa_country_code', $wa_country_code);
		$stmt->bindValue(':wa_phone'       , $wa_phone);
		$stmt->execute();

		$listing_id = $conn->lastInsertId();
		$_SESSION['last_submitted_listing_id'] = $listing_id;

		/*--------------------------------------------------
		rel_listing_cat
		--------------------------------------------------*/

		// $cat_id is the primary category
		// $cats_arr = $_POST['cats'] is an array of secondary categories
		// modify $cats_arr structure to include is_main info and add $cat_id
		foreach($cats_arr as $k => $v) {
			if($v != $cat_id) {
				$cats_arr[$k] = array($v, 0);
			}

			else {
				unset($cats_arr[$k]);
			}
		}

		$cats_arr[] = array($cat_id, 1);

		if(!empty($cats_arr)) {
			// build query
			$query = "INSERT IGNORE INTO rel_listing_cat(listing_id, cat_id, city_id, is_main) VALUES";

			$i = 1;
			foreach($cats_arr as $v) {
				$is_main = $v[1];

				if(is_numeric($v[0])) {
					if($i > 1) {
						$query .= ", ";
					}

					$query .= "(:listing_id_$i, :cat_id_$i, :city_id_$i, :is_main_$i)";
					$i++;
				}
			}

			// prepare
			$stmt = $conn->prepare($query);

			// bind
			$i = 1;
			foreach($cats_arr as $v) {
				if(is_numeric($v[0])) {
					$stmt->bindValue(":listing_id_$i", $listing_id);
					$stmt->bindValue(":cat_id_$i", $v[0]);
					$stmt->bindValue(":city_id_$i", $city_id);
					$stmt->bindValue(":is_main_$i", $v[1]);
					$i++;
				}
			}

			// execute
			$stmt->execute();
		}

		/*--------------------------------------------------
		Main Pic
		--------------------------------------------------*/
		// folder
		$folder_path = $pic_basepath . '/main-pic/' . substr($main_pic, 0, 2);

		if (!is_dir($folder_path)) {
			if(!mkdir($folder_path, 0755, true)) {
				$has_errors = true;
				$result_message .= '<br>- Error creating main pic directory';
			}

			// create empty index file in the folder
			touch($folder_path . '/index.php');
		}

		// paths and folders
		$path_tmp   = $pic_basepath . '/main-pic-tmp/' . $main_pic;
		$path_final = $folder_path . '/' . $main_pic;

		if(is_file($path_tmp)) {
			if(copy($path_tmp, $path_final)) {
				unlink($path_tmp);
			}
		}

		/*--------------------------------------------------
		Photos
		--------------------------------------------------*/

		// delete pics from temp folder that were deleted by user while posting
		if(!empty($delete_temp_pics)) {
			foreach($delete_temp_pics as $v) {
				$temp_pic_path = $pic_basepath . '/' . $listing_tmp_folder . '/' . $v;
				if(is_file($temp_pic_path)) {
					unlink($temp_pic_path);
				}
			}
		}

		// uploaded images
		if(!empty($uploads)) {
			// define dirs
			$query = "SELECT photo_id FROM photos ORDER BY photo_id DESC LIMIT 1";
			$stmt = $conn->prepare($query);
			$stmt->execute();
			$row = $stmt->fetch(PDO::FETCH_ASSOC);
			$last_photo_id = !empty($row['photo_id']) ? $row['photo_id'] : 1;
			$dir_num = floor($last_photo_id / 1000) + 1;

			$dir_full  = $pic_basepath . '/' . $listing_full_folder . '/' . $dir_num;
			$dir_thumb = $pic_basepath . '/' . $listing_thumb_folder . '/' . $dir_num;

			if (!is_dir($dir_full)) {
				mkdir($dir_full, 0777, true);
			}

			if (!is_dir($dir_thumb)) {
				mkdir($dir_thumb, 0777, true);
			}

			// tmp folder
			$tmp_folder = $pic_basepath . '/' . $listing_tmp_folder;

			if(!isset($global_thumb_width)) {
				$global_thumb_width = 250;
			}

			if(!isset($global_thumb_height)) {
				$global_thumb_height = 250;
			}

			// uploads counter
			$pic_count = 1;

			foreach($uploads as $v) {
				// only insert into db if the move from temp to final destination folder is successful,
				// otherwise user could send custom uploads[] value and replace original(thus deleting) previous pics
				// from other ads
				$tmp_file = $tmp_folder . '/' . $v;

				// if total pics <= max_pics
				if($pic_count < $max_pics + 1) {
					if(copy($tmp_file, $dir_full . '/' . $v)) {
						// insert into photos table
						$stmt = $conn->prepare('
						INSERT INTO photos(listing_id, dir, filename)
						VALUES(:listing_id, :dir, :filename)');

						$stmt->bindValue(':listing_id', $listing_id);
						$stmt->bindValue(':dir'     , $dir_num);
						$stmt->bindValue(':filename', $v);
						$stmt->execute();
					}

					smart_resize_image($tmp_file, null, $global_thumb_width, $global_thumb_height, false, $dir_thumb . '/' . $v, true, false, 85);

					// delete pic from tmp_photos table
					$query = "DELETE FROM tmp_photos WHERE filename = :filename";
					$stmt = $conn->prepare($query);
					$stmt->bindValue(':filename', $v);
					$stmt->execute();

					// if user uploaded more than max_pics, ignore further uploads
					$pic_count++;

					if($pic_count > $max_pics) {
						break;
					}
				}

				// else delete uploaded pic from tmp folder
				else {
					if(is_file($tmp_file)) {
						unlink($tmp_file);
					}
				}
			}
		}

		/*--------------------------------------------------
		Custom fields 2
		--------------------------------------------------*/

		// remove duplicates
		$custom_fields = array_unique($custom_fields, SORT_REGULAR);

		// insert into rel_listing_custom_fields
		foreach($custom_fields as $v) {
			if(!is_array($v['field_value'])) {
				if(!empty($v['field_value'])) {
					$query = "INSERT INTO rel_listing_custom_fields(listing_id, field_id, field_value)
						VALUES(:listing_id, :field_id, :field_value)";
					$stmt = $conn->prepare($query);
					$stmt->bindValue(':listing_id', $listing_id);
					$stmt->bindValue(':field_id', $v['field_id']);
					$stmt->bindValue(':field_value', $v['field_value']);
					$stmt->execute();
				}
			}

			else {
				foreach($v['field_value'] as $v2) {
					if(!empty($v2)) {
						$query = "INSERT INTO rel_listing_custom_fields(listing_id, field_id, field_value)
							VALUES(:listing_id, :field_id, :field_value)";
						$stmt = $conn->prepare($query);
						$stmt->bindValue(':listing_id', $listing_id);
						$stmt->bindValue(':field_id', $v['field_id']);
						$stmt->bindValue(':field_value', $v2);
						$stmt->execute();
					}
				}
			}
		}

		/*--------------------------------------------------
		Credits
		--------------------------------------------------*/
		$query = "UPDATE credits SET credits = credits -1 WHERE user = :userid AND uniq_id = :plan_uniqid";
		$stmt = $conn->prepare($query);
		$stmt->bindValue(':userid', $userid);
		$stmt->bindValue(':plan_uniqid', $plan_uniqid);
		$stmt->execute();

		/*--------------------------------------------------
		Commit
		--------------------------------------------------*/
		$conn->commit();
	}

	catch(PDOException $e) {
		$conn->rollBack();
		$has_errors = true;
		$result_message .= "<br>- " . $e->getMessage();
	}

	// empty session submit token
	unset($_SESSION['submit_token']);

	/*--------------------------------------------------
	sitemap
	--------------------------------------------------*/
	if($cfg_enable_sitemaps && $status == 'approved' && $paid == 1) {
		$listing_link = get_listing_link($listing_id, $listing_slug, $cat_id, '', $city_id, '', '', $cfg_permalink_struct);

		sitemap_add_url($listing_link);
	}
}

// else assume user reloaded page
else {
	$result_message = '';

	if($post_token != $session_token) {
		$result_message .= "<br>post_token <> session_token<br>post_token = $post_token<br>session_token = $session_token<br>";
		$has_errors = true;
	}

	if($post_token != $cookie_token) {
		$result_message .= "<br>post_token <> cookie_token<br>post_token = $post_token<br>cookie_token = $cookie_token<br>";
		$has_errors = true;
	}
}

// listing id, in case page is refreshed, $conn->lastInsertId() is lost, so get listing_id from SESSION
if(empty($listing_id) && isset($_SESSION['last_submitted_listing_id'])) {
	$listing_id = $_SESSION['last_submitted_listing_id'];
}

/*--------------------------------------------------
Notify listing created
--------------------------------------------------*/

if($mail_after_post) {
	// listing link
	$listing_link = get_listing_link($listing_id, $listing_slug, $cat_id, '', $city_id, '', '', $cfg_permalink_struct);

	// get email template
	$query = "SELECT * FROM email_templates WHERE type = 'process_add_listing'";
	$stmt = $conn->prepare($query);
	$stmt->execute();
	$row = $stmt->fetch(PDO::FETCH_ASSOC);
	$email_subject = !empty($row['subject']) ? $row['subject'] : '';
	$email_body = !empty($row['body']) ? $row['body'] : '';

	// replace %new_listing_url%
	$email_body = str_replace('%new_listing_url%', $listing_link, $email_body);

	try {
		// mailer params
		$PHPMailer->clearAllRecipients();
		$PHPMailer->clearReplyTos();
		$PHPMailer->AllowEmpty = true;
		$PHPMailer->setFrom($admin_email, $site_name);
		$PHPMailer->addAddress($admin_email);
		$PHPMailer->isHTML(false);
		$PHPMailer->Subject = $email_subject;
		$PHPMailer->Body = $email_body;

		// send
		$PHPMailer->send();
	} catch (Exception $e) {
		echo '<!-- ' . "Message could not be sent. Mailer Error: {$PHPMailer->ErrorInfo}" . ' -->';
	}
}

/*--------------------------------------------------
canonical
--------------------------------------------------*/
$canonical = $baseurl . '/user/process-create-listing';
