<?php
require_once(__DIR__ . '/../inc/config.php');
require_once(__DIR__ . '/user_area_inc.php');
require_once(__DIR__ . '/../sitemaps/sitemap-functions.php');

// csrf check
require_once(__DIR__ . '/_user_inc_request_with_ajax.php');

// post data
$listing_id = $_POST['listing_id'];

// check listing
$stmt = $conn->prepare('SELECT * FROM listings WHERE listing_id = :listing_id AND userid = :userid');
$stmt->bindValue(':listing_id', $listing_id);
$stmt->bindValue(':userid', $userid);
$stmt->execute();
$row = $stmt->fetch(PDO::FETCH_ASSOC);

$city_id         = !empty($row['city_id'        ]) ? $row['city_id'        ] : '';
$paid            = !empty($row['paid'           ]) ? $row['paid'           ] : '';
$listing_id      = !empty($row['listing_id'     ]) ? $row['listing_id'     ] : '';
$slug            = !empty($row['slug'           ]) ? $row['slug'           ] : '';
$state_id        = !empty($row['state_id'       ]) ? $row['state_id'       ] : '';
$main_pic        = !empty($row['main_pic'       ]) ? $row['main_pic'       ] : '';
$plan_id         = !empty($row['plan'           ]) ? $row['plan'           ] : '';
$credits_uniq_id = !empty($row['credits_uniq_id']) ? $row['credits_uniq_id'] : '';

// get listing link (must save listing link in memory before deleting row from database)
$listing_link = '';
if($cfg_enable_sitemaps && !empty($listing_id)) {
	$listing_link = get_listing_link($listing_id, '', '', '', $city_id, '', '', $cfg_permalink_struct);
}

// check if user is owner of this listing
if($row['userid'] == $userid) {
	try {
		$conn->beginTransaction();

		// delete photos first, before cascading foreign key
		$query = "SELECT dir, filename FROM photos WHERE listing_id = :listing_id";
		$stmt = $conn->prepare($query);
		$stmt->bindValue(':listing_id', $listing_id);
		$stmt->execute();

		while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
			$dir = $row['dir'];
			$filename = $row['filename'];

			$full_pic = $pic_basepath . '/' . $listing_full_folder . '/' . $dir . '/' . $filename;
			$thumb_pic = $pic_basepath . '/' . $listing_thumb_folder . '/' . $dir . '/' . $filename;

			if(is_file($full_pic)) {
				unlink($full_pic);
			}

			if(is_file($thumb_pic)) {
				unlink($thumb_pic);
			}
		}

		// delete main pic
		if(is_file($pic_basepath . '/main-pic/' . substr($main_pic, 0, 2) . '/' . $main_pic)) {
			unlink($pic_basepath . '/main-pic/' . substr($main_pic, 0, 2) . '/' . $main_pic);
		}

		// if it's a subscription, add credit back to user
		$query = "SELECT * FROM plans WHERE plan_id = :plan_id";
		$stmt = $conn->prepare($query);
		$stmt->bindValue(':plan_id', $plan_id);
		$stmt->execute();
		$row = $stmt->fetch(PDO::FETCH_ASSOC);

		$plan_type = $row['plan_type'];
		$subscr_types = array('monthly', 'monthly_feat', 'annual', 'annual_feat');

		if(in_array($plan_type, $subscr_types)) {
			// add credit
			$query = "UPDATE credits SET credits = credits + 1 WHERE user = :userid AND uniq_id = :uniq_id";
			$stmt = $conn->prepare($query);
			$stmt->bindValue(':userid', $userid);
			$stmt->bindValue(':uniq_id', $credits_uniq_id);
			$stmt->execute();

			echo "added credits";
		}

		// delete from db
		$query = "DELETE FROM listings WHERE listing_id = :listing_id";
		$stmt = $conn->prepare($query);
		$stmt->bindValue(':listing_id', $listing_id);
		$stmt->execute();

		$conn->commit();

		/*--------------------------------------------------
		Delete from sitemap
		--------------------------------------------------*/
		if($cfg_enable_sitemaps && !empty($listing_link)) {
			sitemap_remove_url($listing_link);
		}
	}

	catch(PDOException $e) {
		$conn->rollBack();
		$result_message =  $e->getMessage();

		echo $result_message;
	}
}

else {
	echo "User id does not match the listing user";
}